@@ -5,12 +5,14 @@
  * @license GPL-2.0+
  */
 
-class LU_JSONReaderTest extends MediaWikiTestCase {
+namespace LocalisationUpdate;
+
+class JSONReaderTest extends \PHPUnit_Framework_TestCase {
 	/**
 	 * @dataProvider parseProvider
 	 */
 	public function testParse( $input, $expected, $comment ) {
-		$reader = new LU_JSONReader( 'xx' );
+		$reader = new JSONReader( 'xx' );
 		$observed = $reader->parse( $input );
 		$this->assertEquals( $expected, $observed['xx'], $comment );
 	}
