@@ -60,7 +60,7 @@ class Http {
 	 * @param string $caller The method making this request, for profiling
 	 * @return string|bool (bool)false on failure or a string on success
 	 */
-	public static function request( $method, $url, $options = array(), $caller = __METHOD__ ) {
+	public static function request( $method, $url, $options = [], $caller = __METHOD__ ) {
 		wfDebug( "HTTP: $method: $url\n" );
 
 		$options['method'] = strtoupper( $method );
@@ -80,7 +80,8 @@ class Http {
 		} else {
 			$errors = $status->getErrorsByType( 'error' );
 			$logger = LoggerFactory::getInstance( 'http' );
-			$logger->warning( $status->getWikiText(), array( 'caller' => $caller ) );
+			$logger->warning( $status->getWikiText( false, false, 'en' ),
+				[ 'error' => $errors, 'caller' => $caller, 'content' => $req->getContent() ] );
 			return false;
 		}
 	}
@@ -94,16 +95,16 @@ class Http {
 	 * @param string $url
 	 * @param array $options
 	 * @param string $caller The method making this request, for profiling
-	 * @return string
+	 * @return string|bool false on error
 	 */
-	public static function get( $url, $options = array(), $caller = __METHOD__ ) {
+	public static function get( $url, $options = [], $caller = __METHOD__ ) {
 		$args = func_get_args();
 		if ( isset( $args[1] ) && ( is_string( $args[1] ) || is_numeric( $args[1] ) ) ) {
 			// Second was used to be the timeout
 			// And third parameter used to be $options
 			wfWarn( "Second parameter should not be a timeout.", 2 );
 			$options = isset( $args[2] ) && is_array( $args[2] ) ?
-				$args[2] : array();
+				$args[2] : [];
 			$options['timeout'] = $args[1];
 			$caller = __METHOD__;
 		}
@@ -117,9 +118,9 @@ class Http {
 	 * @param string $url
 	 * @param array $options
 	 * @param string $caller The method making this request, for profiling
-	 * @return string
+	 * @return string|bool false on error
 	 */
-	public static function post( $url, $options = array(), $caller = __METHOD__ ) {
+	public static function post( $url, $options = [], $caller = __METHOD__ ) {
 		return Http::request( 'POST', $url, $options, $caller );
 	}
 
@@ -130,14 +131,14 @@ class Http {
 	 * @return bool
 	 */
 	public static function isLocalURL( $url ) {
-		global $wgCommandLineMode, $wgLocalVirtualHosts, $wgConf;
+		global $wgCommandLineMode, $wgLocalVirtualHosts;
 
 		if ( $wgCommandLineMode ) {
 			return false;
 		}
 
 		// Extract host part
-		$matches = array();
+		$matches = [];
 		if ( preg_match( '!^http://([\w.-]+)[/:].*$!', $url, $matches ) ) {
 			$host = $matches[1];
 			// Split up dotwise
@@ -155,9 +156,7 @@ class Http {
 					$domain = $domainPart . '.' . $domain;
 				}
 
-				if ( in_array( $domain, $wgLocalVirtualHosts )
-					|| $wgConf->isLocalVHost( $domain )
-				) {
+				if ( in_array( $domain, $wgLocalVirtualHosts ) ) {
 					return true;
 				}
 			}
@@ -193,6 +192,26 @@ class Http {
 			$uri
 		);
 	}
+
+	/**
+	 * Gets the relevant proxy from $wgHTTPProxy/http_proxy (when set).
+	 *
+	 * @return mixed The proxy address or an empty string if not set.
+	 */
+	public static function getProxy() {
+		global $wgHTTPProxy;
+
+		if ( $wgHTTPProxy ) {
+			return $wgHTTPProxy;
+		}
+
+		$envHttpProxy = getenv( "http_proxy" );
+		if ( $envHttpProxy ) {
+			return $envHttpProxy;
+		}
+
+		return "";
+	}
 }
 
 /**
@@ -215,7 +234,7 @@ class MWHttpRequest {
 	protected $sslVerifyCert = true;
 	protected $caInfo = null;
 	protected $method = "GET";
-	protected $reqHeaders = array();
+	protected $reqHeaders = [];
 	protected $url;
 	protected $parsedUrl;
 	protected $callback;
@@ -227,10 +246,10 @@ class MWHttpRequest {
 	 */
 	protected $cookieJar;
 
-	protected $headerList = array();
+	protected $headerList = [];
 	protected $respVersion = "0.9";
 	protected $respStatus = "200 Ok";
-	protected $respHeaders = array();
+	protected $respHeaders = [];
 
 	public $status;
 
@@ -250,7 +269,9 @@ class MWHttpRequest {
 	 * @param string $caller The method making this request, for profiling
 	 * @param Profiler $profiler An instance of the profiler for profiling, or null
 	 */
-	protected function __construct( $url, $options = array(), $caller = __METHOD__, $profiler = null ) {
+	protected function __construct(
+		$url, $options = [], $caller = __METHOD__, $profiler = null
+	) {
 		global $wgHTTPTimeout, $wgHTTPConnectTimeout;
 
 		$this->url = wfExpandUrl( $url, PROTO_HTTP );
@@ -276,8 +297,8 @@ class MWHttpRequest {
 			$this->setUserAgent( $options['userAgent'] );
 		}
 
-		$members = array( "postData", "proxy", "noProxy", "sslVerifyHost", "caInfo",
-				"method", "followRedirects", "maxRedirects", "sslVerifyCert", "callback" );
+		$members = [ "postData", "proxy", "noProxy", "sslVerifyHost", "caInfo",
+				"method", "followRedirects", "maxRedirects", "sslVerifyCert", "callback" ];
 
 		foreach ( $members as $o ) {
 			if ( isset( $options[$o] ) ) {
@@ -367,8 +388,6 @@ class MWHttpRequest {
 	 * @return void
 	 */
 	public function proxySetup() {
-		global $wgHTTPProxy;
-
 		// If there is an explicit proxy set and proxies are not disabled, then use it
 		if ( $this->proxy && !$this->noProxy ) {
 			return;
@@ -378,10 +397,8 @@ class MWHttpRequest {
 		// local URL and proxies are not disabled
 		if ( Http::isLocalURL( $this->url ) || $this->noProxy ) {
 			$this->proxy = '';
-		} elseif ( $wgHTTPProxy ) {
-			$this->proxy = $wgHTTPProxy;
-		} elseif ( getenv( "http_proxy" ) ) {
-			$this->proxy = getenv( "http_proxy" );
+		} else {
+			$this->proxy = Http::getProxy();
 		}
 	}
 
@@ -408,7 +425,7 @@ class MWHttpRequest {
 	 * @return array
 	 */
 	public function getHeaderList() {
-		$list = array();
+		$list = [];
 
 		if ( $this->cookieJar ) {
 			$this->reqHeaders['Cookie'] =
@@ -479,7 +496,7 @@ class MWHttpRequest {
 		$this->proxySetup(); // set up any proxy as needed
 
 		if ( !$this->callback ) {
-			$this->setCallback( array( $this, 'read' ) );
+			$this->setCallback( [ $this, 'read' ] );
 		}
 
 		if ( !isset( $this->reqHeaders['User-Agent'] ) ) {
@@ -678,7 +695,7 @@ class MWHttpRequest {
 	public function getFinalUrl() {
 		$headers = $this->getResponseHeaders();
 
-		//return full url (fix for incorrect but handled relative location)
+		// return full url (fix for incorrect but handled relative location)
 		if ( isset( $headers['location'] ) ) {
 			$locations = $headers['location'];
 			$domain = '';
@@ -690,7 +707,7 @@ class MWHttpRequest {
 
 				if ( isset( $url['host'] ) ) {
 					$domain = $url['scheme'] . '://' . $url['host'];
-					break; //found correct URI (with host)
+					break; // found correct URI (with host)
 				} else {
 					$foundRelativeURI = true;
 				}
@@ -730,7 +747,7 @@ class MWHttpRequest {
 class CurlHttpRequest extends MWHttpRequest {
 	const SUPPORTS_FILE_POSTS = true;
 
-	protected $curlOptions = array();
+	protected $curlOptions = [];
 	protected $headerText = "";
 
 	/**
@@ -761,7 +778,7 @@ class CurlHttpRequest extends MWHttpRequest {
 
 		$this->curlOptions[CURLOPT_HTTP_VERSION] = CURL_HTTP_VERSION_1_0;
 		$this->curlOptions[CURLOPT_WRITEFUNCTION] = $this->callback;
-		$this->curlOptions[CURLOPT_HEADERFUNCTION] = array( $this, "readHeader" );
+		$this->curlOptions[CURLOPT_HEADERFUNCTION] = [ $this, "readHeader" ];
 		$this->curlOptions[CURLOPT_MAXREDIRS] = $this->maxRedirects;
 		$this->curlOptions[CURLOPT_ENCODING] = ""; # Enable compression
 
@@ -787,7 +804,7 @@ class CurlHttpRequest extends MWHttpRequest {
 			// but we support lower versions, and the option doesn't exist in HHVM 5.6.99.
 			if ( defined( 'CURLOPT_SAFE_UPLOAD' ) ) {
 				$this->curlOptions[CURLOPT_SAFE_UPLOAD] = true;
-			} else if ( is_array( $postData ) ) {
+			} elseif ( is_array( $postData ) ) {
 				// In PHP 5.2 and later, '@' is interpreted as a file upload if POSTFIELDS
 				// is an array, but not if it's a string. So convert $req['body'] to a string
 				// for safety.
@@ -815,7 +832,7 @@ class CurlHttpRequest extends MWHttpRequest {
 			MediaWiki\suppressWarnings();
 			if ( !curl_setopt( $curlHandle, CURLOPT_FOLLOWLOCATION, true ) ) {
 				wfDebug( __METHOD__ . ": Couldn't set CURLOPT_FOLLOWLOCATION. " .
-					"Probably safe_mode or open_basedir is set.\n" );
+					"Probably open_basedir is set.\n" );
 				// Continue the processing. If it were in curl_setopt_array,
 				// processing would have halted on its entry
 			}
@@ -853,24 +870,26 @@ class CurlHttpRequest extends MWHttpRequest {
 	 * @return bool
 	 */
 	public function canFollowRedirects() {
-		if ( strval( ini_get( 'open_basedir' ) ) !== '' || wfIniGetBool( 'safe_mode' ) ) {
-			wfDebug( "Cannot follow redirects in safe mode\n" );
-			return false;
-		}
-
 		$curlVersionInfo = curl_version();
 		if ( $curlVersionInfo['version_number'] < 0x071304 ) {
 			wfDebug( "Cannot follow redirects with libcurl < 7.19.4 due to CVE-2009-0037\n" );
 			return false;
 		}
 
+		if ( version_compare( PHP_VERSION, '5.6.0', '<' ) ) {
+			if ( strval( ini_get( 'open_basedir' ) ) !== '' ) {
+				wfDebug( "Cannot follow redirects when open_basedir is set\n" );
+				return false;
+			}
+		}
+
 		return true;
 	}
 }
 
 class PhpHttpRequest extends MWHttpRequest {
 
-	private $fopenErrors = array();
+	private $fopenErrors = [];
 
 	/**
 	 * @param string $url
@@ -883,23 +902,28 @@ class PhpHttpRequest extends MWHttpRequest {
 	}
 
 	/**
-	 * Returns an array with a 'capath' or 'cafile' key that is suitable to be merged into the 'ssl' sub-array of a
-	 * stream context options array. Uses the 'caInfo' option of the class if it is provided, otherwise uses the system
+	 * Returns an array with a 'capath' or 'cafile' key
+	 * that is suitable to be merged into the 'ssl' sub-array of
+	 * a stream context options array.
+	 * Uses the 'caInfo' option of the class if it is provided, otherwise uses the system
 	 * default CA bundle if PHP supports that, or searches a few standard locations.
 	 * @return array
 	 * @throws DomainException
 	 */
 	protected function getCertOptions() {
-		$certOptions = array();
-		$certLocations = array();
+		$certOptions = [];
+		$certLocations = [];
 		if ( $this->caInfo ) {
-			$certLocations = array( 'manual' => $this->caInfo );
+			$certLocations = [ 'manual' => $this->caInfo ];
 		} elseif ( version_compare( PHP_VERSION, '5.6.0', '<' ) ) {
+			// @codingStandardsIgnoreStart Generic.Files.LineLength
 			// Default locations, based on
 			// https://www.happyassassin.net/2015/01/12/a-note-about-ssltls-trusted-certificate-stores-and-platforms/
-			// PHP 5.5 and older doesn't have any defaults, so we try to guess ourselves. PHP 5.6+ gets the CA location
-			// from OpenSSL as long as it is not set manually, so we should leave capath/cafile empty there.
-			$certLocations = array_filter( array(
+			// PHP 5.5 and older doesn't have any defaults, so we try to guess ourselves.
+			// PHP 5.6+ gets the CA location from OpenSSL as long as it is not set manually,
+			// so we should leave capath/cafile empty there.
+			// @codingStandardsIgnoreEnd
+			$certLocations = array_filter( [
 				getenv( 'SSL_CERT_DIR' ),
 				getenv( 'SSL_CERT_PATH' ),
 				'/etc/pki/tls/certs/ca-bundle.crt', # Fedora et al
@@ -907,10 +931,10 @@ class PhpHttpRequest extends MWHttpRequest {
 				'/etc/pki/tls/certs/ca-bundle.trust.crt',
 				'/etc/pki/ca-trust/extracted/pem/tls-ca-bundle.pem',
 				'/System/Library/OpenSSL', # OSX
-			) );
+			] );
 		}
 
-		foreach( $certLocations as $key => $cert ) {
+		foreach ( $certLocations as $key => $cert ) {
 			if ( is_dir( $cert ) ) {
 				$certOptions['capath'] = $cert;
 				break;
@@ -927,13 +951,15 @@ class PhpHttpRequest extends MWHttpRequest {
 	}
 
 	/**
-	 * Custom error handler for dealing with fopen() errors. fopen() tends to fire multiple errors in succession, and the last one
-	 * is completely useless (something like "fopen: failed to open stream") so normal methods of handling errors programmatically
+	 * Custom error handler for dealing with fopen() errors.
+	 * fopen() tends to fire multiple errors in succession, and the last one
+	 * is completely useless (something like "fopen: failed to open stream")
+	 * so normal methods of handling errors programmatically
 	 * like get_last_error() don't work.
 	 */
 	public function errorHandler( $errno, $errstr ) {
 		$n = count( $this->fopenErrors ) + 1;
-		$this->fopenErrors += array( "errno$n" => $errno, "errstr$n" => $errstr );
+		$this->fopenErrors += [ "errno$n" => $errno, "errstr$n" => $errstr ];
 	}
 
 	public function execute() {
@@ -960,8 +986,8 @@ class PhpHttpRequest extends MWHttpRequest {
 		}
 
 		// Set up PHP stream context
-		$options = array(
-			'http' => array(
+		$options = [
+			'http' => [
 				'method' => $this->method,
 				'header' => implode( "\r\n", $this->getHeaderList() ),
 				'protocol_version' => '1.1',
@@ -971,15 +997,17 @@ class PhpHttpRequest extends MWHttpRequest {
 				// Curl options in case curlwrappers are installed
 				'curl_verify_ssl_host' => $this->sslVerifyHost ? 2 : 0,
 				'curl_verify_ssl_peer' => $this->sslVerifyCert,
-			),
-			'ssl' => array(
+			],
+			'ssl' => [
 				'verify_peer' => $this->sslVerifyCert,
 				'SNI_enabled' => true,
-			),
-		);
+				'ciphers' => 'HIGH:!SSLv2:!SSLv3:-ADH:-kDH:-kECDH:-DSS',
+				'disable_compression' => true,
+			],
+		];
 
 		if ( $this->proxy ) {
-			$options['http']['proxy'] = $this->urlToTCP( $this->proxy );
+			$options['http']['proxy'] = $this->urlToTcp( $this->proxy );
 			$options['http']['request_fulluri'] = true;
 		}
 
@@ -1001,11 +1029,11 @@ class PhpHttpRequest extends MWHttpRequest {
 
 		$context = stream_context_create( $options );
 
-		$this->headerList = array();
+		$this->headerList = [];
 		$reqCount = 0;
 		$url = $this->url;
 
-		$result = array();
+		$result = [];
 
 		if ( $this->profiler ) {
 			$profileSection = $this->profiler->scopedProfileIn(
@@ -1014,8 +1042,8 @@ class PhpHttpRequest extends MWHttpRequest {
 		}
 		do {
 			$reqCount++;
-			$this->fopenErrors = array();
-			set_error_handler( array( $this, 'errorHandler' ) );
+			$this->fopenErrors = [];
+			set_error_handler( [ $this, 'errorHandler' ] );
 			$fh = fopen( $url, "r", false, $context );
 			restore_error_handler();
 
