@@ -73,8 +73,8 @@ class ChangeTagsLogItem extends RevisionItemBase {
 		$loglink = Linker::link(
 			SpecialPage::getTitleFor( 'Log' ),
 			$this->list->msg( 'log' )->escaped(),
-			array(),
-			array( 'page' => $title->getPrefixedText() )
+			[],
+			[ 'page' => $title->getPrefixedText() ]
 		);
 		$loglink = $this->list->msg( 'parentheses' )->rawParams( $loglink )->escaped();
 		// User links and action text
@@ -88,10 +88,14 @@ class ChangeTagsLogItem extends RevisionItemBase {
 		}
 
 		$content = "$loglink $date $action $comment";
-		$attribs = array();
+		$attribs = [];
 		$tags = $this->getTags();
 		if ( $tags ) {
-			list( $tagSummary, $classes ) = ChangeTags::formatSummaryRow( $tags, 'edittags' );
+			list( $tagSummary, $classes ) = ChangeTags::formatSummaryRow(
+				$tags,
+				'edittags',
+				$this->list->getContext()
+			);
 			$content .= " $tagSummary";
 			$attribs['class'] = implode( ' ', $classes );
 		}
