@@ -30,7 +30,7 @@
 class JsonContentHandler extends CodeContentHandler {
 
 	public function __construct( $modelId = CONTENT_MODEL_JSON ) {
-		parent::__construct( $modelId, array( CONTENT_FORMAT_JSON ) );
+		parent::__construct( $modelId, [ CONTENT_FORMAT_JSON ] );
 	}
 
 	/**
