@@ -25,7 +25,7 @@
  *
  * @todo document (e.g. one-sentence top-level class description).
  */
-class LinksUpdate extends SqlDataUpdate {
+class LinksUpdate extends SqlDataUpdate implements EnqueueableDataUpdate {
 	// @todo make members protected, but make sure extensions don't break
 
 	/** @var int Page ID of the article linked from */
@@ -55,12 +55,18 @@ class LinksUpdate extends SqlDataUpdate {
 	/** @var array Map of language codes to titles */
 	public $mInterlangs;
 
+	/** @var array 2-D map of (prefix => DBK => 1) */
+	public $mInterwikis;
+
 	/** @var array Map of arbitrary name to value */
 	public $mProperties;
 
 	/** @var bool Whether to queue jobs for recursive updates */
 	public $mRecursive;
 
+	/** @var Revision Revision for which this update has been triggered */
+	private $mRevision;
+
 	/**
 	 * @var null|array Added links if calculated.
 	 */
@@ -71,6 +77,11 @@ class LinksUpdate extends SqlDataUpdate {
 	 */
 	private $linkDeletions = null;
 
+	/**
+	 * @var User|null
+	 */
+	private $user;
+
 	/**
 	 * Constructor
 	 *
@@ -79,25 +90,16 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @param bool $recursive Queue jobs for recursive updates?
 	 * @throws MWException
 	 */
-	function __construct( $title, $parserOutput, $recursive = true ) {
+	function __construct( Title $title, ParserOutput $parserOutput, $recursive = true ) {
 		parent::__construct( false ); // no implicit transaction
 
-		if ( !( $title instanceof Title ) ) {
-			throw new MWException( "The calling convention to LinksUpdate::LinksUpdate() has changed. " .
-				"Please see Article::editUpdates() for an invocation example.\n" );
-		}
-
-		if ( !( $parserOutput instanceof ParserOutput ) ) {
-			throw new MWException( "The calling convention to LinksUpdate::__construct() has changed. " .
-				"Please see WikiPage::doEditUpdates() for an invocation example.\n" );
-		}
-
 		$this->mTitle = $title;
-		$this->mId = $title->getArticleID();
+		$this->mId = $title->getArticleID( Title::GAID_FOR_UPDATE );
 
 		if ( !$this->mId ) {
-			throw new MWException( "The Title object did not provide an article " .
-				"ID. Perhaps the page doesn't exist?" );
+			throw new InvalidArgumentException(
+				"The Title object yields no ID. Perhaps the page doesn't exist?"
+			);
 		}
 
 		$this->mParserOutput = $parserOutput;
@@ -115,7 +117,7 @@ class LinksUpdate extends SqlDataUpdate {
 		# the way back to the skin, so either a skin API break would be required, or an
 		# inefficient back-conversion.
 		$ill = $parserOutput->getLanguageLinks();
-		$this->mInterlangs = array();
+		$this->mInterlangs = [];
 		foreach ( $ill as $link ) {
 			list( $key, $title ) = explode( ':', $link, 2 );
 			$this->mInterlangs[$key] = $title;
@@ -134,20 +136,22 @@ class LinksUpdate extends SqlDataUpdate {
 
 		$this->mRecursive = $recursive;
 
-		Hooks::run( 'LinksUpdateConstructed', array( &$this ) );
+		Hooks::run( 'LinksUpdateConstructed', [ &$this ] );
 	}
 
 	/**
 	 * Update link tables with outgoing links from an updated article
 	 */
 	public function doUpdate() {
-		Hooks::run( 'LinksUpdate', array( &$this ) );
+		Hooks::run( 'LinksUpdate', [ &$this ] );
 		$this->doIncrementalUpdate();
-		Hooks::run( 'LinksUpdateComplete', array( &$this ) );
+
+		$this->mDb->onTransactionIdle( function() {
+			Hooks::run( 'LinksUpdateComplete', [ &$this ] );
+		} );
 	}
 
 	protected function doIncrementalUpdate() {
-
 		# Page links
 		$existing = $this->getExistingLinks();
 		$this->linkDeletions = $this->getLinkDeletions( $existing );
@@ -241,9 +245,9 @@ class LinksUpdate extends SqlDataUpdate {
 		// should be implicitly protected as soon as possible, if applicable.
 		// These jobs duplicate a subset of the above ones, but can run sooner.
 		// Which ever runs first generally no-ops the other one.
-		$jobs = array();
+		$jobs = [];
 		foreach ( $bc->getCascadeProtectedLinks() as $title ) {
-			$jobs[] = new RefreshLinksJob( $title, array( 'prioritize' => true ) );
+			$jobs[] = RefreshLinksJob::newPrioritized( $title, [] );
 		}
 		JobQueueGroup::singleton()->push( $jobs );
 	}
@@ -258,10 +262,10 @@ class LinksUpdate extends SqlDataUpdate {
 		if ( $title->getBacklinkCache()->hasLinks( $table ) ) {
 			$job = new RefreshLinksJob(
 				$title,
-				array(
+				[
 					'table' => $table,
 					'recursive' => true,
-				) + Job::newRootJobParams( // "overall" refresh links job info
+				] + Job::newRootJobParams( // "overall" refresh links job info
 					"refreshlinks:{$table}:{$title->getPrefixedText()}"
 				)
 			);
@@ -309,7 +313,7 @@ class LinksUpdate extends SqlDataUpdate {
 		} else {
 			$fromField = "{$prefix}_from";
 		}
-		$where = array( $fromField => $this->mId );
+		$where = [ $fromField => $this->mId ];
 		if ( $table == 'pagelinks' || $table == 'templatelinks' || $table == 'iwlinks' ) {
 			if ( $table == 'iwlinks' ) {
 				$baseKey = 'iwl_prefix';
@@ -341,7 +345,7 @@ class LinksUpdate extends SqlDataUpdate {
 		}
 		if ( count( $insertions ) ) {
 			$this->mDb->insert( $table, $insertions, __METHOD__, 'IGNORE' );
-			Hooks::run( 'LinksUpdateAfterInsert', array( $this, $table, $insertions ) );
+			Hooks::run( 'LinksUpdateAfterInsert', [ $this, $table, $insertions ] );
 		}
 	}
 
@@ -351,19 +355,19 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @param array $existing
 	 * @return array
 	 */
-	private function getLinkInsertions( $existing = array() ) {
-		$arr = array();
+	private function getLinkInsertions( $existing = [] ) {
+		$arr = [];
 		foreach ( $this->mLinks as $ns => $dbkeys ) {
 			$diffs = isset( $existing[$ns] )
 				? array_diff_key( $dbkeys, $existing[$ns] )
 				: $dbkeys;
 			foreach ( $diffs as $dbk => $id ) {
-				$arr[] = array(
+				$arr[] = [
 					'pl_from' => $this->mId,
 					'pl_from_namespace' => $this->mTitle->getNamespace(),
 					'pl_namespace' => $ns,
 					'pl_title' => $dbk
-				);
+				];
 			}
 		}
 
@@ -375,17 +379,17 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @param array $existing
 	 * @return array
 	 */
-	private function getTemplateInsertions( $existing = array() ) {
-		$arr = array();
+	private function getTemplateInsertions( $existing = [] ) {
+		$arr = [];
 		foreach ( $this->mTemplates as $ns => $dbkeys ) {
 			$diffs = isset( $existing[$ns] ) ? array_diff_key( $dbkeys, $existing[$ns] ) : $dbkeys;
 			foreach ( $diffs as $dbk => $id ) {
-				$arr[] = array(
+				$arr[] = [
 					'tl_from' => $this->mId,
 					'tl_from_namespace' => $this->mTitle->getNamespace(),
 					'tl_namespace' => $ns,
 					'tl_title' => $dbk
-				);
+				];
 			}
 		}
 
@@ -398,15 +402,15 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @param array $existing
 	 * @return array
 	 */
-	private function getImageInsertions( $existing = array() ) {
-		$arr = array();
+	private function getImageInsertions( $existing = [] ) {
+		$arr = [];
 		$diffs = array_diff_key( $this->mImages, $existing );
 		foreach ( $diffs as $iname => $dummy ) {
-			$arr[] = array(
+			$arr[] = [
 				'il_from' => $this->mId,
 				'il_from_namespace' => $this->mTitle->getNamespace(),
 				'il_to' => $iname
-			);
+			];
 		}
 
 		return $arr;
@@ -417,17 +421,17 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @param array $existing
 	 * @return array
 	 */
-	private function getExternalInsertions( $existing = array() ) {
-		$arr = array();
+	private function getExternalInsertions( $existing = [] ) {
+		$arr = [];
 		$diffs = array_diff_key( $this->mExternals, $existing );
 		foreach ( $diffs as $url => $dummy ) {
 			foreach ( wfMakeUrlIndexes( $url ) as $index ) {
-				$arr[] = array(
+				$arr[] = [
 					'el_id' => $this->mDb->nextSequenceValue( 'externallinks_el_id_seq' ),
 					'el_from' => $this->mId,
 					'el_to' => $url,
 					'el_index' => $index,
-				);
+				];
 			}
 		}
 
@@ -442,10 +446,10 @@ class LinksUpdate extends SqlDataUpdate {
 	 *
 	 * @return array
 	 */
-	private function getCategoryInsertions( $existing = array() ) {
+	private function getCategoryInsertions( $existing = [] ) {
 		global $wgContLang, $wgCategoryCollation;
 		$diffs = array_diff_assoc( $this->mCategories, $existing );
-		$arr = array();
+		$arr = [];
 		foreach ( $diffs as $name => $prefix ) {
 			$nt = Title::makeTitleSafe( NS_CATEGORY, $name );
 			$wgContLang->findVariantLink( $name, $nt, true );
@@ -465,7 +469,7 @@ class LinksUpdate extends SqlDataUpdate {
 			$sortkey = Collation::singleton()->getSortKey(
 				$this->mTitle->getCategorySortkey( $prefix ) );
 
-			$arr[] = array(
+			$arr[] = [
 				'cl_from' => $this->mId,
 				'cl_to' => $name,
 				'cl_sortkey' => $sortkey,
@@ -473,7 +477,7 @@ class LinksUpdate extends SqlDataUpdate {
 				'cl_sortkey_prefix' => $prefix,
 				'cl_collation' => $wgCategoryCollation,
 				'cl_type' => $type,
-			);
+			];
 		}
 
 		return $arr;
@@ -486,15 +490,15 @@ class LinksUpdate extends SqlDataUpdate {
 	 *
 	 * @return array
 	 */
-	private function getInterlangInsertions( $existing = array() ) {
+	private function getInterlangInsertions( $existing = [] ) {
 		$diffs = array_diff_assoc( $this->mInterlangs, $existing );
-		$arr = array();
+		$arr = [];
 		foreach ( $diffs as $lang => $title ) {
-			$arr[] = array(
+			$arr[] = [
 				'll_from' => $this->mId,
 				'll_lang' => $lang,
 				'll_title' => $title
-			);
+			];
 		}
 
 		return $arr;
@@ -505,10 +509,10 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @param array $existing
 	 * @return array
 	 */
-	function getPropertyInsertions( $existing = array() ) {
+	function getPropertyInsertions( $existing = [] ) {
 		$diffs = array_diff_assoc( $this->mProperties, $existing );
 
-		$arr = array();
+		$arr = [];
 		foreach ( array_keys( $diffs ) as $name ) {
 			$arr[] = $this->getPagePropRowData( $name );
 		}
@@ -537,11 +541,11 @@ class LinksUpdate extends SqlDataUpdate {
 
 		$value = $this->mProperties[$prop];
 
-		$row = array(
+		$row = [
 			'pp_page' => $this->mId,
 			'pp_propname' => $prop,
 			'pp_value' => $value,
-		);
+		];
 
 		if ( $wgPagePropsHaveSortkey ) {
 			$row['pp_sortkey'] = $this->getPropertySortKeyValue( $value );
@@ -576,19 +580,19 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @param array $existing
 	 * @return array
 	 */
-	private function getInterwikiInsertions( $existing = array() ) {
-		$arr = array();
+	private function getInterwikiInsertions( $existing = [] ) {
+		$arr = [];
 		foreach ( $this->mInterwikis as $prefix => $dbkeys ) {
 			$diffs = isset( $existing[$prefix] )
 				? array_diff_key( $dbkeys, $existing[$prefix] )
 				: $dbkeys;
 
 			foreach ( $diffs as $dbk => $id ) {
-				$arr[] = array(
+				$arr[] = [
 					'iwl_from' => $this->mId,
 					'iwl_prefix' => $prefix,
 					'iwl_title' => $dbk
-				);
+				];
 			}
 		}
 
@@ -602,7 +606,7 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @return array
 	 */
 	private function getLinkDeletions( $existing ) {
-		$del = array();
+		$del = [];
 		foreach ( $existing as $ns => $dbkeys ) {
 			if ( isset( $this->mLinks[$ns] ) ) {
 				$del[$ns] = array_diff_key( $existing[$ns], $this->mLinks[$ns] );
@@ -621,7 +625,7 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @return array
 	 */
 	private function getTemplateDeletions( $existing ) {
-		$del = array();
+		$del = [];
 		foreach ( $existing as $ns => $dbkeys ) {
 			if ( isset( $this->mTemplates[$ns] ) ) {
 				$del[$ns] = array_diff_key( $existing[$ns], $this->mTemplates[$ns] );
@@ -689,7 +693,7 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @return array
 	 */
 	private function getInterwikiDeletions( $existing ) {
-		$del = array();
+		$del = [];
 		foreach ( $existing as $prefix => $dbkeys ) {
 			if ( isset( $this->mInterwikis[$prefix] ) ) {
 				$del[$prefix] = array_diff_key( $existing[$prefix], $this->mInterwikis[$prefix] );
@@ -707,12 +711,12 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @return array
 	 */
 	private function getExistingLinks() {
-		$res = $this->mDb->select( 'pagelinks', array( 'pl_namespace', 'pl_title' ),
-			array( 'pl_from' => $this->mId ), __METHOD__, $this->mOptions );
-		$arr = array();
+		$res = $this->mDb->select( 'pagelinks', [ 'pl_namespace', 'pl_title' ],
+			[ 'pl_from' => $this->mId ], __METHOD__, $this->mOptions );
+		$arr = [];
 		foreach ( $res as $row ) {
 			if ( !isset( $arr[$row->pl_namespace] ) ) {
-				$arr[$row->pl_namespace] = array();
+				$arr[$row->pl_namespace] = [];
 			}
 			$arr[$row->pl_namespace][$row->pl_title] = 1;
 		}
@@ -726,12 +730,12 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @return array
 	 */
 	private function getExistingTemplates() {
-		$res = $this->mDb->select( 'templatelinks', array( 'tl_namespace', 'tl_title' ),
-			array( 'tl_from' => $this->mId ), __METHOD__, $this->mOptions );
-		$arr = array();
+		$res = $this->mDb->select( 'templatelinks', [ 'tl_namespace', 'tl_title' ],
+			[ 'tl_from' => $this->mId ], __METHOD__, $this->mOptions );
+		$arr = [];
 		foreach ( $res as $row ) {
 			if ( !isset( $arr[$row->tl_namespace] ) ) {
-				$arr[$row->tl_namespace] = array();
+				$arr[$row->tl_namespace] = [];
 			}
 			$arr[$row->tl_namespace][$row->tl_title] = 1;
 		}
@@ -745,9 +749,9 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @return array
 	 */
 	private function getExistingImages() {
-		$res = $this->mDb->select( 'imagelinks', array( 'il_to' ),
-			array( 'il_from' => $this->mId ), __METHOD__, $this->mOptions );
-		$arr = array();
+		$res = $this->mDb->select( 'imagelinks', [ 'il_to' ],
+			[ 'il_from' => $this->mId ], __METHOD__, $this->mOptions );
+		$arr = [];
 		foreach ( $res as $row ) {
 			$arr[$row->il_to] = 1;
 		}
@@ -761,9 +765,9 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @return array
 	 */
 	private function getExistingExternals() {
-		$res = $this->mDb->select( 'externallinks', array( 'el_to' ),
-			array( 'el_from' => $this->mId ), __METHOD__, $this->mOptions );
-		$arr = array();
+		$res = $this->mDb->select( 'externallinks', [ 'el_to' ],
+			[ 'el_from' => $this->mId ], __METHOD__, $this->mOptions );
+		$arr = [];
 		foreach ( $res as $row ) {
 			$arr[$row->el_to] = 1;
 		}
@@ -777,9 +781,9 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @return array
 	 */
 	private function getExistingCategories() {
-		$res = $this->mDb->select( 'categorylinks', array( 'cl_to', 'cl_sortkey_prefix' ),
-			array( 'cl_from' => $this->mId ), __METHOD__, $this->mOptions );
-		$arr = array();
+		$res = $this->mDb->select( 'categorylinks', [ 'cl_to', 'cl_sortkey_prefix' ],
+			[ 'cl_from' => $this->mId ], __METHOD__, $this->mOptions );
+		$arr = [];
 		foreach ( $res as $row ) {
 			$arr[$row->cl_to] = $row->cl_sortkey_prefix;
 		}
@@ -794,9 +798,9 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @return array
 	 */
 	private function getExistingInterlangs() {
-		$res = $this->mDb->select( 'langlinks', array( 'll_lang', 'll_title' ),
-			array( 'll_from' => $this->mId ), __METHOD__, $this->mOptions );
-		$arr = array();
+		$res = $this->mDb->select( 'langlinks', [ 'll_lang', 'll_title' ],
+			[ 'll_from' => $this->mId ], __METHOD__, $this->mOptions );
+		$arr = [];
 		foreach ( $res as $row ) {
 			$arr[$row->ll_lang] = $row->ll_title;
 		}
@@ -809,12 +813,12 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @return array (prefix => array(dbkey => 1))
 	 */
 	protected function getExistingInterwikis() {
-		$res = $this->mDb->select( 'iwlinks', array( 'iwl_prefix', 'iwl_title' ),
-			array( 'iwl_from' => $this->mId ), __METHOD__, $this->mOptions );
-		$arr = array();
+		$res = $this->mDb->select( 'iwlinks', [ 'iwl_prefix', 'iwl_title' ],
+			[ 'iwl_from' => $this->mId ], __METHOD__, $this->mOptions );
+		$arr = [];
 		foreach ( $res as $row ) {
 			if ( !isset( $arr[$row->iwl_prefix] ) ) {
-				$arr[$row->iwl_prefix] = array();
+				$arr[$row->iwl_prefix] = [];
 			}
 			$arr[$row->iwl_prefix][$row->iwl_title] = 1;
 		}
@@ -828,9 +832,9 @@ class LinksUpdate extends SqlDataUpdate {
 	 * @return array Array of property names and values
 	 */
 	private function getExistingProperties() {
-		$res = $this->mDb->select( 'page_props', array( 'pp_propname', 'pp_value' ),
-			array( 'pp_page' => $this->mId ), __METHOD__, $this->mOptions );
-		$arr = array();
+		$res = $this->mDb->select( 'page_props', [ 'pp_propname', 'pp_value' ],
+			[ 'pp_page' => $this->mId ], __METHOD__, $this->mOptions );
+		$arr = [];
 		foreach ( $res as $row ) {
 			$arr[$row->pp_propname] = $row->pp_value;
 		}
@@ -863,6 +867,35 @@ class LinksUpdate extends SqlDataUpdate {
 		return $this->mImages;
 	}
 
+	/**
+	 * Set the revision corresponding to this LinksUpdate
+	 *
+	 * @since 1.27
+	 *
+	 * @param Revision $revision
+	 */
+	public function setRevision( Revision $revision ) {
+		$this->mRevision = $revision;
+	}
+
+	/**
+	 * Set the User who triggered this LinksUpdate
+	 *
+	 * @since 1.27
+	 * @param User $user
+	 */
+	public function setTriggeringUser( User $user ) {
+		$this->user = $user;
+	}
+
+	/**
+	 * @since 1.27
+	 * @return null|User
+	 */
+	public function getTriggeringUser() {
+		return $this->user;
+	}
+
 	/**
 	 * Invalidate any necessary link lists related to page property changes
 	 * @param array $changed
@@ -874,11 +907,10 @@ class LinksUpdate extends SqlDataUpdate {
 			if ( isset( $wgPagePropLinkInvalidations[$name] ) ) {
 				$inv = $wgPagePropLinkInvalidations[$name];
 				if ( !is_array( $inv ) ) {
-					$inv = array( $inv );
+					$inv = [ $inv ];
 				}
 				foreach ( $inv as $table ) {
-					$update = new HTMLCacheUpdate( $this->mTitle, $table );
-					$update->doUpdate();
+					DeferredUpdates::addUpdate( new HTMLCacheUpdate( $this->mTitle, $table ) );
 				}
 			}
 		}
@@ -893,7 +925,7 @@ class LinksUpdate extends SqlDataUpdate {
 		if ( $this->linkInsertions === null ) {
 			return null;
 		}
-		$result = array();
+		$result = [];
 		foreach ( $this->linkInsertions as $insertion ) {
 			$result[] = Title::makeTitle( $insertion['pl_namespace'], $insertion['pl_title'] );
 		}
@@ -910,7 +942,7 @@ class LinksUpdate extends SqlDataUpdate {
 		if ( $this->linkDeletions === null ) {
 			return null;
 		}
-		$result = array();
+		$result = [];
 		foreach ( $this->linkDeletions as $ns => $titles ) {
 			foreach ( $titles as $title => $unused ) {
 				$result[] = Title::makeTitle( $ns, $title );
@@ -928,10 +960,43 @@ class LinksUpdate extends SqlDataUpdate {
 			// The link updates made here only reflect the freshness of the parser output
 			$timestamp = $this->mParserOutput->getCacheTime();
 			$this->mDb->update( 'page',
-				array( 'page_links_updated' => $this->mDb->timestamp( $timestamp ) ),
-				array( 'page_id' => $this->mId ),
+				[ 'page_links_updated' => $this->mDb->timestamp( $timestamp ) ],
+				[ 'page_id' => $this->mId ],
 				__METHOD__
 			);
 		}
 	}
+
+	public function getAsJobSpecification() {
+		if ( $this->user ) {
+			$userInfo = [
+				'userId' => $this->user->getId(),
+				'userName' => $this->user->getName(),
+			];
+		} else {
+			$userInfo = false;
+		}
+
+		if ( $this->mRevision ) {
+			$triggeringRevisionId = $this->mRevision->getId();
+		} else {
+			$triggeringRevisionId = false;
+		}
+
+		return [
+			'wiki' => $this->mDb->getWikiID(),
+			'job'  => new JobSpecification(
+				'refreshLinksPrioritized',
+				[
+					// Reuse the parser cache if it was saved
+					'rootJobTimestamp' => $this->mParserOutput->getCacheTime(),
+					'useRecursiveLinksUpdate' => $this->mRecursive,
+					'triggeringUser' => $userInfo,
+					'triggeringRevisionId' => $triggeringRevisionId,
+				],
+				[ 'removeDuplicates' => true ],
+				$this->getTitle()
+			)
+		];
+	}
 }
