@@ -180,16 +180,16 @@ class DifferenceEngine extends ContextSource {
 		if ( $this->getUser()->isAllowed( 'deletedhistory' ) ) {
 			$dbr = wfGetDB( DB_SLAVE );
 			$row = $dbr->selectRow( 'archive', '*',
-				array( 'ar_rev_id' => $id ),
+				[ 'ar_rev_id' => $id ],
 				__METHOD__ );
 			if ( $row ) {
 				$rev = Revision::newFromArchiveRow( $row );
 				$title = Title::makeTitleSafe( $row->ar_namespace, $row->ar_title );
 
-				return SpecialPage::getTitleFor( 'Undelete' )->getFullURL( array(
+				return SpecialPage::getTitleFor( 'Undelete' )->getFullURL( [
 					'target' => $title->getPrefixedText(),
 					'timestamp' => $rev->getTimestamp()
-				) );
+				] );
 			}
 		}
 
@@ -215,7 +215,7 @@ class DifferenceEngine extends ContextSource {
 	private function showMissingRevision() {
 		$out = $this->getOutput();
 
-		$missing = array();
+		$missing = [];
 		if ( $this->mOldRev === null ||
 			( $this->mOldRev && $this->mOldContent === null )
 		) {
@@ -232,7 +232,7 @@ class DifferenceEngine extends ContextSource {
 			->params( $this->getLanguage()->listToText( $missing ) )
 			->numParams( count( $missing ) )
 			->parseAsBlock();
-		$out->addHtml( $msg );
+		$out->addHTML( $msg );
 	}
 
 	public function showDiffPage( $diffOnly = false ) {
@@ -260,7 +260,7 @@ class DifferenceEngine extends ContextSource {
 
 		$rollback = '';
 
-		$query = array();
+		$query = [];
 		# Carry over 'diffonly' param via navigation links
 		if ( $diffOnly != $user->getBoolOption( 'diffonly' ) ) {
 			$query['diffonly'] = $diffOnly;
@@ -274,7 +274,7 @@ class DifferenceEngine extends ContextSource {
 		$deleted = $suppressed = false;
 		$allowed = $this->mNewRev->userCan( Revision::DELETED_TEXT, $user );
 
-		$revisionTools = array();
+		$revisionTools = [];
 
 		# mOldRev is false if the difference engine is called with a "vague" query for
 		# a diff between a version V and its previous version V' AND the version V
@@ -284,7 +284,7 @@ class DifferenceEngine extends ContextSource {
 			$samePage = true;
 			$oldHeader = '';
 		} else {
-			Hooks::run( 'DiffViewHeader', array( $this, $this->mOldRev, $this->mNewRev ) );
+			Hooks::run( 'DiffViewHeader', [ $this, $this->mOldRev, $this->mNewRev ] );
 
 			if ( $this->mNewPage->equals( $this->mOldPage ) ) {
 				$out->setPageTitle( $this->msg( 'difference-title', $this->mNewPage->getPrefixedText() ) );
@@ -308,14 +308,14 @@ class DifferenceEngine extends ContextSource {
 				if ( !$this->mOldRev->isDeleted( Revision::DELETED_TEXT ) &&
 					!$this->mNewRev->isDeleted( Revision::DELETED_TEXT )
 				) {
-					$undoLink = Html::element( 'a', array(
-							'href' => $this->mNewPage->getLocalURL( array(
+					$undoLink = Html::element( 'a', [
+							'href' => $this->mNewPage->getLocalURL( [
 								'action' => 'edit',
 								'undoafter' => $this->mOldid,
 								'undo' => $this->mNewid
-							) ),
+							] ),
 							'title' => Linker::titleAttrib( 'undo' ),
-						),
+						],
 						$this->msg( 'editundo' )->text()
 					);
 					$revisionTools['mw-diff-undo'] = $undoLink;
@@ -327,8 +327,8 @@ class DifferenceEngine extends ContextSource {
 				$prevlink = Linker::linkKnown(
 					$this->mOldPage,
 					$this->msg( 'previousdiff' )->escaped(),
-					array( 'id' => 'differences-prevlink' ),
-					array( 'diff' => 'prev', 'oldid' => $this->mOldid ) + $query
+					[ 'id' => 'differences-prevlink' ],
+					[ 'diff' => 'prev', 'oldid' => $this->mOldid ] + $query
 				);
 			} else {
 				$prevlink = '&#160;';
@@ -342,7 +342,7 @@ class DifferenceEngine extends ContextSource {
 
 			$ldel = $this->revisionDeleteLink( $this->mOldRev );
 			$oldRevisionHeader = $this->getRevisionHeader( $this->mOldRev, 'complete' );
-			$oldChangeTags = ChangeTags::formatSummaryRow( $this->mOldTags, 'diff' );
+			$oldChangeTags = ChangeTags::formatSummaryRow( $this->mOldTags, 'diff', $this->getContext() );
 
 			$oldHeader = '<div id="mw-diff-otitle1"><strong>' . $oldRevisionHeader . '</strong></div>' .
 				'<div id="mw-diff-otitle2">' .
@@ -371,8 +371,8 @@ class DifferenceEngine extends ContextSource {
 			$nextlink = Linker::linkKnown(
 				$this->mNewPage,
 				$this->msg( 'nextdiff' )->escaped(),
-				array( 'id' => 'differences-nextlink' ),
-				array( 'diff' => 'next', 'oldid' => $this->mNewid ) + $query
+				[ 'id' => 'differences-nextlink' ],
+				[ 'diff' => 'next', 'oldid' => $this->mNewid ] + $query
 			);
 		} else {
 			$nextlink = '&#160;';
@@ -388,21 +388,22 @@ class DifferenceEngine extends ContextSource {
 		$rdel = $this->revisionDeleteLink( $this->mNewRev );
 
 		# Allow extensions to define their own revision tools
-		Hooks::run( 'DiffRevisionTools', array( $this->mNewRev, &$revisionTools, $this->mOldRev ) );
-		$formattedRevisionTools = array();
+		Hooks::run( 'DiffRevisionTools',
+			[ $this->mNewRev, &$revisionTools, $this->mOldRev, $user ] );
+		$formattedRevisionTools = [];
 		// Put each one in parentheses (poor man's button)
 		foreach ( $revisionTools as $key => $tool ) {
 			$toolClass = is_string( $key ) ? $key : 'mw-diff-tool';
 			$element = Html::rawElement(
 				'span',
-				array( 'class' => $toolClass ),
+				[ 'class' => $toolClass ],
 				$this->msg( 'parentheses' )->rawParams( $tool )->escaped()
 			);
 			$formattedRevisionTools[] = $element;
 		}
 		$newRevisionHeader = $this->getRevisionHeader( $this->mNewRev, 'complete' ) .
 			' ' . implode( ' ', $formattedRevisionTools );
-		$newChangeTags = ChangeTags::formatSummaryRow( $this->mNewTags, 'diff' );
+		$newChangeTags = ChangeTags::formatSummaryRow( $this->mNewTags, 'diff', $this->getContext() );
 
 		$newHeader = '<div id="mw-diff-ntitle1"><strong>' . $newRevisionHeader . '</strong></div>' .
 			'<div id="mw-diff-ntitle2">' . Linker::revUserTools( $this->mNewRev, !$this->unhide ) .
@@ -429,15 +430,15 @@ class DifferenceEngine extends ContextSource {
 				$msg = $suppressed ? 'rev-suppressed-no-diff' : 'rev-deleted-no-diff';
 				# Give explanation for why revision is not visible
 				$out->wrapWikiMsg( "<div id='mw-$msg' class='mw-warning plainlinks'>\n$1\n</div>\n",
-					array( $msg ) );
+					[ $msg ] );
 			} else {
 				# Give explanation and add a link to view the diff...
-				$query = $this->getRequest()->appendQueryValue( 'unhide', '1', true );
+				$query = $this->getRequest()->appendQueryValue( 'unhide', '1' );
 				$link = $this->getTitle()->getFullURL( $query );
 				$msg = $suppressed ? 'rev-suppressed-unhide-diff' : 'rev-deleted-unhide-diff';
 				$out->wrapWikiMsg(
 					"<div id='mw-$msg' class='mw-warning plainlinks'>\n$1\n</div>\n",
-					array( $msg, $link )
+					[ $msg, $link ]
 				);
 			}
 		# Otherwise, output a regular diff...
@@ -458,75 +459,94 @@ class DifferenceEngine extends ContextSource {
 	}
 
 	/**
-	 * Get a link to mark the change as patrolled, or '' if there's either no
-	 * revision to patrol or the user is not allowed to to it.
+	 * Build a link to mark a change as patrolled.
+	 *
+	 * Returns empty string if there's either no revision to patrol or the user is not allowed to.
 	 * Side effect: When the patrol link is build, this method will call
 	 * OutputPage::preventClickjacking() and load mediawiki.page.patrol.ajax.
 	 *
-	 * @return string
+	 * @return string HTML or empty string
 	 */
 	protected function markPatrolledLink() {
-		global $wgUseRCPatrol, $wgEnableAPI, $wgEnableWriteAPI;
-		$user = $this->getUser();
-
 		if ( $this->mMarkPatrolledLink === null ) {
-			// Prepare a change patrol link, if applicable
-			if (
-				// Is patrolling enabled and the user allowed to?
-				$wgUseRCPatrol && $this->mNewPage->quickUserCan( 'patrol', $user ) &&
-				// Only do this if the revision isn't more than 6 hours older
-				// than the Max RC age (6h because the RC might not be cleaned out regularly)
-				RecentChange::isInRCLifespan( $this->mNewRev->getTimestamp(), 21600 )
-			) {
-				// Look for an unpatrolled change corresponding to this diff
-
-				$db = wfGetDB( DB_SLAVE );
-				$change = RecentChange::newFromConds(
-					array(
-						'rc_timestamp' => $db->timestamp( $this->mNewRev->getTimestamp() ),
-						'rc_this_oldid' => $this->mNewid,
-						'rc_patrolled' => 0
-					),
-					__METHOD__,
-					array( 'USE INDEX' => 'rc_timestamp' )
-				);
-
-				if ( $change && !$change->getPerformer()->equals( $user ) ) {
-					$rcid = $change->getAttribute( 'rc_id' );
-				} else {
-					// None found or the page has been created by the current user.
-					// If the user could patrol this it already would be patrolled
-					$rcid = 0;
-				}
-				// Build the link
-				if ( $rcid ) {
-					$this->getOutput()->preventClickjacking();
-					if ( $wgEnableAPI && $wgEnableWriteAPI
-						&& $user->isAllowed( 'writeapi' )
-					) {
-						$this->getOutput()->addModules( 'mediawiki.page.patrol.ajax' );
-					}
-
-					$token = $user->getEditToken( $rcid );
-					$this->mMarkPatrolledLink = ' <span class="patrollink">[' . Linker::linkKnown(
+			$linkInfo = $this->getMarkPatrolledLinkInfo();
+			// If false, there is no patrol link needed/allowed
+			if ( !$linkInfo ) {
+				$this->mMarkPatrolledLink = '';
+			} else {
+				$this->mMarkPatrolledLink = ' <span class="patrollink" data-mw="interface">[' .
+					Linker::linkKnown(
 						$this->mNewPage,
 						$this->msg( 'markaspatrolleddiff' )->escaped(),
-						array( 'class' => 'mw-patrollink' ),
-						array(
+						[],
+						[
 							'action' => 'markpatrolled',
-							'rcid' => $rcid,
-							'token' => $token,
-						)
+							'rcid' => $linkInfo['rcid'],
+							'token' => $linkInfo['token'],
+						]
 					) . ']</span>';
-				} else {
-					$this->mMarkPatrolledLink = '';
-				}
+			}
+		}
+		return $this->mMarkPatrolledLink;
+	}
+
+	/**
+	 * Returns an array of meta data needed to build a "mark as patrolled" link and
+	 * adds the mediawiki.page.patrol.ajax to the output.
+	 *
+	 * @return array|false An array of meta data for a patrol link (rcid & token)
+	 *  or false if no link is needed
+	 */
+	protected function getMarkPatrolledLinkInfo() {
+		global $wgUseRCPatrol, $wgEnableAPI, $wgEnableWriteAPI;
+
+		$user = $this->getUser();
+
+		// Prepare a change patrol link, if applicable
+		if (
+			// Is patrolling enabled and the user allowed to?
+			$wgUseRCPatrol && $this->mNewPage->quickUserCan( 'patrol', $user ) &&
+			// Only do this if the revision isn't more than 6 hours older
+			// than the Max RC age (6h because the RC might not be cleaned out regularly)
+			RecentChange::isInRCLifespan( $this->mNewRev->getTimestamp(), 21600 )
+		) {
+			// Look for an unpatrolled change corresponding to this diff
+			$db = wfGetDB( DB_SLAVE );
+			$change = RecentChange::newFromConds(
+				[
+					'rc_timestamp' => $db->timestamp( $this->mNewRev->getTimestamp() ),
+					'rc_this_oldid' => $this->mNewid,
+					'rc_patrolled' => 0
+				],
+				__METHOD__
+			);
+
+			if ( $change && !$change->getPerformer()->equals( $user ) ) {
+				$rcid = $change->getAttribute( 'rc_id' );
 			} else {
-				$this->mMarkPatrolledLink = '';
+				// None found or the page has been created by the current user.
+				// If the user could patrol this it already would be patrolled
+				$rcid = 0;
+			}
+			// Build the link
+			if ( $rcid ) {
+				$this->getOutput()->preventClickjacking();
+				if ( $wgEnableAPI && $wgEnableWriteAPI
+					&& $user->isAllowed( 'writeapi' )
+				) {
+					$this->getOutput()->addModules( 'mediawiki.page.patrol.ajax' );
+				}
+
+				$token = $user->getEditToken( $rcid );
+				return [
+					'rcid' => $rcid,
+					'token' => $token,
+				];
 			}
 		}
 
-		return $this->mMarkPatrolledLink;
+		// No mark as patrolled link applicable
+		return false;
 	}
 
 	/**
@@ -554,7 +574,7 @@ class DifferenceEngine extends ContextSource {
 		<h2 class='diff-currentversion-title'>{$revHeader}</h2>\n" );
 		# Page content may be handled by a hooked call instead...
 		# @codingStandardsIgnoreStart Ignoring long lines.
-		if ( Hooks::run( 'ArticleContentOnDiff', array( $this, $out ) ) ) {
+		if ( Hooks::run( 'ArticleContentOnDiff', [ $this, $out ] ) ) {
 			$this->loadNewText();
 			$out->setRevisionId( $this->mNewid );
 			$out->setRevisionTimestamp( $this->mNewRev->getTimestamp() );
@@ -565,7 +585,7 @@ class DifferenceEngine extends ContextSource {
 				// This needs to be synchronised with Article::showCssOrJsPage(), which sucks
 				// Give hooks a chance to customise the output
 				// @todo standardize this crap into one function
-				if ( ContentHandler::runLegacyHooks( 'ShowRawCssJs', array( $this->mNewContent, $this->mNewPage, $out ) ) ) {
+				if ( ContentHandler::runLegacyHooks( 'ShowRawCssJs', [ $this->mNewContent, $this->mNewPage, $out ] ) ) {
 					// NOTE: deprecated hook, B/C only
 					// use the content object's own rendering
 					$cnt = $this->mNewRev->getContent();
@@ -574,9 +594,9 @@ class DifferenceEngine extends ContextSource {
 						$out->addParserOutputContent( $po );
 					}
 				}
-			} elseif ( !Hooks::run( 'ArticleContentViewCustom', array( $this->mNewContent, $this->mNewPage, $out ) ) ) {
+			} elseif ( !Hooks::run( 'ArticleContentViewCustom', [ $this->mNewContent, $this->mNewPage, $out ] ) ) {
 				// Handled by extension
-			} elseif ( !ContentHandler::runLegacyHooks( 'ArticleViewCustom', array( $this->mNewContent, $this->mNewPage, $out ) ) ) {
+			} elseif ( !ContentHandler::runLegacyHooks( 'ArticleViewCustom', [ $this->mNewContent, $this->mNewPage, $out ] ) ) {
 				// NOTE: deprecated hook, B/C only
 				// Handled by extension
 			} else {
@@ -681,7 +701,6 @@ class DifferenceEngine extends ContextSource {
 	 * @return mixed (string/false)
 	 */
 	public function getDiffBody() {
-		global $wgMemc;
 		$this->mCacheHit = true;
 		// Check if the diff should be hidden from this user
 		if ( !$this->loadRevisionData() ) {
@@ -697,18 +716,19 @@ class DifferenceEngine extends ContextSource {
 		}
 		// Short-circuit
 		if ( $this->mOldRev === false || ( $this->mOldRev && $this->mNewRev
-			&& $this->mOldRev->getID() == $this->mNewRev->getID() )
+			&& $this->mOldRev->getId() == $this->mNewRev->getId() )
 		) {
 			return '';
 		}
 		// Cacheable?
 		$key = false;
+		$cache = ObjectCache::getMainWANInstance();
 		if ( $this->mOldid && $this->mNewid ) {
 			$key = $this->getDiffBodyCacheKey();
 
 			// Try cache
 			if ( !$this->mRefreshCache ) {
-				$difftext = $wgMemc->get( $key );
+				$difftext = $cache->get( $key );
 				if ( $difftext ) {
 					wfIncrStats( 'diff_cache.hit' );
 					$difftext = $this->localiseLineNumbers( $difftext );
@@ -728,11 +748,11 @@ class DifferenceEngine extends ContextSource {
 		$difftext = $this->generateContentDiffBody( $this->mOldContent, $this->mNewContent );
 
 		// Save to cache for 7 days
-		if ( !Hooks::run( 'AbortDiffCache', array( &$this ) ) ) {
+		if ( !Hooks::run( 'AbortDiffCache', [ &$this ] ) ) {
 			wfIncrStats( 'diff_cache.uncacheable' );
 		} elseif ( $key !== false && $difftext !== false ) {
 			wfIncrStats( 'diff_cache.miss' );
-			$wgMemc->set( $key, $difftext, 7 * 86400 );
+			$cache->set( $key, $difftext, 7 * 86400 );
 		} else {
 			wfIncrStats( 'diff_cache.uncacheable' );
 		}
@@ -823,9 +843,20 @@ class DifferenceEngine extends ContextSource {
 	 * @return bool|string
 	 */
 	public function generateTextDiffBody( $otext, $ntext ) {
-		$self = $this;
-		$diff = function() use ( $self, $otext, $ntext ) {
-			return $self->textDiff( $otext, $ntext );
+		$diff = function() use ( $otext, $ntext ) {
+			$time = microtime( true );
+
+			$result = $this->textDiff( $otext, $ntext );
+
+			$time = intval( ( microtime( true ) - $time ) * 1000 );
+			$this->getStats()->timing( 'diff_time', $time );
+			// Log requests slower than 99th percentile
+			if ( $time > 100 && $this->mOldPage && $this->mNewPage ) {
+				wfDebugLog( 'diff',
+					"$time ms diff: {$this->mOldid} -> {$this->mNewid} {$this->mNewPage}" );
+			}
+
+			return $result;
 		};
 
 		$error = function( $status ) {
@@ -836,7 +867,7 @@ class DifferenceEngine extends ContextSource {
 		if ( strlen( $otext ) + strlen( $ntext ) > 20000 ) {
 			$work = new PoolCounterWorkViaCallback( 'diff',
 				md5( $otext ) . md5( $ntext ),
-				array( 'doWork' => $diff, 'error' => $error )
+				[ 'doWork' => $diff, 'error' => $error ]
 			);
 			return $work->execute();
 		}
@@ -851,31 +882,27 @@ class DifferenceEngine extends ContextSource {
 	 * @param string $ntext New text, must be already segmented
 	 * @return bool|string
 	 */
-	public function textDiff( $otext, $ntext ) {
+	protected function textDiff( $otext, $ntext ) {
 		global $wgExternalDiffEngine, $wgContLang;
 
 		$otext = str_replace( "\r\n", "\n", $otext );
 		$ntext = str_replace( "\r\n", "\n", $ntext );
 
-		if ( $wgExternalDiffEngine == 'wikidiff' && function_exists( 'wikidiff_do_diff' ) ) {
-			# For historical reasons, external diff engine expects
-			# input text to be HTML-escaped already
-			$otext = htmlspecialchars( $wgContLang->segmentForDiff( $otext ) );
-			$ntext = htmlspecialchars( $wgContLang->segmentForDiff( $ntext ) );
-
-			return $wgContLang->unsegmentForDiff( wikidiff_do_diff( $otext, $ntext, 2 ) ) .
-			$this->debug( 'wikidiff1' );
+		if ( $wgExternalDiffEngine == 'wikidiff' || $wgExternalDiffEngine == 'wikidiff3' ) {
+			wfDeprecated( "\$wgExternalDiffEngine = '{$wgExternalDiffEngine}'", '1.27' );
+			$wgExternalDiffEngine = false;
 		}
 
-		if ( $wgExternalDiffEngine == 'wikidiff2' && function_exists( 'wikidiff2_do_diff' ) ) {
-			# Better external diff engine, the 2 may some day be dropped
-			# This one does the escaping and segmenting itself
-			$text = wikidiff2_do_diff( $otext, $ntext, 2 );
-			$text .= $this->debug( 'wikidiff2' );
+		if ( $wgExternalDiffEngine == 'wikidiff2' ) {
+			if ( function_exists( 'wikidiff2_do_diff' ) ) {
+				# Better external diff engine, the 2 may some day be dropped
+				# This one does the escaping and segmenting itself
+				$text = wikidiff2_do_diff( $otext, $ntext, 2 );
+				$text .= $this->debug( 'wikidiff2' );
 
-			return $text;
-		}
-		if ( $wgExternalDiffEngine != 'wikidiff3' && $wgExternalDiffEngine !== false ) {
+				return $text;
+			}
+		} elseif ( $wgExternalDiffEngine !== false ) {
 			# Diff via the shell
 			$tmpDir = wfTempDir();
 			$tempName1 = tempnam( $tmpDir, 'diff_' );
@@ -925,7 +952,7 @@ class DifferenceEngine extends ContextSource {
 		if ( !$this->enableDebugComment ) {
 			return '';
 		}
-		$data = array( $generator );
+		$data = [ $generator ];
 		if ( $wgShowHostnames ) {
 			$data[] = wfHostname();
 		}
@@ -946,7 +973,7 @@ class DifferenceEngine extends ContextSource {
 	public function localiseLineNumbers( $text ) {
 		return preg_replace_callback(
 			'/<!--LINE (\d+)-->/',
-			array( &$this, 'localiseLineNumbersCb' ),
+			[ &$this, 'localiseLineNumbersCb' ],
 			$text
 		);
 	}
@@ -1050,33 +1077,33 @@ class DifferenceEngine extends ContextSource {
 
 		$title = $rev->getTitle();
 
-		$header = Linker::linkKnown( $title, $header, array(),
-			array( 'oldid' => $rev->getID() ) );
+		$header = Linker::linkKnown( $title, $header, [],
+			[ 'oldid' => $rev->getId() ] );
 
 		if ( $rev->userCan( Revision::DELETED_TEXT, $user ) ) {
-			$editQuery = array( 'action' => 'edit' );
+			$editQuery = [ 'action' => 'edit' ];
 			if ( !$rev->isCurrent() ) {
-				$editQuery['oldid'] = $rev->getID();
+				$editQuery['oldid'] = $rev->getId();
 			}
 
 			$key = $title->quickUserCan( 'edit', $user ) ? 'editold' : 'viewsourceold';
 			$msg = $this->msg( $key )->escaped();
 			$editLink = $this->msg( 'parentheses' )->rawParams(
-				Linker::linkKnown( $title, $msg, array(), $editQuery ) )->escaped();
+				Linker::linkKnown( $title, $msg, [], $editQuery ) )->escaped();
 			$header .= ' ' . Html::rawElement(
 				'span',
-				array( 'class' => 'mw-diff-edit' ),
+				[ 'class' => 'mw-diff-edit' ],
 				$editLink
 			);
 			if ( $rev->isDeleted( Revision::DELETED_TEXT ) ) {
 				$header = Html::rawElement(
 					'span',
-					array( 'class' => 'history-deleted' ),
+					[ 'class' => 'history-deleted' ],
 					$header
 				);
 			}
 		} else {
-			$header = Html::rawElement( 'span', array( 'class' => 'history-deleted' ), $header );
+			$header = Html::rawElement( 'span', [ 'class' => 'history-deleted' ], $header );
 		}
 
 		return $header;
@@ -1097,8 +1124,10 @@ class DifferenceEngine extends ContextSource {
 	public function addHeader( $diff, $otitle, $ntitle, $multi = '', $notice = '' ) {
 		// shared.css sets diff in interface language/dir, but the actual content
 		// is often in a different language, mostly the page content language/dir
-		$tableClass = 'diff diff-contentalign-' . htmlspecialchars( $this->getDiffLang()->alignStart() );
-		$header = "<table class='$tableClass'>";
+		$header = Html::openElement( 'table', [
+			'class' => [ 'diff', 'diff-contentalign-' . $this->getDiffLang()->alignStart() ],
+			'data-mw' => 'interface',
+		] );
 		$userLang = htmlspecialchars( $this->getLanguage()->getHtmlCode() );
 
 		if ( !$diff && !$otitle ) {
@@ -1141,19 +1170,6 @@ class DifferenceEngine extends ContextSource {
 		return $header . $diff . "</table>";
 	}
 
-	/**
-	 * Use specified text instead of loading from the database
-	 * @deprecated since 1.21, use setContent() instead.
-	 */
-	public function setText( $oldText, $newText ) {
-		ContentHandler::deprecated( __METHOD__, "1.21" );
-
-		$oldContent = ContentHandler::makeContent( $oldText, $this->getTitle() );
-		$newContent = ContentHandler::makeContent( $newText, $this->getTitle() );
-
-		$this->setContent( $oldContent, $newContent );
-	}
-
 	/**
 	 * Use specified text instead of loading from the database
 	 * @param Content $oldContent
@@ -1203,7 +1219,7 @@ class DifferenceEngine extends ContextSource {
 			$newid = intval( $new );
 		}
 
-		return array( $oldid, $newid );
+		return [ $oldid, $newid ];
 	}
 
 	/**
@@ -1228,7 +1244,7 @@ class DifferenceEngine extends ContextSource {
 
 		Hooks::run(
 			'NewDifferenceEngine',
-			array( $this->getTitle(), &$this->mOldid, &$this->mNewid, $old, $new )
+			[ $this->getTitle(), &$this->mOldid, &$this->mNewid, $old, $new ]
 		);
 	}
 
@@ -1303,7 +1319,7 @@ class DifferenceEngine extends ContextSource {
 			$this->mOldTags = $dbr->selectField(
 				'tag_summary',
 				'ts_tags',
-				array( 'ts_rev_id' => $this->mOldid ),
+				[ 'ts_rev_id' => $this->mOldid ],
 				__METHOD__
 			);
 		} else {
@@ -1312,7 +1328,7 @@ class DifferenceEngine extends ContextSource {
 		$this->mNewTags = $dbr->selectField(
 			'tag_summary',
 			'ts_tags',
-			array( 'ts_rev_id' => $this->mNewid ),
+			[ 'ts_rev_id' => $this->mNewid ],
 			__METHOD__
 		);
 
