@@ -33,7 +33,6 @@ class MovePageForm extends UnlistedSpecialPage {
 	/** @var Title */
 	protected $newTitle;
 
-
 	/** @var string Text input */
 	protected $reason;
 
@@ -63,6 +62,10 @@ class MovePageForm extends UnlistedSpecialPage {
 		parent::__construct( 'Movepage' );
 	}
 
+	public function doesWrites() {
+		return true;
+	}
+
 	public function execute( $par ) {
 		$this->useTransactionalTimeLimit();
 
@@ -77,11 +80,9 @@ class MovePageForm extends UnlistedSpecialPage {
 		// Yes, the use of getVal() and getText() is wanted, see bug 20365
 
 		$oldTitleText = $request->getVal( 'wpOldTitle', $target );
-		if ( is_string( $oldTitleText ) ) {
-			$this->oldTitle = Title::newFromText( $oldTitleText );
-		}
+		$this->oldTitle = Title::newFromText( $oldTitleText );
 
-		if ( $this->oldTitle === null ) {
+		if ( !$this->oldTitle ) {
 			// Either oldTitle wasn't passed, or newFromText returned null
 			throw new ErrorPageError( 'notargettitle', 'notargettext' );
 		}
@@ -116,9 +117,9 @@ class MovePageForm extends UnlistedSpecialPage {
 		$this->moveTalk = $request->getBool( 'wpMovetalk', $def );
 		$this->fixRedirects = $request->getBool( 'wpFixRedirects', $def );
 		$this->leaveRedirect = $request->getBool( 'wpLeaveRedirect', $def );
-		$this->moveSubpages = $request->getBool( 'wpMovesubpages', false );
-		$this->deleteAndMove = $request->getBool( 'wpDeleteAndMove' ) && $request->getBool( 'wpConfirm' );
-		$this->moveOverShared = $request->getBool( 'wpMoveOverSharedFile', false );
+		$this->moveSubpages = $request->getBool( 'wpMovesubpages' );
+		$this->deleteAndMove = $request->getBool( 'wpDeleteAndMove' );
+		$this->moveOverShared = $request->getBool( 'wpMoveOverSharedFile' );
 		$this->watch = $request->getCheck( 'wpWatch' ) && $user->isLoggedIn();
 
 		if ( 'submit' == $request->getVal( 'action' ) && $request->wasPosted()
@@ -126,7 +127,7 @@ class MovePageForm extends UnlistedSpecialPage {
 		) {
 			$this->doSubmit();
 		} else {
-			$this->showForm( array() );
+			$this->showForm( [] );
 		}
 	}
 
@@ -142,14 +143,32 @@ class MovePageForm extends UnlistedSpecialPage {
 
 		$this->getSkin()->setRelevantTitle( $this->oldTitle );
 
-		$oldTitleLink = Linker::link( $this->oldTitle );
-
 		$out = $this->getOutput();
 		$out->setPageTitle( $this->msg( 'move-page', $this->oldTitle->getPrefixedText() ) );
 		$out->addModules( 'mediawiki.special.movePage' );
 		$out->addModuleStyles( 'mediawiki.special.movePage.styles' );
 		$this->addHelpLink( 'Help:Moving a page' );
 
+		$out->addWikiMsg( $this->getConfig()->get( 'FixDoubleRedirects' ) ?
+			'movepagetext' :
+			'movepagetext-noredirectfixer'
+		);
+
+		if ( $this->oldTitle->getNamespace() == NS_USER && !$this->oldTitle->isSubpage() ) {
+			$out->wrapWikiMsg(
+				"<div class=\"warningbox mw-moveuserpage-warning\">\n$1\n</div>",
+				'moveuserpage-warning'
+			);
+		} elseif ( $this->oldTitle->getNamespace() == NS_CATEGORY ) {
+			$out->wrapWikiMsg(
+				"<div class=\"warningbox mw-movecategorypage-warning\">\n$1\n</div>",
+				'movecategorypage-warning'
+			);
+		}
+
+		$deleteAndMove = false;
+		$moveOverShared = false;
+
 		$newTitle = $this->newTitle;
 
 		if ( !$newTitle ) {
@@ -171,39 +190,26 @@ class MovePageForm extends UnlistedSpecialPage {
 		if ( count( $err ) == 1 && isset( $err[0][0] ) && $err[0][0] == 'articleexists'
 			&& $newTitle->quickUserCan( 'delete', $user )
 		) {
-			$out->addWikiMsg( 'delete_and_move_text', $newTitle->getPrefixedText() );
-			$movepagebtn = $this->msg( 'delete_and_move' )->text();
-			$submitVar = 'wpDeleteAndMove';
-			$confirm = true;
-			$err = array();
-		} else {
-			if ( $this->oldTitle->getNamespace() == NS_USER && !$this->oldTitle->isSubpage() ) {
-				$out->wrapWikiMsg(
-					"<div class=\"error mw-moveuserpage-warning\">\n$1\n</div>",
-					'moveuserpage-warning'
-				);
-			} elseif ( $this->oldTitle->getNamespace() == NS_CATEGORY ) {
-				$out->wrapWikiMsg(
-					"<div class=\"error mw-movecategorypage-warning\">\n$1\n</div>",
-					'movecategorypage-warning'
-				);
-			}
-
-			$out->addWikiMsg( $this->getConfig()->get( 'FixDoubleRedirects' ) ?
-				'movepagetext' :
-				'movepagetext-noredirectfixer'
+			$out->wrapWikiMsg(
+				"<div class='warningbox'>\n$1\n</div>\n",
+				[ 'delete_and_move_text', $newTitle->getPrefixedText() ]
 			);
-			$movepagebtn = $this->msg( 'movepagebtn' )->text();
-			$submitVar = 'wpMove';
-			$confirm = false;
+			$deleteAndMove = true;
+			$err = [];
 		}
 
 		if ( count( $err ) == 1 && isset( $err[0][0] ) && $err[0][0] == 'file-exists-sharedrepo'
 			&& $user->isAllowed( 'reupload-shared' )
 		) {
-			$out->addWikiMsg( 'move-over-sharedrepo', $newTitle->getPrefixedText() );
-			$submitVar = 'wpMoveOverSharedFile';
-			$err = array();
+			$out->wrapWikiMsg(
+				"<div class='warningbox'>\n$1\n</div>\n",
+				[
+					'move-over-sharedrepo',
+					$newTitle->getPrefixedText()
+				]
+			);
+			$moveOverShared = true;
+			$err = [];
 		}
 
 		$oldTalk = $this->oldTitle->getTalkPage();
@@ -222,20 +228,16 @@ class MovePageForm extends UnlistedSpecialPage {
 		$dbr = wfGetDB( DB_SLAVE );
 		if ( $this->getConfig()->get( 'FixDoubleRedirects' ) ) {
 			$hasRedirects = $dbr->selectField( 'redirect', '1',
-				array(
+				[
 					'rd_namespace' => $this->oldTitle->getNamespace(),
 					'rd_title' => $this->oldTitle->getDBkey(),
-				), __METHOD__ );
+				], __METHOD__ );
 		} else {
 			$hasRedirects = false;
 		}
 
-		if ( $considerTalk ) {
-			$out->addWikiMsg( 'movepagetalktext' );
-		}
-
 		if ( count( $err ) ) {
-			$out->addHTML( "<div class='error'>\n" );
+			$out->addHTML( "<div class='errorbox'>\n" );
 			$action_desc = $this->msg( 'action-move' )->plain();
 			$out->addWikiMsg( 'permissionserrorstext-withaction', count( $err ), $action_desc );
 
@@ -249,7 +251,7 @@ class MovePageForm extends UnlistedSpecialPage {
 					$out->addWikiMsgArray( $errMsgName, $errMsg );
 				}
 			} else {
-				$errStr = array();
+				$errStr = [];
 
 				foreach ( $err as $errMsg ) {
 					if ( $errMsg[0] == 'hookaborted' ) {
@@ -282,7 +284,7 @@ class MovePageForm extends UnlistedSpecialPage {
 				'protect',
 				$this->oldTitle,
 				'',
-				array( 'lim' => 1 )
+				[ 'lim' => 1 ]
 			);
 			$out->addHTML( "</div>\n" );
 		}
@@ -290,7 +292,7 @@ class MovePageForm extends UnlistedSpecialPage {
 		// Byte limit (not string length limit) for wpReason and wpNewTitleMain
 		// is enforced in the mediawiki.special.movePage module
 
-		$immovableNamespaces = array();
+		$immovableNamespaces = [];
 		foreach ( array_keys( $this->getLanguage()->getNamespaces() ) as $nsId ) {
 			if ( !MWNamespace::isMovable( $nsId ) ) {
 				$immovableNamespaces[] = $nsId;
@@ -300,67 +302,60 @@ class MovePageForm extends UnlistedSpecialPage {
 		$handler = ContentHandler::getForTitle( $this->oldTitle );
 
 		$out->enableOOUI();
-		$fields = array();
+		$fields = [];
 
 		$fields[] = new OOUI\FieldLayout(
-			new OOUI\LabelWidget( array(
-				'label' => new OOUI\HtmlSnippet( "<strong>$oldTitleLink</strong>" )
-			) ),
-			array(
-				'label' => $this->msg( 'movearticle' )->text(),
-				'align' => 'top',
-			)
-		);
-
-		$fields[] = new OOUI\FieldLayout(
-			new MediaWiki\Widget\ComplexTitleInputWidget( array(
+			new MediaWiki\Widget\ComplexTitleInputWidget( [
 				'id' => 'wpNewTitle',
-				'namespace' => array(
+				'namespace' => [
 					'id' => 'wpNewTitleNs',
 					'name' => 'wpNewTitleNs',
 					'value' => $newTitle->getNamespace(),
 					'exclude' => $immovableNamespaces,
-				),
-				'title' => array(
+				],
+				'title' => [
 					'id' => 'wpNewTitleMain',
 					'name' => 'wpNewTitleMain',
 					'value' => $wgContLang->recodeForEdit( $newTitle->getText() ),
 					// Inappropriate, since we're expecting the user to input a non-existent page's title
 					'suggestions' => false,
-				),
+				],
 				'infusable' => true,
-			) ),
-			array(
+			] ),
+			[
 				'label' => $this->msg( 'newtitle' )->text(),
 				'align' => 'top',
-			)
+			]
 		);
 
 		$fields[] = new OOUI\FieldLayout(
-			new OOUI\TextInputWidget( array(
+			new OOUI\TextInputWidget( [
 				'name' => 'wpReason',
 				'id' => 'wpReason',
 				'maxLength' => 200,
 				'infusable' => true,
-			) ),
-			array(
+				'value' => $this->reason,
+			] ),
+			[
 				'label' => $this->msg( 'movereason' )->text(),
 				'align' => 'top',
-			)
+			]
 		);
 
 		if ( $considerTalk ) {
 			$fields[] = new OOUI\FieldLayout(
-				new OOUI\CheckboxInputWidget( array(
+				new OOUI\CheckboxInputWidget( [
 					'name' => 'wpMovetalk',
 					'id' => 'wpMovetalk',
 					'value' => '1',
 					'selected' => $this->moveTalk,
-				) ),
-				array(
+				] ),
+				[
 					'label' => $this->msg( 'movetalk' )->text(),
+					'help' => new OOUI\HtmlSnippet( $this->msg( 'movepagetalktext' )->parseAsBlock() ),
 					'align' => 'inline',
-				)
+					'infusable' => true,
+				]
 			);
 		}
 
@@ -373,47 +368,47 @@ class MovePageForm extends UnlistedSpecialPage {
 				$isDisabled = true;
 			}
 			$fields[] = new OOUI\FieldLayout(
-				new OOUI\CheckboxInputWidget( array(
+				new OOUI\CheckboxInputWidget( [
 					'name' => 'wpLeaveRedirect',
 					'id' => 'wpLeaveRedirect',
 					'value' => '1',
 					'selected' => $isChecked,
 					'disabled' => $isDisabled,
-				) ),
-				array(
+				] ),
+				[
 					'label' => $this->msg( 'move-leave-redirect' )->text(),
 					'align' => 'inline',
-				)
+				]
 			);
 		}
 
 		if ( $hasRedirects ) {
 			$fields[] = new OOUI\FieldLayout(
-				new OOUI\CheckboxInputWidget( array(
+				new OOUI\CheckboxInputWidget( [
 					'name' => 'wpFixRedirects',
 					'id' => 'wpFixRedirects',
 					'value' => '1',
 					'selected' => $this->fixRedirects,
-				) ),
-				array(
+				] ),
+				[
 					'label' => $this->msg( 'fix-double-redirects' )->text(),
 					'align' => 'inline',
-				)
+				]
 			);
 		}
 
 		if ( $canMoveSubpage ) {
 			$maximumMovedPages = $this->getConfig()->get( 'MaximumMovedPages' );
 			$fields[] = new OOUI\FieldLayout(
-				new OOUI\CheckboxInputWidget( array(
+				new OOUI\CheckboxInputWidget( [
 					'name' => 'wpMovesubpages',
 					'id' => 'wpMovesubpages',
 					'value' => '1',
 					# Don't check the box if we only have talk subpages to
 					# move and we aren't moving the talk page.
 					'selected' => $this->moveSubpages && ( $this->oldTitle->hasSubpages() || $this->moveTalk ),
-				) ),
-				array(
+				] ),
+				[
 					'label' => new OOUI\HtmlSnippet(
 						$this->msg(
 							( $this->oldTitle->hasSubpages()
@@ -422,7 +417,7 @@ class MovePageForm extends UnlistedSpecialPage {
 						)->numParams( $maximumMovedPages )->params( $maximumMovedPages )->parse()
 					),
 					'align' => 'inline',
-				)
+				]
 			);
 		}
 
@@ -431,75 +426,79 @@ class MovePageForm extends UnlistedSpecialPage {
 			$watchChecked = $user->isLoggedIn() && ( $this->watch || $user->getBoolOption( 'watchmoves' )
 				|| $user->isWatched( $this->oldTitle ) );
 			$fields[] = new OOUI\FieldLayout(
-				new OOUI\CheckboxInputWidget( array(
+				new OOUI\CheckboxInputWidget( [
 					'name' => 'wpWatch',
 					'id' => 'watch', # ew
 					'value' => '1',
 					'selected' => $watchChecked,
-				) ),
-				array(
+				] ),
+				[
 					'label' => $this->msg( 'move-watch' )->text(),
 					'align' => 'inline',
-				)
+				]
 			);
 		}
 
-		if ( $confirm ) {
-			$watchChecked = $user->isLoggedIn() && ( $this->watch || $user->getBoolOption( 'watchmoves' )
-				|| $user->isWatched( $this->oldTitle ) );
+		$hiddenFields = '';
+		if ( $moveOverShared ) {
+			$hiddenFields .= Html::hidden( 'wpMoveOverSharedFile', '1' );
+		}
+
+		if ( $deleteAndMove ) {
 			$fields[] = new OOUI\FieldLayout(
-				new OOUI\CheckboxInputWidget( array(
-					'name' => 'wpConfirm',
-					'id' => 'wpConfirm',
+				new OOUI\CheckboxInputWidget( [
+					'name' => 'wpDeleteAndMove',
+					'id' => 'wpDeleteAndMove',
 					'value' => '1',
-				) ),
-				array(
+				] ),
+				[
 					'label' => $this->msg( 'delete_and_move_confirm' )->text(),
 					'align' => 'inline',
-				)
+				]
 			);
 		}
 
 		$fields[] = new OOUI\FieldLayout(
-			new OOUI\ButtonInputWidget( array(
-				'name' => $submitVar,
-				'value' => $movepagebtn,
-				'label' => $movepagebtn,
-				'flags' => array( 'progressive', 'primary' ),
+			new OOUI\ButtonInputWidget( [
+				'name' => 'wpMove',
+				'value' => $this->msg( 'movepagebtn' )->text(),
+				'label' => $this->msg( 'movepagebtn' )->text(),
+				'flags' => [ 'constructive', 'primary' ],
 				'type' => 'submit',
-			) ),
-			array(
+			] ),
+			[
 				'align' => 'top',
-			)
+			]
 		);
 
-		$fieldset = new OOUI\FieldsetLayout( array(
+		$fieldset = new OOUI\FieldsetLayout( [
 			'label' => $this->msg( 'move-page-legend' )->text(),
 			'id' => 'mw-movepage-table',
 			'items' => $fields,
-		) );
+		] );
 
-		$form = new OOUI\FormLayout( array(
+		$form = new OOUI\FormLayout( [
 			'method' => 'post',
 			'action' => $this->getPageTitle()->getLocalURL( 'action=submit' ),
 			'id' => 'movepage',
-		) );
+		] );
 		$form->appendContent(
 			$fieldset,
 			new OOUI\HtmlSnippet(
+				$hiddenFields .
 				Html::hidden( 'wpOldTitle', $this->oldTitle->getPrefixedText() ) .
 				Html::hidden( 'wpEditToken', $user->getEditToken() )
 			)
 		);
 
 		$out->addHTML(
-			new OOUI\PanelLayout( array(
-				'classes' => array( 'movepage-wrapper' ),
+			new OOUI\PanelLayout( [
+				'classes' => [ 'movepage-wrapper' ],
 				'expanded' => false,
 				'padded' => true,
 				'framed' => true,
 				'content' => $form,
-			) )
+			] )
 		);
 
 		$this->showLogFragment( $this->oldTitle );
@@ -518,7 +517,7 @@ class MovePageForm extends UnlistedSpecialPage {
 
 		# don't allow moving to pages with # in
 		if ( !$nt || $nt->hasFragment() ) {
-			$this->showForm( array( array( 'badtitletext' ) ) );
+			$this->showForm( [ [ 'badtitletext' ] ] );
 
 			return;
 		}
@@ -529,7 +528,7 @@ class MovePageForm extends UnlistedSpecialPage {
 			&& !RepoGroup::singleton()->getLocalRepo()->findFile( $nt )
 			&& wfFindFile( $nt )
 		) {
-			$this->showForm( array( array( 'file-exists-sharedrepo' ) ) );
+			$this->showForm( [ [ 'file-exists-sharedrepo' ] ] );
 
 			return;
 		}
@@ -605,19 +604,19 @@ class MovePageForm extends UnlistedSpecialPage {
 		$oldLink = Linker::link(
 			$ot,
 			null,
-			array( 'id' => 'movepage-oldlink' ),
-			array( 'redirect' => 'no' )
+			[ 'id' => 'movepage-oldlink' ],
+			[ 'redirect' => 'no' ]
 		);
 		$newLink = Linker::linkKnown(
 			$nt,
 			null,
-			array( 'id' => 'movepage-newlink' )
+			[ 'id' => 'movepage-newlink' ]
 		);
 		$oldText = $ot->getPrefixedText();
 		$newText = $nt->getPrefixedText();
 
 		if ( $ot->exists() ) {
-			//NOTE: we assume that if the old title exists, it's because it was re-created as
+			// NOTE: we assume that if the old title exists, it's because it was re-created as
 			// a redirect to the new title. This is not safe, but what we did before was
 			// even worse: we just determined whether a redirect should have been created,
 			// and reported that it was created if it should have, without any checks.
@@ -631,7 +630,7 @@ class MovePageForm extends UnlistedSpecialPage {
 			$newLink )->params( $oldText, $newText )->parseAsBlock() );
 		$out->addWikiMsg( $msgName );
 
-		Hooks::run( 'SpecialMovepageAfterMove', array( &$this, &$ot, &$nt ) );
+		Hooks::run( 'SpecialMovepageAfterMove', [ &$this, &$ot, &$nt ] );
 
 		# Now we move extra pages we've been asked to move: subpages and talk
 		# pages.  First, if the old page or the new page is a talk page, we
@@ -644,17 +643,16 @@ class MovePageForm extends UnlistedSpecialPage {
 			$this->moveSubpages = false;
 		}
 
-		# Next make a list of id's.  This might be marginally less efficient
-		# than a more direct method, but this is not a highly performance-cri-
-		# tical code path and readable code is more important here.
-		#
-		# Note: this query works nicely on MySQL 5, but the optimizer in MySQL
-		# 4 might get confused.  If so, consider rewriting as a UNION.
-		#
-		# If the target namespace doesn't allow subpages, moving with subpages
-		# would mean that you couldn't move them back in one operation, which
-		# is bad.
-		# @todo FIXME: A specific error message should be given in this case.
+		/**
+		 * Next make a list of id's.  This might be marginally less efficient
+		 * than a more direct method, but this is not a highly performance-cri-
+		 * tical code path and readable code is more important here.
+		 *
+		 * If the target namespace doesn't allow subpages, moving with subpages
+		 * would mean that you couldn't move them back in one operation, which
+		 * is bad.
+		 * @todo FIXME: A specific error message should be given in this case.
+		 */
 
 		// @todo FIXME: Use Title::moveSubpages() here
 		$dbr = wfGetDB( DB_MASTER );
@@ -664,11 +662,11 @@ class MovePageForm extends UnlistedSpecialPage {
 					&& MWNamespace::hasSubpages( $nt->getTalkPage()->getNamespace() )
 			)
 		) ) {
-			$conds = array(
+			$conds = [
 				'page_title' . $dbr->buildLike( $ot->getDBkey() . '/', $dbr->anyString() )
 					. ' OR page_title = ' . $dbr->addQuotes( $ot->getDBkey() )
-			);
-			$conds['page_namespace'] = array();
+			];
+			$conds['page_namespace'] = [];
 			if ( MWNamespace::hasSubpages( $nt->getNamespace() ) ) {
 				$conds['page_namespace'][] = $ot->getNamespace();
 			}
@@ -678,27 +676,27 @@ class MovePageForm extends UnlistedSpecialPage {
 				$conds['page_namespace'][] = $ot->getTalkPage()->getNamespace();
 			}
 		} elseif ( $this->moveTalk ) {
-			$conds = array(
+			$conds = [
 				'page_namespace' => $ot->getTalkPage()->getNamespace(),
 				'page_title' => $ot->getDBkey()
-			);
+			];
 		} else {
 			# Skip the query
 			$conds = null;
 		}
 
-		$extraPages = array();
+		$extraPages = [];
 		if ( !is_null( $conds ) ) {
 			$extraPages = TitleArray::newFromResult(
 				$dbr->select( 'page',
-					array( 'page_id', 'page_namespace', 'page_title' ),
+					[ 'page_id', 'page_namespace', 'page_title' ],
 					$conds,
 					__METHOD__
 				)
 			);
 		}
 
-		$extraOutput = array();
+		$extraOutput = [];
 		$count = 1;
 		foreach ( $extraPages as $oldSubpage ) {
 			if ( $ot->equals( $oldSubpage ) || $nt->equals( $oldSubpage ) ) {
@@ -745,8 +743,8 @@ class MovePageForm extends UnlistedSpecialPage {
 					$oldLink = Linker::link(
 						$oldSubpage,
 						null,
-						array(),
-						array( 'redirect' => 'no' )
+						[],
+						[ 'redirect' => 'no' ]
 					);
 
 					$newLink = Linker::linkKnown( $newSubpage );
@@ -769,7 +767,7 @@ class MovePageForm extends UnlistedSpecialPage {
 			}
 		}
 
-		if ( $extraOutput !== array() ) {
+		if ( $extraOutput !== [] ) {
 			$out->addHTML( "<ul>\n<li>" . implode( "</li>\n<li>", $extraOutput ) . "</li>\n</ul>" );
 		}
 
@@ -794,7 +792,7 @@ class MovePageForm extends UnlistedSpecialPage {
 		$count = $subpages instanceof TitleArray ? $subpages->count() : 0;
 
 		$out = $this->getOutput();
-		$out->wrapWikiMsg( '== $1 ==', array( 'movesubpage', $count ) );
+		$out->wrapWikiMsg( '== $1 ==', [ 'movesubpage', $count ] );
 
 		# No subpages.
 		if ( $count == 0 ) {
@@ -813,6 +811,18 @@ class MovePageForm extends UnlistedSpecialPage {
 		$out->addHTML( "</ul>\n" );
 	}
 
+	/**
+	 * Return an array of subpages beginning with $search that this special page will accept.
+	 *
+	 * @param string $search Prefix to search for
+	 * @param int $limit Maximum number of results to return (usually 10)
+	 * @param int $offset Number of results to skip (usually 0)
+	 * @return string[] Matching subpages
+	 */
+	public function prefixSearchSubpages( $search, $limit, $offset ) {
+		return $this->prefixSearchString( $search, $limit, $offset );
+	}
+
 	protected function getGroupName() {
 		return 'pagetools';
 	}
