@@ -23,6 +23,8 @@
  * @ingroup SpecialPage
  */
 
+use MediaWiki\MediaWikiServices;
+
 /**
  * implements Special:Search - Run text & title search and display the output
  * @ingroup SpecialPage
@@ -45,7 +47,7 @@ class SpecialSearch extends SpecialPage {
 	protected $searchEngineType;
 
 	/** @var array For links */
-	protected $extraParams = array();
+	protected $extraParams = [];
 
 	/**
 	 * @var string The prefix url parameter. Set on the searcher and the
@@ -73,10 +75,23 @@ class SpecialSearch extends SpecialPage {
 	 */
 	protected $runSuggestion = true;
 
+	/**
+	 * Names of the wikis, in format: Interwiki prefix -> caption
+	 * @var array
+	 */
+	protected $customCaptions;
+
+	/**
+	 * Search engine configurations.
+	 * @var SearchEngineConfig
+	 */
+	protected $searchConfig;
+
 	const NAMESPACES_CURRENT = 'sense';
 
 	public function __construct() {
 		parent::__construct( 'Search' );
+		$this->searchConfig = MediaWikiServices::getInstance()->getSearchEngineConfig();
 	}
 
 	/**
@@ -89,10 +104,11 @@ class SpecialSearch extends SpecialPage {
 		$this->outputHeader();
 		$out = $this->getOutput();
 		$out->allowClickjacking();
-		$out->addModuleStyles( array(
+		$out->addModuleStyles( [
 			'mediawiki.special', 'mediawiki.special.search', 'mediawiki.ui', 'mediawiki.ui.button',
-			'mediawiki.ui.input',
-		) );
+			'mediawiki.ui.input', 'mediawiki.widgets.SearchInputWidget.styles',
+		] );
+		$this->addHelpLink( 'Help:Searching' );
 
 		// Strip underscores from title parameter; most of the time we'll want
 		// text form here. But don't strip underscores from actual text params!
@@ -115,6 +131,7 @@ class SpecialSearch extends SpecialPage {
 			return;
 		}
 
+		$out->addJsConfigVars( [ 'searchTerm' => $search ] );
 		$this->searchEngineType = $request->getVal( 'srbackend' );
 
 		if ( $request->getVal( 'fulltext' )
@@ -142,7 +159,7 @@ class SpecialSearch extends SpecialPage {
 		$nslist = $this->powerSearch( $request );
 		if ( !count( $nslist ) ) {
 			# Fallback to user preference
-			$nslist = SearchEngine::userNamespaces( $user );
+			$nslist = $this->searchConfig->userNamespaces( $user );
 		}
 
 		$profile = null;
@@ -194,17 +211,23 @@ class SpecialSearch extends SpecialPage {
 			return;
 		}
 		# If there's an exact or very near match, jump right there.
-		$title = SearchEngine::getNearMatch( $term );
+		$title = $this->getSearchEngine()
+			->getNearMatcher( $this->getConfig() )->getNearMatch( $term );
 
-		if ( !is_null( $title ) ) {
-			$this->getOutput()->redirect( $title->getFullURL() );
+		if ( !is_null( $title ) &&
+			Hooks::run( 'SpecialSearchGoResult', [ $term, $title, &$url ] )
+		) {
+			if ( $url === null ) {
+				$url = $title->getFullURL();
+			}
+			$this->getOutput()->redirect( $url );
 
 			return;
 		}
 		# No match, generate an edit URL
 		$title = Title::newFromText( $term );
 		if ( !is_null( $title ) ) {
-			Hooks::run( 'SpecialSearchNogomatch', array( &$title ) );
+			Hooks::run( 'SpecialSearchNogomatch', [ &$title ] );
 		}
 		$this->showResults( $term );
 	}
@@ -222,7 +245,7 @@ class SpecialSearch extends SpecialPage {
 		$search->prefix = $this->mPrefix;
 		$term = $search->transformSearchTerm( $term );
 
-		Hooks::run( 'SpecialSearchSetupEngine', array( $this, $this->profile, $search ) );
+		Hooks::run( 'SpecialSearchSetupEngine', [ $this, $this->profile, $search ] );
 
 		$this->setupPage( $term );
 
@@ -239,7 +262,7 @@ class SpecialSearch extends SpecialPage {
 					Xml::element( 'legend', null, $this->msg( 'search-external' )->text() ) .
 					Xml::element(
 						'p',
-						array( 'class' => 'mw-searchdisabled' ),
+						[ 'class' => 'mw-searchdisabled' ],
 						$this->msg( 'searchdisabled' )->text()
 					) .
 					$this->msg( 'googlesearch' )->rawParams(
@@ -280,20 +303,20 @@ class SpecialSearch extends SpecialPage {
 			}
 		}
 
-		if ( !Hooks::run( 'SpecialSearchResultsPrepend', array( $this, $out, $term ) ) ) {
+		if ( !Hooks::run( 'SpecialSearchResultsPrepend', [ $this, $out, $term ] ) ) {
 			# Hook requested termination
 			return;
 		}
 
 		// start rendering the page
-		$out->addHtml(
+		$out->addHTML(
 			Xml::openElement(
 				'form',
-				array(
+				[
 					'id' => ( $this->isPowerSearch() ? 'powersearch' : 'search' ),
 					'method' => 'get',
 					'action' => wfScript(),
-				)
+				]
 			)
 		);
 
@@ -310,11 +333,12 @@ class SpecialSearch extends SpecialPage {
 		$num = $titleMatchesNum + $textMatchesNum;
 		$totalRes = $numTitleMatches + $numTextMatches;
 
-		$out->addHtml(
+		$out->enableOOUI();
+		$out->addHTML(
 			# This is an awful awful ID name. It's not a table, but we
 			# named it poorly from when this was a table so now we're
 			# stuck with it
-			Xml::openElement( 'div', array( 'id' => 'mw-search-top-table' ) ) .
+			Xml::openElement( 'div', [ 'id' => 'mw-search-top-table' ] ) .
 			$this->shortDialog( $term, $num, $totalRes ) .
 			Xml::closeElement( 'div' ) .
 			$this->searchProfileTabs( $term ) .
@@ -329,7 +353,7 @@ class SpecialSearch extends SpecialPage {
 			return;
 		}
 
-		$out->addHtml( "<div class='searchresults'>" );
+		$out->addHTML( "<div class='searchresults'>" );
 
 		// prev/next links
 		$prevnext = null;
@@ -344,12 +368,12 @@ class SpecialSearch extends SpecialPage {
 					$this->getPageTitle(),
 					$this->offset,
 					$this->limit,
-					$this->powerSearchOptions() + array( 'search' => $term ),
+					$this->powerSearchOptions() + [ 'search' => $term ],
 					$this->limit + $this->offset >= $totalRes
 				);
 			}
 		}
-		Hooks::run( 'SpecialSearchResults', array( $term, &$titleMatches, &$textMatches ) );
+		Hooks::run( 'SpecialSearchResults', [ $term, &$titleMatches, &$textMatches ] );
 
 		$out->parserOptions()->setEditSection( false );
 		if ( $titleMatches ) {
@@ -362,6 +386,7 @@ class SpecialSearch extends SpecialPage {
 		if ( $textMatches && !$textStatus ) {
 			// output appropriate heading
 			if ( $numTextMatches > 0 && $numTitleMatches > 0 ) {
+				$out->addHTML( '<div class="visualClear"></div>' );
 				// if no title matches the heading is redundant
 				$out->wrapWikiMsg( "==$1==\n", 'textmatches' );
 			}
@@ -370,35 +395,70 @@ class SpecialSearch extends SpecialPage {
 			if ( $numTextMatches > 0 ) {
 				$out->addHTML( $this->showMatches( $textMatches ) );
 			}
-			// show interwiki results if any
-			if ( $textMatches->hasInterwikiResults() ) {
-				$out->addHTML( $this->showInterwiki( $textMatches->getInterwikiResults(), $term ) );
-			}
 
-			$textMatches->free();
+			// show secondary interwiki results if any
+			if ( $textMatches->hasInterwikiResults( SearchResultSet::SECONDARY_RESULTS ) ) {
+				$out->addHTML( $this->showInterwiki( $textMatches->getInterwikiResults(
+						SearchResultSet::SECONDARY_RESULTS ), $term ) );
+			}
 		}
+
+		$hasOtherResults = $textMatches &&
+			$textMatches->hasInterwikiResults( SearchResultSet::INLINE_RESULTS );
+
 		if ( $num === 0 ) {
 			if ( $textStatus ) {
 				$out->addHTML( '<div class="error">' .
 					$textStatus->getMessage( 'search-error' ) . '</div>' );
 			} else {
-				$out->wrapWikiMsg( "<p class=\"mw-search-nonefound\">\n$1</p>",
-					array( 'search-nonefound', wfEscapeWikiText( $term ) ) );
 				$this->showCreateLink( $title, $num, $titleMatches, $textMatches );
+				$out->wrapWikiMsg( "<p class=\"mw-search-nonefound\">\n$1</p>",
+					[ $hasOtherResults ? 'search-nonefound-thiswiki' : 'search-nonefound',
+							wfEscapeWikiText( $term )
+					] );
 			}
 		}
 
+		if ( $hasOtherResults ) {
+			foreach ( $textMatches->getInterwikiResults( SearchResultSet::INLINE_RESULTS )
+						as $interwiki => $interwikiResult ) {
+				if ( $interwikiResult instanceof Status || $interwikiResult->numRows() == 0 ) {
+					// ignore bad interwikis for now
+					continue;
+				}
+				// TODO: wiki header
+				$out->addHTML( $this->showMatches( $interwikiResult, $interwiki ) );
+			}
+		}
+
+		if ( $textMatches ) {
+			$textMatches->free();
+		}
+
 		$out->addHTML( '<div class="visualClear"></div>' );
+
 		if ( $prevnext ) {
 			$out->addHTML( "<p class='mw-search-pager-bottom'>{$prevnext}</p>\n" );
 		}
 
-		$out->addHtml( "</div>" );
+		$out->addHTML( "</div>" );
 
-		Hooks::run( 'SpecialSearchResultsAppend', array( $this, $out ) );
+		Hooks::run( 'SpecialSearchResultsAppend', [ $this, $out, $term ] );
 
 	}
 
+	/**
+	 * Produce wiki header for interwiki results
+	 * @param string $interwiki Interwiki name
+	 * @param SearchResultSet $interwikiResult The result set
+	 * @return string
+	 */
+	protected function interwikiHeader( $interwiki, $interwikiResult ) {
+		// TODO: we need to figure out how to name wikis correctly
+		$wikiMsg = $this->msg( 'search-interwiki-results-' . $interwiki )->parse();
+		return "<p class=\"mw-search-interwiki-header\">\n$wikiMsg</p>";
+	}
+
 	/**
 	 * Decide if the suggested query should be run, and it's results returned
 	 * instead of the provided $textMatches
@@ -424,7 +484,7 @@ class SpecialSearch extends SpecialPage {
 	 */
 	protected function getDidYouMeanHtml( SearchResultSet $textMatches ) {
 		# mirror Go/Search behavior of original request ..
-		$params = array( 'search' => $textMatches->getSuggestionQuery() );
+		$params = [ 'search' => $textMatches->getSuggestionQuery() ];
 		if ( $this->fulltext != null ) {
 			$params['fulltext'] = $this->fulltext;
 		}
@@ -433,14 +493,14 @@ class SpecialSearch extends SpecialPage {
 		$suggest = Linker::linkKnown(
 			$this->getPageTitle(),
 			$textMatches->getSuggestionSnippet() ?: null,
-			array(),
+			[ 'id' => 'mw-search-DYM-suggestion' ],
 			$stParams
 		);
 
-		# html of did you mean... search suggestion link
+		# HTML of did you mean... search suggestion link
 		return Html::rawElement(
 			'div',
-			array( 'class' => 'searchdidyoumean' ),
+			[ 'class' => 'searchdidyoumean' ],
 			$this->msg( 'search-suggest' )->rawParams( $suggest )->parse()
 		);
 	}
@@ -458,7 +518,7 @@ class SpecialSearch extends SpecialPage {
 		// Showing results for '$rewritten'
 		// Search instead for '$orig'
 
-		$params = array( 'search' => $textMatches->getQueryAfterRewrite() );
+		$params = [ 'search' => $textMatches->getQueryAfterRewrite() ];
 		if ( $this->fulltext != null ) {
 			$params['fulltext'] = $this->fulltext;
 		}
@@ -467,7 +527,7 @@ class SpecialSearch extends SpecialPage {
 		$rewritten = Linker::linkKnown(
 			$this->getPageTitle(),
 			$textMatches->getQueryAfterRewriteSnippet() ?: null,
-			array(),
+			[ 'id' => 'mw-search-DYM-rewritten' ],
 			$stParams
 		);
 
@@ -476,13 +536,13 @@ class SpecialSearch extends SpecialPage {
 		$original = Linker::linkKnown(
 			$this->getPageTitle(),
 			htmlspecialchars( $term ),
-			array(),
+			[ 'id' => 'mw-search-DYM-original' ],
 			$stParams
 		);
 
 		return Html::rawElement(
 			'div',
-			array( 'class' => 'searchdidyoumean' ),
+			[ 'class' => 'searchdidyoumean' ],
 			$this->msg( 'search-rewritten' )->rawParams( $rewritten, $original )->escaped()
 		);
 	}
@@ -503,7 +563,7 @@ class SpecialSearch extends SpecialPage {
 		) {
 			// invalid title
 			// preserve the paragraph for margins etc...
-			$this->getOutput()->addHtml( '<p></p>' );
+			$this->getOutput()->addHTML( '<p></p>' );
 
 			return;
 		}
@@ -520,19 +580,19 @@ class SpecialSearch extends SpecialPage {
 			}
 		}
 
-		$params = array(
+		$params = [
 			$messageName,
 			wfEscapeWikiText( $title->getPrefixedText() ),
 			Message::numParam( $num )
-		);
-		Hooks::run( 'SpecialSearchCreateLink', array( $title, &$params ) );
+		];
+		Hooks::run( 'SpecialSearchCreateLink', [ $title, &$params ] );
 
 		// Extensions using the hook might still return an empty $messageName
 		if ( $messageName ) {
 			$this->getOutput()->wrapWikiMsg( "<p class=\"$linkClass\">\n$1</p>", $params );
 		} else {
 			// preserve the paragraph for margins etc...
-			$this->getOutput()->addHtml( '<p></p>' );
+			$this->getOutput()->addHTML( '<p></p>' );
 		}
 	}
 
@@ -569,8 +629,8 @@ class SpecialSearch extends SpecialPage {
 	 * @return array
 	 */
 	protected function powerSearch( &$request ) {
-		$arr = array();
-		foreach ( SearchEngine::searchableNamespaces() as $ns => $name ) {
+		$arr = [];
+		foreach ( $this->searchConfig->searchableNamespaces() as $ns => $name ) {
 			if ( $request->getCheck( 'ns' . $ns ) ) {
 				$arr[] = $ns;
 			}
@@ -585,7 +645,7 @@ class SpecialSearch extends SpecialPage {
 	 * @return array
 	 */
 	protected function powerSearchOptions() {
-		$opt = array();
+		$opt = [];
 		if ( !$this->isPowerSearch() ) {
 			$opt['profile'] = $this->profile;
 		} else {
@@ -624,7 +684,10 @@ class SpecialSearch extends SpecialPage {
 				$user->setOption( 'searchNs' . $n, true );
 			}
 
-			$user->saveSettings();
+			DeferredUpdates::addCallableUpdate( function () use ( $user ) {
+				$user->saveSettings();
+			} );
+
 			return true;
 		}
 
@@ -635,18 +698,25 @@ class SpecialSearch extends SpecialPage {
 	 * Show whole set of results
 	 *
 	 * @param SearchResultSet $matches
+	 * @param string $interwiki Interwiki name
 	 *
 	 * @return string
 	 */
-	protected function showMatches( &$matches ) {
+	protected function showMatches( &$matches, $interwiki = null ) {
 		global $wgContLang;
 
 		$terms = $wgContLang->convertForSearchResult( $matches->termMatches() );
-
-		$out = "<ul class='mw-search-results'>\n";
+		$out = '';
 		$result = $matches->next();
+		$pos = $this->offset;
+
+		if ( $result && $interwiki ) {
+			$out .= $this->interwikiHeader( $interwiki, $result );
+		}
+
+		$out .= "<ul class='mw-search-results'>\n";
 		while ( $result ) {
-			$out .= $this->showHit( $result, $terms );
+			$out .= $this->showHit( $result, $terms, ++$pos );
 			$result = $matches->next();
 		}
 		$out .= "</ul>\n";
@@ -662,10 +732,11 @@ class SpecialSearch extends SpecialPage {
 	 *
 	 * @param SearchResult $result
 	 * @param array $terms Terms to highlight
+	 * @param int $position Position within the search results, including offset.
 	 *
 	 * @return string
 	 */
-	protected function showHit( $result, $terms ) {
+	protected function showHit( $result, $terms, $position ) {
 
 		if ( $result->isBrokenTitle() ) {
 			return '';
@@ -680,18 +751,21 @@ class SpecialSearch extends SpecialPage {
 		}
 
 		$link_t = clone $title;
+		$query = [];
 
 		Hooks::run( 'ShowSearchHitTitle',
-			array( &$link_t, &$titleSnippet, $result, $terms, $this ) );
+			[ &$link_t, &$titleSnippet, $result, $terms, $this, &$query ] );
 
 		$link = Linker::linkKnown(
 			$link_t,
-			$titleSnippet
+			$titleSnippet,
+			[ 'data-serp-pos' => $position ], // HTML attributes
+			$query
 		);
 
-		//If page content is not readable, just return the title.
-		//This is not quite safe, but better than showing excerpts from non-readable pages
-		//Note that hiding the entry entirely would screw up paging.
+		// If page content is not readable, just return the title.
+		// This is not quite safe, but better than showing excerpts from non-readable pages
+		// Note that hiding the entry entirely would screw up paging.
 		if ( !$title->userCan( 'read', $this->getUser() ) ) {
 			return "<li>{$link}</li>\n";
 		}
@@ -772,7 +846,7 @@ class SpecialSearch extends SpecialPage {
 					$this->msg( 'search-file-match' )->escaped() . "</span>";
 			}
 			if ( $img ) {
-				$thumb = $img->transform( array( 'width' => 120, 'height' => 120 ) );
+				$thumb = $img->transform( [ 'width' => 120, 'height' => 120 ] );
 				if ( $thumb ) {
 					$desc = $this->msg( 'parentheses' )->rawParams( $img->getShortDesc() )->escaped();
 					// Float doesn't seem to interact well with the bullets.
@@ -782,7 +856,7 @@ class SpecialSearch extends SpecialPage {
 						'<table class="searchResultImage">' .
 						'<tr>' .
 						'<td style="width: 120px; text-align: center; vertical-align: top;">' .
-						$thumb->toHtml( array( 'desc-link' => true ) ) .
+						$thumb->toHtml( [ 'desc-link' => true ] ) .
 						'</td>' .
 						'<td style="vertical-align: top;">' .
 						"{$link} {$redirect} {$category} {$section} {$fileMatch}" .
@@ -799,12 +873,13 @@ class SpecialSearch extends SpecialPage {
 		$html = null;
 
 		$score = '';
-		if ( Hooks::run( 'ShowSearchHit', array(
+		$related = '';
+		if ( Hooks::run( 'ShowSearchHit', [
 			$this, $result, $terms,
 			&$link, &$redirect, &$section, &$extract,
 			&$score, &$size, &$date, &$related,
 			&$html
-		) ) ) {
+		] ) ) {
 			$html = "<li><div class='mw-search-result-heading'>" .
 				"{$link} {$redirect} {$category} {$section} {$fileMatch}</div> {$extract}\n" .
 				"<div class='mw-search-result-data'>{$size} - {$date}</div>" .
@@ -814,6 +889,23 @@ class SpecialSearch extends SpecialPage {
 		return $html;
 	}
 
+	/**
+	 * Extract custom captions from search-interwiki-custom message
+	 */
+	protected function getCustomCaptions() {
+		if ( is_null( $this->customCaptions ) ) {
+			$this->customCaptions = [];
+			// format per line <iwprefix>:<caption>
+			$customLines = explode( "\n", $this->msg( 'search-interwiki-custom' )->text() );
+			foreach ( $customLines as $line ) {
+				$parts = explode( ":", $line, 2 );
+				if ( count( $parts ) == 2 ) { // validate line
+					$this->customCaptions[$parts[0]] = $parts[1];
+				}
+			}
+		}
+	}
+
 	/**
 	 * Show results from other wikis
 	 *
@@ -830,25 +922,17 @@ class SpecialSearch extends SpecialPage {
 		$out .= "<ul class='mw-search-iwresults'>\n";
 
 		// work out custom project captions
-		$customCaptions = array();
-		// format per line <iwprefix>:<caption>
-		$customLines = explode( "\n", $this->msg( 'search-interwiki-custom' )->text() );
-		foreach ( $customLines as $line ) {
-			$parts = explode( ":", $line, 2 );
-			if ( count( $parts ) == 2 ) { // validate line
-				$customCaptions[$parts[0]] = $parts[1];
-			}
-		}
+		$this->getCustomCaptions();
 
 		if ( !is_array( $matches ) ) {
-			$matches = array( $matches );
+			$matches = [ $matches ];
 		}
 
 		foreach ( $matches as $set ) {
 			$prev = null;
 			$result = $set->next();
 			while ( $result ) {
-				$out .= $this->showInterwikiHit( $result, $prev, $query, $customCaptions );
+				$out .= $this->showInterwikiHit( $result, $prev, $query );
 				$prev = $result->getInterwikiPrefix();
 				$result = $set->next();
 			}
@@ -869,11 +953,10 @@ class SpecialSearch extends SpecialPage {
 	 * @param SearchResult $result
 	 * @param string $lastInterwiki
 	 * @param string $query
-	 * @param array $customCaptions Interwiki prefix -> caption
 	 *
 	 * @return string
 	 */
-	protected function showInterwikiHit( $result, $lastInterwiki, $query, $customCaptions ) {
+	protected function showInterwikiHit( $result, $lastInterwiki, $query ) {
 
 		if ( $result->isBrokenTitle() ) {
 			return '';
@@ -910,9 +993,9 @@ class SpecialSearch extends SpecialPage {
 		$out = "";
 		// display project name
 		if ( is_null( $lastInterwiki ) || $lastInterwiki != $title->getInterwiki() ) {
-			if ( array_key_exists( $title->getInterwiki(), $customCaptions ) ) {
+			if ( array_key_exists( $title->getInterwiki(), $this->customCaptions ) ) {
 				// captions from 'search-interwiki-custom'
-				$caption = $customCaptions[$title->getInterwiki()];
+				$caption = $this->customCaptions[$title->getInterwiki()];
 			} else {
 				// default is to show the hostname of the other wiki which might suck
 				// if there are many wikis on one hostname
@@ -924,11 +1007,11 @@ class SpecialSearch extends SpecialPage {
 			$searchLink = Linker::linkKnown(
 				$searchTitle,
 				$this->msg( 'search-interwiki-more' )->text(),
-				array(),
-				array(
+				[],
+				[
 					'search' => $query,
 					'fulltext' => 'Search'
-				)
+				]
 			);
 			$out .= "</ul><div class='mw-search-interwiki-project'><span class='mw-search-interwiki-more'>
 				{$searchLink}</span>{$caption}</div>\n<ul>";
@@ -950,8 +1033,8 @@ class SpecialSearch extends SpecialPage {
 		global $wgContLang;
 
 		// Groups namespaces into rows according to subject
-		$rows = array();
-		foreach ( SearchEngine::searchableNamespaces() as $namespace => $name ) {
+		$rows = [];
+		foreach ( $this->searchConfig->searchableNamespaces() as $namespace => $name ) {
 			$subject = MWNamespace::getSubject( $namespace );
 			if ( !array_key_exists( $subject, $rows ) ) {
 				$rows[$subject] = "";
@@ -989,9 +1072,9 @@ class SpecialSearch extends SpecialPage {
 			$namespaceTables .= Xml::closeElement( 'table' );
 		}
 
-		$showSections = array( 'namespaceTables' => $namespaceTables );
+		$showSections = [ 'namespaceTables' => $namespaceTables ];
 
-		Hooks::run( 'SpecialSearchPowerBox', array( &$showSections, $term, $opts ) );
+		Hooks::run( 'SpecialSearchPowerBox', [ &$showSections, $term, $opts ] );
 
 		$hidden = '';
 		foreach ( $opts as $key => $value ) {
@@ -1009,22 +1092,22 @@ class SpecialSearch extends SpecialPage {
 				false,
 				// The token goes here rather than in a hidden field so it
 				// is only sent when necessary (not every form submission).
-				array( 'value' => $user->getEditToken(
+				[ 'value' => $user->getEditToken(
 					'searchnamespace',
 					$this->getRequest()
-				) )
+				) ]
 			);
 		}
 
 		// Return final output
-		return Xml::openElement( 'fieldset', array( 'id' => 'mw-searchoptions' ) ) .
+		return Xml::openElement( 'fieldset', [ 'id' => 'mw-searchoptions' ] ) .
 			Xml::element( 'legend', null, $this->msg( 'powersearch-legend' )->text() ) .
 			Xml::tags( 'h4', null, $this->msg( 'powersearch-ns' )->parse() ) .
-			Xml::element( 'div', array( 'id' => 'mw-search-togglebox' ), '', false ) .
-			Xml::element( 'div', array( 'class' => 'divider' ), '', false ) .
-			implode( Xml::element( 'div', array( 'class' => 'divider' ), '', false ), $showSections ) .
+			Xml::element( 'div', [ 'id' => 'mw-search-togglebox' ], '', false ) .
+			Xml::element( 'div', [ 'class' => 'divider' ], '', false ) .
+			implode( Xml::element( 'div', [ 'class' => 'divider' ], '', false ), $showSections ) .
 			$hidden .
-			Xml::element( 'div', array( 'class' => 'divider' ), '', false ) .
+			Xml::element( 'div', [ 'class' => 'divider' ], '', false ) .
 			$remember .
 			Xml::closeElement( 'fieldset' );
 	}
@@ -1034,35 +1117,35 @@ class SpecialSearch extends SpecialPage {
 	 */
 	protected function getSearchProfiles() {
 		// Builds list of Search Types (profiles)
-		$nsAllSet = array_keys( SearchEngine::searchableNamespaces() );
-
-		$profiles = array(
-			'default' => array(
+		$nsAllSet = array_keys( $this->searchConfig->searchableNamespaces() );
+		$defaultNs = $this->searchConfig->defaultNamespaces();
+		$profiles = [
+			'default' => [
 				'message' => 'searchprofile-articles',
 				'tooltip' => 'searchprofile-articles-tooltip',
-				'namespaces' => SearchEngine::defaultNamespaces(),
-				'namespace-messages' => SearchEngine::namespacesAsText(
-					SearchEngine::defaultNamespaces()
+				'namespaces' => $defaultNs,
+				'namespace-messages' => $this->searchConfig->namespacesAsText(
+					$defaultNs
 				),
-			),
-			'images' => array(
+			],
+			'images' => [
 				'message' => 'searchprofile-images',
 				'tooltip' => 'searchprofile-images-tooltip',
-				'namespaces' => array( NS_FILE ),
-			),
-			'all' => array(
+				'namespaces' => [ NS_FILE ],
+			],
+			'all' => [
 				'message' => 'searchprofile-everything',
 				'tooltip' => 'searchprofile-everything-tooltip',
 				'namespaces' => $nsAllSet,
-			),
-			'advanced' => array(
+			],
+			'advanced' => [
 				'message' => 'searchprofile-advanced',
 				'tooltip' => 'searchprofile-advanced-tooltip',
 				'namespaces' => self::NAMESPACES_CURRENT,
-			)
-		);
+			]
+		];
 
-		Hooks::run( 'SpecialSearchProfiles', array( &$profiles ) );
+		Hooks::run( 'SpecialSearchProfiles', [ &$profiles ] );
 
 		foreach ( $profiles as &$data ) {
 			if ( !is_array( $data['namespaces'] ) ) {
@@ -1079,7 +1162,7 @@ class SpecialSearch extends SpecialPage {
 	 * @return string
 	 */
 	protected function searchProfileTabs( $term ) {
-		$out = Xml::openElement( 'div', array( 'class' => 'mw-search-profile-tabs' ) );
+		$out = Xml::openElement( 'div', [ 'class' => 'mw-search-profile-tabs' ] );
 
 		$bareterm = $term;
 		if ( $this->startsWithImage( $term ) ) {
@@ -1091,11 +1174,11 @@ class SpecialSearch extends SpecialPage {
 		$lang = $this->getLanguage();
 
 		// Outputs XML for Search Types
-		$out .= Xml::openElement( 'div', array( 'class' => 'search-types' ) );
+		$out .= Xml::openElement( 'div', [ 'class' => 'search-types' ] );
 		$out .= Xml::openElement( 'ul' );
 		foreach ( $profiles as $id => $profile ) {
 			if ( !isset( $profile['parameters'] ) ) {
-				$profile['parameters'] = array();
+				$profile['parameters'] = [];
 			}
 			$profile['parameters']['profile'] = $id;
 
@@ -1103,12 +1186,12 @@ class SpecialSearch extends SpecialPage {
 				$lang->commaList( $profile['namespace-messages'] ) : null;
 			$out .= Xml::tags(
 				'li',
-				array(
+				[
 					'class' => $this->profile === $id ? 'current' : 'normal'
-				),
+				],
 				$this->makeSearchLink(
 					$bareterm,
-					array(),
+					[],
 					$this->msg( $profile['message'] )->text(),
 					$this->msg( $profile['tooltip'], $tooltipParam )->text(),
 					$profile['parameters']
@@ -1117,7 +1200,7 @@ class SpecialSearch extends SpecialPage {
 		}
 		$out .= Xml::closeElement( 'ul' );
 		$out .= Xml::closeElement( 'div' );
-		$out .= Xml::element( 'div', array( 'style' => 'clear:both' ), '', false );
+		$out .= Xml::element( 'div', [ 'style' => 'clear:both' ], '', false );
 		$out .= Xml::closeElement( 'div' );
 
 		return $out;
@@ -1129,14 +1212,14 @@ class SpecialSearch extends SpecialPage {
 	 */
 	protected function searchOptions( $term ) {
 		$out = '';
-		$opts = array();
+		$opts = [];
 		$opts['profile'] = $this->profile;
 
 		if ( $this->isPowerSearch() ) {
 			$out .= $this->powerSearchBox( $term, $opts );
 		} else {
 			$form = '';
-			Hooks::run( 'SpecialSearchProfileForm', array( $this, &$form, $this->profile, $term, $opts ) );
+			Hooks::run( 'SpecialSearchProfileForm', [ $this, &$form, $this->profile, $term, $opts ] );
 			$out .= $form;
 		}
 
@@ -1150,21 +1233,24 @@ class SpecialSearch extends SpecialPage {
 	 * @return string
 	 */
 	protected function shortDialog( $term, $resultsShown, $totalNum ) {
-		$out = Html::hidden( 'title', $this->getPageTitle()->getPrefixedText() );
-		$out .= Html::hidden( 'profile', $this->profile ) . "\n";
-		// Term box
-		$out .= Html::input( 'search', $term, 'search', array(
-			'id' => $this->isPowerSearch() ? 'powerSearchText' : 'searchText',
-			'size' => '50',
+		$searchWidget = new MediaWiki\Widget\SearchInputWidget( [
+			'id' => 'searchText',
+			'name' => 'search',
 			'autofocus' => trim( $term ) === '',
-			'class' => 'mw-ui-input mw-ui-input-inline',
-		) ) . "\n";
-		$out .= Html::hidden( 'fulltext', 'Search' ) . "\n";
-		$out .= Html::submitButton(
-			$this->msg( 'searchbutton' )->text(),
-			array( 'class' => 'mw-ui-button mw-ui-progressive' ),
-			array( 'mw-ui-progressive' )
-		) . "\n";
+			'value' => $term,
+			'dataLocation' => 'content',
+		] );
+
+		$out =
+			Html::hidden( 'title', $this->getPageTitle()->getPrefixedText() ) .
+			Html::hidden( 'profile', $this->profile ) .
+			Html::hidden( 'fulltext', 'Search' ) .
+			$searchWidget .
+			new OOUI\ButtonInputWidget( [
+				'type' => 'submit',
+				'label' => $this->msg( 'searchbutton' )->text(),
+				'flags' => [ 'progressive', 'primary' ],
+			] );
 
 		// Results-info
 		if ( $totalNum > 0 && $this->offset < $totalNum ) {
@@ -1172,8 +1258,8 @@ class SpecialSearch extends SpecialPage {
 				->numParams( $this->offset + 1, $this->offset + $resultsShown, $totalNum )
 				->numParams( $resultsShown )
 				->parse();
-			$out .= Xml::tags( 'div', array( 'class' => 'results-info' ), $top ) .
-				Xml::element( 'div', array( 'style' => 'clear:both' ), '', false );
+			$out .= Xml::tags( 'div', [ 'class' => 'results-info' ], $top ) .
+				Xml::element( 'div', [ 'style' => 'clear:both' ], '', false );
 		}
 
 		return $out;
@@ -1189,26 +1275,26 @@ class SpecialSearch extends SpecialPage {
 	 * @param array $params Query string parameters
 	 * @return string HTML fragment
 	 */
-	protected function makeSearchLink( $term, $namespaces, $label, $tooltip, $params = array() ) {
+	protected function makeSearchLink( $term, $namespaces, $label, $tooltip, $params = [] ) {
 		$opt = $params;
 		foreach ( $namespaces as $n ) {
 			$opt['ns' . $n] = 1;
 		}
 
 		$stParams = array_merge(
-			array(
+			[
 				'search' => $term,
 				'fulltext' => $this->msg( 'search' )->text()
-			),
+			],
 			$opt
 		);
 
 		return Xml::element(
 			'a',
-			array(
+			[
 				'href' => $this->getPageTitle()->getLocalURL( $stParams ),
 				'title' => $tooltip
-			),
+			],
 			$label
 		);
 	}
@@ -1256,7 +1342,8 @@ class SpecialSearch extends SpecialPage {
 	public function getSearchEngine() {
 		if ( $this->searchEngine === null ) {
 			$this->searchEngine = $this->searchEngineType ?
-				SearchEngine::create( $this->searchEngineType ) : SearchEngine::create();
+				MediaWikiServices::getInstance()->getSearchEngineFactory()->create( $this->searchEngineType ) :
+				MediaWikiServices::getInstance()->newSearchEngine();
 		}
 
 		return $this->searchEngine;
