@@ -44,22 +44,22 @@ class UnwatchedpagesPage extends QueryPage {
 	}
 
 	public function getQueryInfo() {
-		return array(
-			'tables' => array( 'page', 'watchlist' ),
-			'fields' => array(
+		return [
+			'tables' => [ 'page', 'watchlist' ],
+			'fields' => [
 				'namespace' => 'page_namespace',
 				'title' => 'page_title',
 				'value' => 'page_namespace'
-			),
-			'conds' => array(
+			],
+			'conds' => [
 				'wl_title IS NULL',
 				'page_is_redirect' => 0,
 				"page_namespace != '" . NS_MEDIAWIKI . "'"
-			),
-			'join_conds' => array( 'watchlist' => array(
-				'LEFT JOIN', array( 'wl_title = page_title',
-					'wl_namespace = page_namespace' ) ) )
-		);
+			],
+			'join_conds' => [ 'watchlist' => [
+				'LEFT JOIN', [ 'wl_title = page_title',
+					'wl_namespace = page_namespace' ] ] ]
+		];
 	}
 
 	function sortDescending() {
@@ -67,7 +67,7 @@ class UnwatchedpagesPage extends QueryPage {
 	}
 
 	function getOrderFields() {
-		return array( 'page_namespace', 'page_title' );
+		return [ 'page_namespace', 'page_title' ];
 	}
 
 	/**
@@ -89,19 +89,18 @@ class UnwatchedpagesPage extends QueryPage {
 
 		$nt = Title::makeTitleSafe( $result->namespace, $result->title );
 		if ( !$nt ) {
-			return Html::element( 'span', array( 'class' => 'mw-invalidtitle' ),
+			return Html::element( 'span', [ 'class' => 'mw-invalidtitle' ],
 				Linker::getInvalidTitleDescription( $this->getContext(), $result->namespace, $result->title ) );
 		}
 
 		$text = $wgContLang->convert( $nt->getPrefixedText() );
 
 		$plink = Linker::linkKnown( $nt, htmlspecialchars( $text ) );
-		$token = WatchAction::getWatchToken( $nt, $this->getUser() );
 		$wlink = Linker::linkKnown(
 			$nt,
 			$this->msg( 'watch' )->escaped(),
-			array( 'class' => 'mw-watch-link' ),
-			array( 'action' => 'watch', 'token' => $token )
+			[ 'class' => 'mw-watch-link' ],
+			[ 'action' => 'watch' ]
 		);
 
 		return $this->getLanguage()->specialList( $plink, $wlink );
