@@ -38,6 +38,10 @@ class SpecialUpload extends SpecialPage {
 		parent::__construct( 'Upload', 'upload' );
 	}
 
+	public function doesWrites() {
+		return true;
+	}
+
 	/** Misc variables **/
 
 	/** @var WebRequest|FauxRequest The request this form is supposed to handle */
@@ -176,6 +180,11 @@ class SpecialUpload extends SpecialPage {
 			throw new UserBlockedError( $user->getBlock() );
 		}
 
+		// Global blocks
+		if ( $user->isBlockedGlobally() ) {
+			throw new UserBlockedError( $user->getGlobalBlock() );
+		}
+
 		# Check whether we actually want to allow changing stuff
 		$this->checkReadOnly();
 
@@ -197,7 +206,7 @@ class SpecialUpload extends SpecialPage {
 			$this->processUpload();
 		} else {
 			# Backwards compatibility hook
-			if ( !Hooks::run( 'UploadForm:initial', array( &$this ) ) ) {
+			if ( !Hooks::run( 'UploadForm:initial', [ &$this ] ) ) {
 				wfDebug( "Hook 'UploadForm:initial' broke output of the upload form\n" );
 
 				return;
@@ -241,7 +250,7 @@ class SpecialUpload extends SpecialPage {
 		# Initialize form
 		$context = new DerivativeContext( $this->getContext() );
 		$context->setTitle( $this->getPageTitle() ); // Remove subpage
-		$form = new UploadForm( array(
+		$form = new UploadForm( [
 			'watch' => $this->getWatchCheck(),
 			'forreupload' => $this->mForReUpload,
 			'sessionkey' => $sessionKey,
@@ -252,7 +261,7 @@ class SpecialUpload extends SpecialPage {
 			'texttop' => $this->uploadFormTextTop,
 			'textaftersummary' => $this->uploadFormTextAfterSummary,
 			'destfile' => $this->mDesiredDestName,
-		), $context );
+		], $context );
 
 		# Check the token, but only if necessary
 		if (
@@ -263,23 +272,23 @@ class SpecialUpload extends SpecialPage {
 		}
 
 		# Give a notice if the user is uploading a file that has been deleted or moved
-		# Note that this is independent from the message 'filewasdeleted' that requires JS
+		# Note that this is independent from the message 'filewasdeleted'
 		$desiredTitleObj = Title::makeTitleSafe( NS_FILE, $this->mDesiredDestName );
 		$delNotice = ''; // empty by default
 		if ( $desiredTitleObj instanceof Title && !$desiredTitleObj->exists() ) {
-			LogEventsList::showLogExtract( $delNotice, array( 'delete', 'move' ),
+			LogEventsList::showLogExtract( $delNotice, [ 'delete', 'move' ],
 				$desiredTitleObj,
-				'', array( 'lim' => 10,
-					'conds' => array( "log_action != 'revision'" ),
+				'', [ 'lim' => 10,
+					'conds' => [ "log_action != 'revision'" ],
 					'showIfEmpty' => false,
-					'msgKey' => array( 'upload-recreate-warning' ) )
+					'msgKey' => [ 'upload-recreate-warning' ] ]
 			);
 		}
 		$form->addPreText( $delNotice );
 
 		# Add text to form
 		$form->addPreText( '<div id="uploadtext">' .
-			$this->msg( 'uploadtext', array( $this->mDesiredDestName ) )->parseAsBlock() .
+			$this->msg( 'uploadtext', [ $this->mDesiredDestName ] )->parseAsBlock() .
 			'</div>' );
 		# Add upload error message
 		$form->addPreText( $message );
@@ -358,14 +367,30 @@ class SpecialUpload extends SpecialPage {
 
 		$sessionKey = $this->mUpload->stashSession();
 
+		// Add styles for the warning, reused from the live preview
+		$this->getOutput()->addModuleStyles( 'mediawiki.special.upload' );
+
 		$warningHtml = '<h2>' . $this->msg( 'uploadwarning' )->escaped() . "</h2>\n"
-			. '<div class="warningbox"><ul>';
+			. '<div class="mw-destfile-warning"><ul>';
 		foreach ( $warnings as $warning => $args ) {
 			if ( $warning == 'badfilename' ) {
 				$this->mDesiredDestName = Title::makeTitle( NS_FILE, $args )->getText();
 			}
 			if ( $warning == 'exists' ) {
 				$msg = "\t<li>" . self::getExistsWarning( $args ) . "</li>\n";
+			} elseif ( $warning == 'was-deleted' ) {
+				# If the file existed before and was deleted, warn the user of this
+				$ltitle = SpecialPage::getTitleFor( 'Log' );
+				$llink = Linker::linkKnown(
+					$ltitle,
+					wfMessage( 'deletionlog' )->escaped(),
+					[],
+					[
+						'type' => 'delete',
+						'page' => Title::makeTitle( NS_FILE, $args )->getPrefixedText(),
+					]
+				);
+				$msg = "\t<li>" . wfMessage( 'filewasdeleted' )->rawParams( $llink )->parse() . "</li>\n";
 			} elseif ( $warning == 'duplicate' ) {
 				$msg = $this->getDupeWarning( $args );
 			} elseif ( $warning == 'duplicate-archive' ) {
@@ -379,9 +404,9 @@ class SpecialUpload extends SpecialPage {
 				}
 			} else {
 				if ( $args === true ) {
-					$args = array();
+					$args = [];
 				} elseif ( !is_array( $args ) ) {
-					$args = array( $args );
+					$args = [ $args ];
 				}
 				$msg = "\t<li>" . $this->msg( $warning, $args )->parse() . "</li>\n";
 			}
@@ -392,8 +417,14 @@ class SpecialUpload extends SpecialPage {
 
 		$form = $this->getUploadForm( $warningHtml, $sessionKey, /* $hideIgnoreWarning */ true );
 		$form->setSubmitText( $this->msg( 'upload-tryagain' )->text() );
-		$form->addButton( 'wpUploadIgnoreWarning', $this->msg( 'ignorewarning' )->text() );
-		$form->addButton( 'wpCancelUpload', $this->msg( 'reuploaddesc' )->text() );
+		$form->addButton( [
+			'name' => 'wpUploadIgnoreWarning',
+			'value' => $this->msg( 'ignorewarning' )->text()
+		] );
+		$form->addButton( [
+			'name' => 'wpCancelUpload',
+			'value' => $this->msg( 'reuploaddesc' )->text()
+		] );
 
 		$this->showUploadForm( $form );
 
@@ -425,7 +456,7 @@ class SpecialUpload extends SpecialPage {
 			return;
 		}
 
-		if ( !Hooks::run( 'UploadForm:BeforeProcessing', array( &$this ) ) ) {
+		if ( !Hooks::run( 'UploadForm:BeforeProcessing', [ &$this ] ) ) {
 			wfDebug( "Hook 'UploadForm:BeforeProcessing' broke processing the file.\n" );
 			// This code path is deprecated. If you want to break upload processing
 			// do so by hooking into the appropriate hooks in UploadBase::verifyUpload
@@ -478,11 +509,29 @@ class SpecialUpload extends SpecialPage {
 			$pageText = false;
 		}
 
+		$changeTags = $this->getRequest()->getVal( 'wpChangeTags' );
+		if ( is_null( $changeTags ) || $changeTags === '' ) {
+			$changeTags = [];
+		} else {
+			$changeTags = array_filter( array_map( 'trim', explode( ',', $changeTags ) ) );
+		}
+
+		if ( $changeTags ) {
+			$changeTagsStatus = ChangeTags::canAddTagsAccompanyingChange(
+				$changeTags, $this->getUser() );
+			if ( !$changeTagsStatus->isOK() ) {
+				$this->showUploadError( $this->getOutput()->parse( $changeTagsStatus->getWikiText() ) );
+
+				return;
+			}
+		}
+
 		$status = $this->mUpload->performUpload(
 			$this->mComment,
 			$pageText,
 			$this->mWatchthis,
-			$this->getUser()
+			$this->getUser(),
+			$changeTags
 		);
 
 		if ( !$status->isGood() ) {
@@ -493,7 +542,7 @@ class SpecialUpload extends SpecialPage {
 
 		// Success, redirect to description page
 		$this->mUploadSuccessful = true;
-		Hooks::run( 'SpecialUploadComplete', array( &$this ) );
+		Hooks::run( 'SpecialUploadComplete', [ &$this ] );
 		$this->getOutput()->redirect( $this->mLocalFile->getTitle()->getFullURL() );
 	}
 
@@ -514,13 +563,13 @@ class SpecialUpload extends SpecialPage {
 			$config = ConfigFactory::getDefaultInstance()->makeConfig( 'main' );
 		}
 
-		$msg = array();
+		$msg = [];
 		$forceUIMsgAsContentMsg = (array)$config->get( 'ForceUIMsgAsContentMsg' );
 		/* These messages are transcluded into the actual text of the description page.
 		 * Thus, forcing them as content messages makes the upload to produce an int: template
 		 * instead of hardcoding it there in the uploader language.
 		 */
-		foreach ( array( 'license-header', 'filedesc', 'filestatus', 'filesource' ) as $msgName ) {
+		foreach ( [ 'license-header', 'filedesc', 'filestatus', 'filesource' ] as $msgName ) {
 			if ( in_array( $msgName, $forceUIMsgAsContentMsg ) ) {
 				$msg[$msgName] = "{{int:$msgName}}";
 			} else {
@@ -581,7 +630,8 @@ class SpecialUpload extends SpecialPage {
 			return false;
 		} else {
 			// New page should get watched if that's our option.
-			return $this->getUser()->getOption( 'watchcreations' );
+			return $this->getUser()->getOption( 'watchcreations' ) ||
+				$this->getUser()->getOption( 'watchuploads' );
 		}
 	}
 
@@ -719,19 +769,6 @@ class SpecialUpload extends SpecialPage {
 			$warning = wfMessage( 'file-thumbnail-no', $badPart )->parse();
 		} elseif ( $exists['warning'] == 'bad-prefix' ) {
 			$warning = wfMessage( 'filename-bad-prefix', $exists['prefix'] )->parse();
-		} elseif ( $exists['warning'] == 'was-deleted' ) {
-			# If the file existed before and was deleted, warn the user of this
-			$ltitle = SpecialPage::getTitleFor( 'Log' );
-			$llink = Linker::linkKnown(
-				$ltitle,
-				wfMessage( 'deletionlog' )->escaped(),
-				array(),
-				array(
-					'type' => 'delete',
-					'page' => $filename
-				)
-			);
-			$warning = wfMessage( 'filewasdeleted' )->rawParams( $llink )->parseAsBlock();
 		}
 
 		return $warning;
@@ -792,11 +829,11 @@ class UploadForm extends HTMLForm {
 
 	protected $mSourceIds;
 
-	protected $mMaxFileSize = array();
+	protected $mMaxFileSize = [];
 
-	protected $mMaxUploadSize = array();
+	protected $mMaxUploadSize = [];
 
-	public function __construct( array $options = array(), IContextSource $context = null ) {
+	public function __construct( array $options = [], IContextSource $context = null ) {
 		if ( $context instanceof IContextSource ) {
 			$this->setContext( $context );
 		}
@@ -822,16 +859,17 @@ class UploadForm extends HTMLForm {
 			+ $this->getDescriptionSection()
 			+ $this->getOptionsSection();
 
-		Hooks::run( 'UploadFormInitDescriptor', array( &$descriptor ) );
+		Hooks::run( 'UploadFormInitDescriptor', [ &$descriptor ] );
 		parent::__construct( $descriptor, $context, 'upload' );
 
 		# Add a link to edit MediaWik:Licenses
 		if ( $this->getUser()->isAllowed( 'editinterface' ) ) {
+			$this->getOutput()->addModuleStyles( 'mediawiki.special' );
 			$licensesLink = Linker::linkKnown(
 				$this->msg( 'licenses' )->inContentLanguage()->getTitle(),
 				$this->msg( 'licenses-edit' )->escaped(),
-				array(),
-				array( 'action' => 'edit' )
+				[],
+				[ 'action' => 'edit' ]
 			);
 			$editLicenses = '<p class="mw-upload-editlicenses">' . $licensesLink . '</p>';
 			$this->addFooterText( $editLicenses, 'description' );
@@ -845,7 +883,7 @@ class UploadForm extends HTMLForm {
 		$this->setId( 'mw-upload-form' );
 
 		# Build a list of IDs for javascript insertion
-		$this->mSourceIds = array();
+		$this->mSourceIds = [];
 		foreach ( $sourceDescriptor as $field ) {
 			if ( !empty( $field['id'] ) ) {
 				$this->mSourceIds[] = $field['id'];
@@ -861,16 +899,16 @@ class UploadForm extends HTMLForm {
 	 */
 	protected function getSourceSection() {
 		if ( $this->mSessionKey ) {
-			return array(
-				'SessionKey' => array(
+			return [
+				'SessionKey' => [
 					'type' => 'hidden',
 					'default' => $this->mSessionKey,
-				),
-				'SourceType' => array(
+				],
+				'SourceType' => [
 					'type' => 'hidden',
 					'default' => 'Stash',
-				),
-			);
+				],
+			];
 		}
 
 		$canUploadByUrl = UploadFromUrl::isEnabled()
@@ -879,25 +917,20 @@ class UploadForm extends HTMLForm {
 		$radio = $canUploadByUrl;
 		$selectedSourceType = strtolower( $this->getRequest()->getText( 'wpSourceType', 'File' ) );
 
-		$descriptor = array();
+		$descriptor = [];
 		if ( $this->mTextTop ) {
-			$descriptor['UploadFormTextTop'] = array(
+			$descriptor['UploadFormTextTop'] = [
 				'type' => 'info',
 				'section' => 'source',
 				'default' => $this->mTextTop,
 				'raw' => true,
-			);
+			];
 		}
 
-		$this->mMaxUploadSize['file'] = UploadBase::getMaxUploadSize( 'file' );
-		# Limit to upload_max_filesize unless we are running under HipHop and
-		# that setting doesn't exist
-		if ( !wfIsHHVM() ) {
-			$this->mMaxUploadSize['file'] = min( $this->mMaxUploadSize['file'],
-				wfShorthandToInteger( ini_get( 'upload_max_filesize' ) ),
-				wfShorthandToInteger( ini_get( 'post_max_size' ) )
-			);
-		}
+		$this->mMaxUploadSize['file'] = min(
+			UploadBase::getMaxUploadSize( 'file' ),
+			UploadBase::getMaxPhpUploadSize()
+		);
 
 		$help = $this->msg( 'upload-maxfilesize',
 				$this->getContext()->getLanguage()->formatSize( $this->mMaxUploadSize['file'] )
@@ -910,7 +943,7 @@ class UploadForm extends HTMLForm {
 			$help .= $this->msg( 'upload_source_file' )->parse();
 		}
 
-		$descriptor['UploadFile'] = array(
+		$descriptor['UploadFile'] = [
 			'class' => 'UploadSourceField',
 			'section' => 'source',
 			'type' => 'file',
@@ -921,11 +954,11 @@ class UploadForm extends HTMLForm {
 			'radio' => &$radio,
 			'help' => $help,
 			'checked' => $selectedSourceType == 'file',
-		);
+		];
 
 		if ( $canUploadByUrl ) {
 			$this->mMaxUploadSize['url'] = UploadBase::getMaxUploadSize( 'url' );
-			$descriptor['UploadFileURL'] = array(
+			$descriptor['UploadFileURL'] = [
 				'class' => 'UploadSourceField',
 				'section' => 'source',
 				'id' => 'wpUploadFileURL',
@@ -939,16 +972,16 @@ class UploadForm extends HTMLForm {
 					$this->msg( 'word-separator' )->escaped() .
 					$this->msg( 'upload_source_url' )->parse(),
 				'checked' => $selectedSourceType == 'url',
-			);
+			];
 		}
-		Hooks::run( 'UploadFormSourceDescriptors', array( &$descriptor, &$radio, $selectedSourceType ) );
+		Hooks::run( 'UploadFormSourceDescriptors', [ &$descriptor, &$radio, $selectedSourceType ] );
 
-		$descriptor['Extensions'] = array(
+		$descriptor['Extensions'] = [
 			'type' => 'info',
 			'section' => 'source',
 			'default' => $this->getExtensionsMessage(),
 			'raw' => true,
-		);
+		];
 
 		return $descriptor;
 	}
@@ -1017,18 +1050,18 @@ class UploadForm extends HTMLForm {
 			if ( $file ) {
 				global $wgContLang;
 
-				$mto = $file->transform( array( 'width' => 120 ) );
+				$mto = $file->transform( [ 'width' => 120 ] );
 				$this->addHeaderText(
 					'<div class="thumb t' . $wgContLang->alignEnd() . '">' .
-					Html::element( 'img', array(
+					Html::element( 'img', [
 						'src' => $mto->getUrl(),
 						'class' => 'thumbimage',
-					) ) . '</div>', 'description' );
+					] ) . '</div>', 'description' );
 			}
 		}
 
-		$descriptor = array(
-			'DestFile' => array(
+		$descriptor = [
+			'DestFile' => [
 				'type' => 'text',
 				'section' => 'description',
 				'id' => 'wpDestFile',
@@ -1037,8 +1070,8 @@ class UploadForm extends HTMLForm {
 				'default' => $this->mDestFile,
 				# @todo FIXME: Hack to work around poor handling of the 'default' option in HTMLForm
 				'nodata' => strval( $this->mDestFile ) !== '',
-			),
-			'UploadDescription' => array(
+			],
+			'UploadDescription' => [
 				'type' => 'textarea',
 				'section' => 'description',
 				'id' => 'wpUploadDescription',
@@ -1048,50 +1081,50 @@ class UploadForm extends HTMLForm {
 				'default' => $this->mComment,
 				'cols' => $this->getUser()->getIntOption( 'cols' ),
 				'rows' => 8,
-			)
-		);
+			]
+		];
 		if ( $this->mTextAfterSummary ) {
-			$descriptor['UploadFormTextAfterSummary'] = array(
+			$descriptor['UploadFormTextAfterSummary'] = [
 				'type' => 'info',
 				'section' => 'description',
 				'default' => $this->mTextAfterSummary,
 				'raw' => true,
-			);
+			];
 		}
 
-		$descriptor += array(
-			'EditTools' => array(
+		$descriptor += [
+			'EditTools' => [
 				'type' => 'edittools',
 				'section' => 'description',
 				'message' => 'edittools-upload',
-			)
-		);
+			]
+		];
 
 		if ( $this->mForReUpload ) {
 			$descriptor['DestFile']['readonly'] = true;
 		} else {
-			$descriptor['License'] = array(
+			$descriptor['License'] = [
 				'type' => 'select',
 				'class' => 'Licenses',
 				'section' => 'description',
 				'id' => 'wpLicense',
 				'label-message' => 'license',
-			);
+			];
 		}
 
 		if ( $config->get( 'UseCopyrightUpload' ) ) {
-			$descriptor['UploadCopyStatus'] = array(
+			$descriptor['UploadCopyStatus'] = [
 				'type' => 'text',
 				'section' => 'description',
 				'id' => 'wpUploadCopyStatus',
 				'label-message' => 'filestatus',
-			);
-			$descriptor['UploadSource'] = array(
+			];
+			$descriptor['UploadSource'] = [
 				'type' => 'text',
 				'section' => 'description',
 				'id' => 'wpUploadSource',
 				'label-message' => 'filesource',
-			);
+			];
 		}
 
 		return $descriptor;
@@ -1106,37 +1139,37 @@ class UploadForm extends HTMLForm {
 	protected function getOptionsSection() {
 		$user = $this->getUser();
 		if ( $user->isLoggedIn() ) {
-			$descriptor = array(
-				'Watchthis' => array(
+			$descriptor = [
+				'Watchthis' => [
 					'type' => 'check',
 					'id' => 'wpWatchthis',
 					'label-message' => 'watchthisupload',
 					'section' => 'options',
 					'default' => $this->mWatch,
-				)
-			);
+				]
+			];
 		}
 		if ( !$this->mHideIgnoreWarning ) {
-			$descriptor['IgnoreWarning'] = array(
+			$descriptor['IgnoreWarning'] = [
 				'type' => 'check',
 				'id' => 'wpIgnoreWarning',
 				'label-message' => 'ignorewarnings',
 				'section' => 'options',
-			);
+			];
 		}
 
-		$descriptor['DestFileWarningAck'] = array(
+		$descriptor['DestFileWarningAck'] = [
 			'type' => 'hidden',
 			'id' => 'wpDestFileWarningAck',
 			'default' => $this->mDestWarningAck ? '1' : '',
-		);
+		];
 
 		if ( $this->mForReUpload ) {
-			$descriptor['ForReUpload'] = array(
+			$descriptor['ForReUpload'] = [
 				'type' => 'hidden',
 				'id' => 'wpForReUpload',
 				'default' => '1',
-			);
+			];
 		}
 
 		return $descriptor;
@@ -1161,7 +1194,7 @@ class UploadForm extends HTMLForm {
 			$config->get( 'AjaxLicensePreview' ) && $config->get( 'EnableAPI' );
 		$this->mMaxUploadSize['*'] = UploadBase::getMaxUploadSize();
 
-		$scriptVars = array(
+		$scriptVars = [
 			'wgAjaxUploadDestCheck' => $useAjaxDestCheck,
 			'wgAjaxLicensePreview' => $useAjaxLicensePreview,
 			'wgUploadAutoFill' => !$this->mForReUpload &&
@@ -1175,15 +1208,15 @@ class UploadForm extends HTMLForm {
 			'wgCapitalizeUploads' => MWNamespace::isCapitalized( NS_FILE ),
 			'wgMaxUploadSize' => $this->mMaxUploadSize,
 			'wgFileCanRotate' => SpecialUpload::rotationEnabled(),
-		);
+		];
 
 		$out = $this->getOutput();
 		$out->addJsConfigVars( $scriptVars );
 
-		$out->addModules( array(
+		$out->addModules( [
 			'mediawiki.action.edit', // For <charinsert> support
 			'mediawiki.special.upload', // Extras for thumbnail and license preview.
-		) );
+		] );
 	}
 
 	/**
@@ -1205,9 +1238,9 @@ class UploadSourceField extends HTMLTextField {
 	 * @param array $cellAttributes
 	 * @return string
 	 */
-	function getLabelHtml( $cellAttributes = array() ) {
+	function getLabelHtml( $cellAttributes = [] ) {
 		$id = $this->mParams['id'];
-		$label = Html::rawElement( 'label', array( 'for' => $id ), $this->mLabel );
+		$label = Html::rawElement( 'label', [ 'for' => $id ], $this->mLabel );
 
 		if ( !empty( $this->mParams['radio'] ) ) {
 			if ( isset( $this->mParams['radio-id'] ) ) {
@@ -1218,12 +1251,12 @@ class UploadSourceField extends HTMLTextField {
 				$radioId = 'wpSourceType' . $this->mParams['upload-type'];
 			}
 
-			$attribs = array(
+			$attribs = [
 				'name' => 'wpSourceType',
 				'type' => 'radio',
 				'id' => $radioId,
 				'value' => $this->mParams['upload-type'],
-			);
+			];
 
 			if ( !empty( $this->mParams['checked'] ) ) {
 				$attribs['checked'] = 'checked';
@@ -1232,7 +1265,7 @@ class UploadSourceField extends HTMLTextField {
 			$label .= Html::element( 'input', $attribs );
 		}
 
-		return Html::rawElement( 'td', array( 'class' => 'mw-label' ) + $cellAttributes, $label );
+		return Html::rawElement( 'td', [ 'class' => 'mw-label' ] + $cellAttributes, $label );
 	}
 
 	/**
