@@ -38,12 +38,6 @@ class SpecialVersion extends SpecialPage {
 
 	protected static $extensionTypes = false;
 
-	protected static $viewvcUrls = array(
-		'svn+ssh://svn.wikimedia.org/svnroot/mediawiki' => 'http://svn.wikimedia.org/viewvc/mediawiki',
-		'http://svn.wikimedia.org/svnroot/mediawiki' => 'http://svn.wikimedia.org/viewvc/mediawiki',
-		'https://svn.wikimedia.org/svnroot/mediawiki' => 'https://svn.wikimedia.org/viewvc/mediawiki',
-	);
-
 	public function __construct() {
 		parent::__construct( 'Version' );
 	}
@@ -94,10 +88,10 @@ class SpecialVersion extends SpecialPage {
 						if ( substr( $file, -4 ) === '.txt' ) {
 							$wikiText = Html::element(
 								'pre',
-								array(
+								[
 									'lang' => 'en',
 									'dir' => 'ltr',
-								),
+								],
 								$wikiText
 							);
 						}
@@ -118,10 +112,10 @@ class SpecialVersion extends SpecialPage {
 						$wikiText = file_get_contents( $file );
 						$wikiText = Html::element(
 							'pre',
-							array(
+							[
 								'lang' => 'en',
 								'dir' => 'ltr',
-							),
+							],
 							$wikiText
 						);
 					}
@@ -132,13 +126,13 @@ class SpecialVersion extends SpecialPage {
 				break;
 
 			default:
-				$out->addModules( 'mediawiki.special.version' );
+				$out->addModuleStyles( 'mediawiki.special.version' );
 				$out->addWikiText(
 					$this->getMediaWikiCredits() .
 					$this->softwareInformation() .
 					$this->getEntryPointInfo()
 				);
-				$out->addHtml(
+				$out->addHTML(
 					$this->getSkinCredits() .
 					$this->getExtensionCredits() .
 					$this->getExternalLibraries() .
@@ -160,7 +154,7 @@ class SpecialVersion extends SpecialPage {
 	private static function getMediaWikiCredits() {
 		$ret = Xml::element(
 			'h2',
-			array( 'id' => 'mw-version-license' ),
+			[ 'id' => 'mw-version-license' ],
 			wfMessage( 'version-license' )->text()
 		);
 
@@ -183,7 +177,7 @@ class SpecialVersion extends SpecialPage {
 		global $wgLang;
 
 		if ( defined( 'MEDIAWIKI_INSTALL' ) ) {
-			$othersLink = '[//www.mediawiki.org/wiki/Special:Version/Credits ' .
+			$othersLink = '[https://www.mediawiki.org/wiki/Special:Version/Credits ' .
 				wfMessage( 'version-poweredby-others' )->text() . ']';
 		} else {
 			$othersLink = '[[Special:Version/Credits|' .
@@ -193,7 +187,7 @@ class SpecialVersion extends SpecialPage {
 		$translatorsLink = '[//translatewiki.net/wiki/Translating:MediaWiki/Credits ' .
 			wfMessage( 'version-poweredby-translators' )->text() . ']';
 
-		$authorList = array(
+		$authorList = [
 			'Magnus Manske', 'Brion Vibber', 'Lee Daniel Crocker',
 			'Tim Starling', 'Erik Möller', 'Gabriel Wicke', 'Ævar Arnfjörð Bjarmason',
 			'Niklas Laxström', 'Domas Mituzas', 'Rob Church', 'Yuri Astrakhan',
@@ -203,7 +197,7 @@ class SpecialVersion extends SpecialPage {
 			'Victor Vasiliev', 'Rotem Liss', 'Platonides', 'Antoine Musso',
 			'Timo Tijhof', 'Daniel Kinzler', 'Jeroen De Dauw', 'Brad Jorsch',
 			$othersLink, $translatorsLink
-		);
+		];
 
 		return wfMessage( 'version-poweredby-credits', MWTimestamp::getLocalInstance()->format( 'Y' ),
 			$wgLang->listToText( $authorList ) )->text();
@@ -220,7 +214,7 @@ class SpecialVersion extends SpecialPage {
 		// Put the software in an array of form 'name' => 'version'. All messages should
 		// be loaded here, so feel free to use wfMessage in the 'name'. Raw HTML or
 		// wikimarkup can be used.
-		$software = array();
+		$software = [];
 		$software['[https://www.mediawiki.org/ MediaWiki]'] = self::getVersionLinked();
 		if ( wfIsHHVM() ) {
 			$software['[http://hhvm.com/ HHVM]'] = HHVM_VERSION . " (" . PHP_SAPI . ")";
@@ -234,14 +228,14 @@ class SpecialVersion extends SpecialPage {
 		}
 
 		// Allow a hook to add/remove items.
-		Hooks::run( 'SoftwareInfo', array( &$software ) );
+		Hooks::run( 'SoftwareInfo', [ &$software ] );
 
 		$out = Xml::element(
 				'h2',
-				array( 'id' => 'mw-version-software' ),
+				[ 'id' => 'mw-version-software' ],
 				wfMessage( 'version-software' )->text()
 			) .
-				Xml::openElement( 'table', array( 'class' => 'wikitable plainlinks', 'id' => 'sv-software' ) ) .
+				Xml::openElement( 'table', [ 'class' => 'wikitable plainlinks', 'id' => 'sv-software' ] ) .
 				"<tr>
 					<th>" . wfMessage( 'version-software-product' )->text() . "</th>
 					<th>" . wfMessage( 'version-software-version' )->text() . "</th>
@@ -258,34 +252,29 @@ class SpecialVersion extends SpecialPage {
 	}
 
 	/**
-	 * Return a string of the MediaWiki version with SVN revision if available.
+	 * Return a string of the MediaWiki version with Git revision if available.
 	 *
 	 * @param string $flags
+	 * @param Language|string|null $lang
 	 * @return mixed
 	 */
-	public static function getVersion( $flags = '' ) {
+	public static function getVersion( $flags = '', $lang = null ) {
 		global $wgVersion, $IP;
 
 		$gitInfo = self::getGitHeadSha1( $IP );
-		$svnInfo = self::getSvnInfo( $IP );
-		if ( !$svnInfo && !$gitInfo ) {
+		if ( !$gitInfo ) {
 			$version = $wgVersion;
-		} elseif ( $gitInfo && $flags === 'nodb' ) {
+		} elseif ( $flags === 'nodb' ) {
 			$shortSha1 = substr( $gitInfo, 0, 7 );
 			$version = "$wgVersion ($shortSha1)";
-		} elseif ( $gitInfo ) {
-			$shortSha1 = substr( $gitInfo, 0, 7 );
-			$shortSha1 = wfMessage( 'parentheses' )->params( $shortSha1 )->escaped();
-			$version = "$wgVersion $shortSha1";
-		} elseif ( $flags === 'nodb' ) {
-			$version = "$wgVersion (r{$svnInfo['checkout-rev']})";
 		} else {
-			$version = $wgVersion . ' ' .
-				wfMessage(
-					'version-svn-revision',
-					isset( $svnInfo['directory-rev'] ) ? $svnInfo['directory-rev'] : '',
-					isset( $svnInfo['checkout-rev'] ) ? $svnInfo['checkout-rev'] : ''
-				)->text();
+			$shortSha1 = substr( $gitInfo, 0, 7 );
+			$msg = wfMessage( 'parentheses' );
+			if ( $lang !== null ) {
+				$msg->inLanguage( $lang );
+			}
+			$shortSha1 = $msg->params( $shortSha1 )->escaped();
+			$version = "$wgVersion $shortSha1";
 		}
 
 		return $version;
@@ -293,8 +282,7 @@ class SpecialVersion extends SpecialPage {
 
 	/**
 	 * Return a wikitext-formatted string of the MediaWiki version with a link to
-	 * the SVN revision or the git SHA1 of head if available.
-	 * Git is prefered over Svn
+	 * the Git SHA1 of head if available.
 	 * The fallback is just $wgVersion
 	 *
 	 * @return mixed
@@ -306,51 +294,20 @@ class SpecialVersion extends SpecialPage {
 		if ( $gitVersion ) {
 			$v = $gitVersion;
 		} else {
-			$svnVersion = self::getVersionLinkedSvn();
-			if ( $svnVersion ) {
-				$v = $svnVersion;
-			} else {
-				$v = $wgVersion; // fallback
-			}
+			$v = $wgVersion; // fallback
 		}
 
 		return $v;
 	}
 
-	/**
-	 * @return string Global wgVersion + a link to subversion revision of svn BASE
-	 */
-	private static function getVersionLinkedSvn() {
-		global $IP;
-
-		$info = self::getSvnInfo( $IP );
-		if ( !isset( $info['checkout-rev'] ) ) {
-			return false;
-		}
-
-		$linkText = wfMessage(
-			'version-svn-revision',
-			isset( $info['directory-rev'] ) ? $info['directory-rev'] : '',
-			$info['checkout-rev']
-		)->text();
-
-		if ( isset( $info['viewvc-url'] ) ) {
-			$version = "[{$info['viewvc-url']} $linkText]";
-		} else {
-			$version = $linkText;
-		}
-
-		return self::getwgVersionLinked() . " $version";
-	}
-
 	/**
 	 * @return string
 	 */
 	private static function getwgVersionLinked() {
 		global $wgVersion;
 		$versionUrl = "";
-		if ( Hooks::run( 'SpecialVersionVersionUrl', array( $wgVersion, &$versionUrl ) ) ) {
-			$versionParts = array();
+		if ( Hooks::run( 'SpecialVersionVersionUrl', [ $wgVersion, &$versionUrl ] ) ) {
+			$versionParts = [];
 			preg_match( "/^(\d+\.\d+)/", $wgVersion, $versionParts );
 			$versionUrl = "https://www.mediawiki.org/wiki/MediaWiki_{$versionParts[1]}";
 		}
@@ -399,7 +356,7 @@ class SpecialVersion extends SpecialPage {
 	 */
 	public static function getExtensionTypes() {
 		if ( self::$extensionTypes === false ) {
-			self::$extensionTypes = array(
+			self::$extensionTypes = [
 				'specialpage' => wfMessage( 'version-specialpages' )->text(),
 				'parserhook' => wfMessage( 'version-parserhooks' )->text(),
 				'variable' => wfMessage( 'version-variables' )->text(),
@@ -408,9 +365,9 @@ class SpecialVersion extends SpecialPage {
 				'skin' => wfMessage( 'version-skins' )->text(),
 				'api' => wfMessage( 'version-api' )->text(),
 				'other' => wfMessage( 'version-other' )->text(),
-			);
+			];
 
-			Hooks::run( 'ExtensionTypes', array( &self::$extensionTypes ) );
+			Hooks::run( 'ExtensionTypes', [ &self::$extensionTypes ] );
 		}
 
 		return self::$extensionTypes;
@@ -451,14 +408,14 @@ class SpecialVersion extends SpecialPage {
 
 		$out = Xml::element(
 				'h2',
-				array( 'id' => 'mw-version-ext' ),
+				[ 'id' => 'mw-version-ext' ],
 				$this->msg( 'version-extensions' )->text()
 			) .
-			Xml::openElement( 'table', array( 'class' => 'wikitable plainlinks', 'id' => 'sv-ext' ) );
+			Xml::openElement( 'table', [ 'class' => 'wikitable plainlinks', 'id' => 'sv-ext' ] );
 
 		// Make sure the 'other' type is set to an array.
 		if ( !array_key_exists( 'other', $wgExtensionCredits ) ) {
-			$wgExtensionCredits['other'] = array();
+			$wgExtensionCredits['other'] = [];
 		}
 
 		// Find all extensions that do not have a valid type and give them the type 'other'.
@@ -498,10 +455,10 @@ class SpecialVersion extends SpecialPage {
 
 		$out = Xml::element(
 				'h2',
-				array( 'id' => 'mw-version-skin' ),
+				[ 'id' => 'mw-version-skin' ],
 				$this->msg( 'version-skins' )->text()
 			) .
-			Xml::openElement( 'table', array( 'class' => 'wikitable plainlinks', 'id' => 'sv-skin' ) );
+			Xml::openElement( 'table', [ 'class' => 'wikitable plainlinks', 'id' => 'sv-skin' ] );
 
 		$this->firstExtOpened = false;
 		$out .= $this->getExtensionCategory( 'skin', null );
@@ -518,34 +475,30 @@ class SpecialVersion extends SpecialPage {
 	 */
 	protected function getExternalLibraries() {
 		global $IP;
-		$path = "$IP/composer.lock";
+		$path = "$IP/vendor/composer/installed.json";
 		if ( !file_exists( $path ) ) {
-			// Maybe they're using mediawiki/vendor?
-			$path = "$IP/vendor/composer.lock";
-			if ( !file_exists( $path ) ) {
-				return '';
-			}
+			return '';
 		}
 
-		$lock = new ComposerLock( $path );
+		$installed = new ComposerInstalled( $path );
 		$out = Html::element(
 			'h2',
-			array( 'id' => 'mw-version-libraries' ),
+			[ 'id' => 'mw-version-libraries' ],
 			$this->msg( 'version-libraries' )->text()
 		);
 		$out .= Html::openElement(
 			'table',
-			array( 'class' => 'wikitable plainlinks', 'id' => 'sv-libraries' )
+			[ 'class' => 'wikitable plainlinks', 'id' => 'sv-libraries' ]
 		);
 		$out .= Html::openElement( 'tr' )
-			. Html::element( 'th', array(), $this->msg( 'version-libraries-library' )->text() )
-			. Html::element( 'th', array(), $this->msg( 'version-libraries-version' )->text() )
-			. Html::element( 'th', array(), $this->msg( 'version-libraries-license' )->text() )
-			. Html::element( 'th', array(), $this->msg( 'version-libraries-description' )->text() )
-			. Html::element( 'th', array(), $this->msg( 'version-libraries-authors' )->text() )
+			. Html::element( 'th', [], $this->msg( 'version-libraries-library' )->text() )
+			. Html::element( 'th', [], $this->msg( 'version-libraries-version' )->text() )
+			. Html::element( 'th', [], $this->msg( 'version-libraries-license' )->text() )
+			. Html::element( 'th', [], $this->msg( 'version-libraries-description' )->text() )
+			. Html::element( 'th', [], $this->msg( 'version-libraries-authors' )->text() )
 			. Html::closeElement( 'tr' );
 
-		foreach ( $lock->getInstalledDependencies() as $name => $info ) {
+		foreach ( $installed->getInstalledDependencies() as $name => $info ) {
 			if ( strpos( $info['type'], 'mediawiki-' ) === 0 ) {
 				// Skip any extensions or skins since they'll be listed
 				// in their proper section
@@ -566,17 +519,17 @@ class SpecialVersion extends SpecialPage {
 			$out .= Html::openElement( 'tr' )
 				. Html::rawElement(
 					'td',
-					array(),
+					[],
 					Linker::makeExternalLink(
 						"https://packagist.org/packages/$name", $name,
 						true, '',
-						array( 'class' => 'mw-version-library-name' )
+						[ 'class' => 'mw-version-library-name' ]
 					)
 				)
-				. Html::element( 'td', array( 'dir' => 'auto' ), $info['version'] )
-				. Html::element( 'td', array( 'dir' => 'auto' ), $this->listToText( $info['licenses'] ) )
-				. Html::element( 'td', array( 'lang' => 'en', 'dir' => 'ltr' ), $info['description'] )
-				. Html::rawElement( 'td', array(), $authors )
+				. Html::element( 'td', [ 'dir' => 'auto' ], $info['version'] )
+				. Html::element( 'td', [ 'dir' => 'auto' ], $this->listToText( $info['licenses'] ) )
+				. Html::element( 'td', [ 'lang' => 'en', 'dir' => 'ltr' ], $info['description'] )
+				. Html::rawElement( 'td', [], $authors )
 				. Html::closeElement( 'tr' );
 		}
 		$out .= Html::closeElement( 'table' );
@@ -597,12 +550,12 @@ class SpecialVersion extends SpecialPage {
 		if ( count( $tags ) ) {
 			$out = Html::rawElement(
 				'h2',
-				array(
+				[
 					'class' => 'mw-headline plainlinks',
 					'id' => 'mw-version-parser-extensiontags',
-				),
+				],
 				Linker::makeExternalLink(
-					'//www.mediawiki.org/wiki/Special:MyLanguage/Manual:Tag_extensions',
+					'https://www.mediawiki.org/wiki/Special:MyLanguage/Manual:Tag_extensions',
 					$this->msg( 'version-parser-extensiontags' )->parse(),
 					false /* msg()->parse() already escapes */
 				)
@@ -613,9 +566,9 @@ class SpecialVersion extends SpecialPage {
 				$value = Html::element(
 					'bdi',
 					// Prevent < and > from slipping to another line
-					array(
+					[
 						'style' => 'white-space: nowrap;',
-					),
+					],
 					"<$value>"
 				);
 			} );
@@ -640,12 +593,12 @@ class SpecialVersion extends SpecialPage {
 		if ( count( $fhooks ) ) {
 			$out = Html::rawElement(
 				'h2',
-				array(
+				[
 					'class' => 'mw-headline plainlinks',
 					'id' => 'mw-version-parser-function-hooks',
-				),
+				],
 				Linker::makeExternalLink(
-					'//www.mediawiki.org/wiki/Special:MyLanguage/Manual:Parser_functions',
+					'https://www.mediawiki.org/wiki/Special:MyLanguage/Manual:Parser_functions',
 					$this->msg( 'version-parser-function-hooks' )->parse(),
 					false /* msg()->parse() already escapes */
 				)
@@ -677,7 +630,7 @@ class SpecialVersion extends SpecialPage {
 		if ( array_key_exists( $type, $wgExtensionCredits ) && count( $wgExtensionCredits[$type] ) > 0 ) {
 			$out .= $this->openExtType( $message, 'credits-' . $type );
 
-			usort( $wgExtensionCredits[$type], array( $this, 'compare' ) );
+			usort( $wgExtensionCredits[$type], [ $this, 'compare' ] );
 
 			foreach ( $wgExtensionCredits[$type] as $extension ) {
 				$out .= $this->getCreditsForExtension( $extension );
@@ -711,7 +664,7 @@ class SpecialVersion extends SpecialPage {
 	 *  - The name of (name), and URL link to (url), the extension
 	 *  - Official version number (version) and if available version control system
 	 *    revision (path), link, and date
-	 *  - If available the short name of the license (license-name) and a linke
+	 *  - If available the short name of the license (license-name) and a link
 	 *    to ((LICENSE)|(COPYING))(\.txt)? if it exists.
 	 *  - Description of extension (descriptionmsg or description)
 	 *  - List of authors (author) and link to a ((AUTHORS)|(CREDITS))(\.txt)? file if it exists
@@ -741,14 +694,14 @@ class SpecialVersion extends SpecialPage {
 				$extensionName,
 				true,
 				'',
-				array( 'class' => 'mw-version-ext-name' )
+				[ 'class' => 'mw-version-ext-name' ]
 			);
 		} else {
 			$extensionNameLink = $extensionName;
 		}
 
 		// ... and the version information
-		// If the extension path is set we will check that directory for GIT and SVN
+		// If the extension path is set we will check that directory for GIT
 		// metadata in an attempt to extract date and vcs commit metadata.
 		$canonicalVersion = '&ndash;';
 		$extensionPath = null;
@@ -768,11 +721,6 @@ class SpecialVersion extends SpecialPage {
 				$coreHeadSHA1 = self::getGitHeadSha1( $IP );
 				if ( $coreHeadSHA1 ) {
 					$this->coreId = $coreHeadSHA1;
-				} else {
-					$svnInfo = self::getSvnInfo( $IP );
-					if ( $svnInfo !== false ) {
-						$this->coreId = $svnInfo['checkout-rev'];
-					}
 				}
 			}
 			$cache = wfGetCache( CACHE_ANYTHING );
@@ -787,14 +735,8 @@ class SpecialVersion extends SpecialPage {
 					$vcsVersion = substr( $vcsVersion, 0, 7 );
 					$vcsLink = $gitInfo->getHeadViewUrl();
 					$vcsDate = $gitInfo->getHeadCommitDate();
-				} else {
-					$svnInfo = self::getSvnInfo( $extensionPath );
-					if ( $svnInfo !== false ) {
-						$vcsVersion = $this->msg( 'version-svn-revision', $svnInfo['checkout-rev'] )->text();
-						$vcsLink = isset( $svnInfo['viewvc-url'] ) ? $svnInfo['viewvc-url'] : '';
-					}
 				}
-				$cache->set( $memcKey, array( $vcsVersion, $vcsLink, $vcsDate ), 60 * 60 * 24 );
+				$cache->set( $memcKey, [ $vcsVersion, $vcsLink, $vcsDate ], 60 * 60 * 24 );
 			} else {
 				wfDebug( "Pulled VCS info for extension {$extension['name']} from cache" );
 			}
@@ -802,7 +744,7 @@ class SpecialVersion extends SpecialPage {
 
 		$versionString = Html::rawElement(
 			'span',
-			array( 'class' => 'mw-version-ext-version' ),
+			[ 'class' => 'mw-version-ext-version' ],
 			$canonicalVersion
 		);
 
@@ -813,11 +755,11 @@ class SpecialVersion extends SpecialPage {
 					$this->msg( 'version-version', $vcsVersion ),
 					true,
 					'',
-					array( 'class' => 'mw-version-ext-vcs-version' )
+					[ 'class' => 'mw-version-ext-vcs-version' ]
 				);
 			} else {
 				$vcsVerString = Html::element( 'span',
-					array( 'class' => 'mw-version-ext-vcs-version' ),
+					[ 'class' => 'mw-version-ext-vcs-version' ],
 					"({$vcsVersion})"
 				);
 			}
@@ -825,13 +767,13 @@ class SpecialVersion extends SpecialPage {
 
 			if ( $vcsDate ) {
 				$vcsTimeString = Html::element( 'span',
-					array( 'class' => 'mw-version-ext-vcs-timestamp' ),
+					[ 'class' => 'mw-version-ext-vcs-timestamp' ],
 					$this->getLanguage()->timeanddate( $vcsDate, true )
 				);
 				$versionString .= " {$vcsTimeString}";
 			}
 			$versionString = Html::rawElement( 'span',
-				array( 'class' => 'mw-version-ext-meta-version' ),
+				[ 'class' => 'mw-version-ext-meta-version' ],
 				$versionString
 			);
 		}
@@ -844,16 +786,16 @@ class SpecialVersion extends SpecialPage {
 			if ( isset( $extension['license-name'] ) ) {
 				$licenseName = $out->parseInline( $extension['license-name'] );
 			} elseif ( $this->getExtLicenseFileName( $extensionPath ) ) {
-				$licenseName = $this->msg( 'version-ext-license' );
+				$licenseName = $this->msg( 'version-ext-license' )->escaped();
 			}
 			if ( $licenseName !== null ) {
 				$licenseLink = Linker::link(
 					$this->getPageTitle( 'License/' . $extension['name'] ),
 					$licenseName,
-					array(
+					[
 						'class' => 'mw-version-ext-license',
 						'dir' => 'auto',
-					)
+					]
 				);
 			}
 		}
@@ -882,21 +824,21 @@ class SpecialVersion extends SpecialPage {
 		$description = $out->parseInline( $description );
 
 		// ... now get the authors for this extension
-		$authors = isset( $extension['author'] ) ? $extension['author'] : array();
+		$authors = isset( $extension['author'] ) ? $extension['author'] : [];
 		$authors = $this->listAuthors( $authors, $extension['name'], $extensionPath );
 
 		// Finally! Create the table
-		$html = Html::openElement( 'tr', array(
+		$html = Html::openElement( 'tr', [
 				'class' => 'mw-version-ext',
 				'id' => Sanitizer::escapeId( 'mw-version-ext-' . $extension['name'] )
-			)
+			]
 		);
 
-		$html .= Html::rawElement( 'td', array(), $extensionNameLink );
-		$html .= Html::rawElement( 'td', array(), $versionString );
-		$html .= Html::rawElement( 'td', array(), $licenseLink );
-		$html .= Html::rawElement( 'td', array( 'class' => 'mw-version-ext-description' ), $description );
-		$html .= Html::rawElement( 'td', array( 'class' => 'mw-version-ext-authors' ), $authors );
+		$html .= Html::rawElement( 'td', [], $extensionNameLink );
+		$html .= Html::rawElement( 'td', [], $versionString );
+		$html .= Html::rawElement( 'td', [], $licenseLink );
+		$html .= Html::rawElement( 'td', [ 'class' => 'mw-version-ext-description' ], $description );
+		$html .= Html::rawElement( 'td', [ 'class' => 'mw-version-ext-authors' ], $authors );
 
 		$html .= Html::closeElement( 'tr' );
 
@@ -915,18 +857,18 @@ class SpecialVersion extends SpecialPage {
 			$myWgHooks = $wgHooks;
 			ksort( $myWgHooks );
 
-			$ret = array();
+			$ret = [];
 			$ret[] = '== {{int:version-hooks}} ==';
-			$ret[] = Html::openElement( 'table', array( 'class' => 'wikitable', 'id' => 'sv-hooks' ) );
+			$ret[] = Html::openElement( 'table', [ 'class' => 'wikitable', 'id' => 'sv-hooks' ] );
 			$ret[] = Html::openElement( 'tr' );
-			$ret[] = Html::element( 'th', array(), $this->msg( 'version-hook-name' )->text() );
-			$ret[] = Html::element( 'th', array(), $this->msg( 'version-hook-subscribedby' )->text() );
+			$ret[] = Html::element( 'th', [], $this->msg( 'version-hook-name' )->text() );
+			$ret[] = Html::element( 'th', [], $this->msg( 'version-hook-subscribedby' )->text() );
 			$ret[] = Html::closeElement( 'tr' );
 
 			foreach ( $myWgHooks as $hook => $hooks ) {
 				$ret[] = Html::openElement( 'tr' );
-				$ret[] = Html::element( 'td', array(), $hook );
-				$ret[] = Html::element( 'td', array(), $this->listToText( $hooks ) );
+				$ret[] = Html::element( 'td', [], $hook );
+				$ret[] = Html::element( 'td', [], $this->listToText( $hooks ) );
 				$ret[] = Html::closeElement( 'tr' );
 			}
 
@@ -941,10 +883,10 @@ class SpecialVersion extends SpecialPage {
 	private function openExtType( $text = null, $name = null ) {
 		$out = '';
 
-		$opt = array( 'colspan' => 5 );
+		$opt = [ 'colspan' => 5 ];
 		if ( $this->firstExtOpened ) {
 			// Insert a spacing line
-			$out .= Html::rawElement( 'tr', array( 'class' => 'sv-space' ),
+			$out .= Html::rawElement( 'tr', [ 'class' => 'sv-space' ],
 				Html::element( 'td', $opt )
 			);
 		}
@@ -955,7 +897,7 @@ class SpecialVersion extends SpecialPage {
 		}
 
 		if ( $text !== null ) {
-			$out .= Html::rawElement( 'tr', array(),
+			$out .= Html::rawElement( 'tr', [],
 				Html::element( 'th', $opt, $text )
 			);
 		}
@@ -964,15 +906,15 @@ class SpecialVersion extends SpecialPage {
 			? 'version-skin-colheader-name'
 			: 'version-ext-colheader-name';
 		$out .= Html::openElement( 'tr' );
-		$out .= Html::element( 'th', array( 'class' => 'mw-version-ext-col-label' ),
+		$out .= Html::element( 'th', [ 'class' => 'mw-version-ext-col-label' ],
 			$this->msg( $firstHeadingMsg )->text() );
-		$out .= Html::element( 'th', array( 'class' => 'mw-version-ext-col-label' ),
+		$out .= Html::element( 'th', [ 'class' => 'mw-version-ext-col-label' ],
 			$this->msg( 'version-ext-colheader-version' )->text() );
-		$out .= Html::element( 'th', array( 'class' => 'mw-version-ext-col-label' ),
+		$out .= Html::element( 'th', [ 'class' => 'mw-version-ext-col-label' ],
 			$this->msg( 'version-ext-colheader-license' )->text() );
-		$out .= Html::element( 'th', array( 'class' => 'mw-version-ext-col-label' ),
+		$out .= Html::element( 'th', [ 'class' => 'mw-version-ext-col-label' ],
 			$this->msg( 'version-ext-colheader-description' )->text() );
-		$out .= Html::element( 'th', array( 'class' => 'mw-version-ext-col-label' ),
+		$out .= Html::element( 'th', [ 'class' => 'mw-version-ext-col-label' ],
 			$this->msg( 'version-ext-colheader-credits' )->text() );
 		$out .= Html::closeElement( 'tr' );
 
@@ -1014,7 +956,7 @@ class SpecialVersion extends SpecialPage {
 	public function listAuthors( $authors, $extName, $extDir ) {
 		$hasOthers = false;
 
-		$list = array();
+		$list = [];
 		foreach ( (array)$authors as $item ) {
 			if ( $item == '...' ) {
 				$hasOthers = true;
@@ -1066,7 +1008,7 @@ class SpecialVersion extends SpecialPage {
 
 		foreach ( scandir( $extDir ) as $file ) {
 			$fullPath = $extDir . DIRECTORY_SEPARATOR . $file;
-			if ( preg_match( '/^((AUTHORS)|(CREDITS))(\.txt)?$/', $file ) &&
+			if ( preg_match( '/^((AUTHORS)|(CREDITS))(\.txt|\.wiki|\.mediawiki)?$/', $file ) &&
 				is_readable( $fullPath ) &&
 				is_file( $fullPath )
 			) {
@@ -1123,7 +1065,7 @@ class SpecialVersion extends SpecialPage {
 		}
 
 		return $this->getLanguage()
-			->listToText( array_map( array( __CLASS__, 'arrayToString' ), $list ) );
+			->listToText( array_map( [ __CLASS__, 'arrayToString' ], $list ) );
 	}
 
 	/**
@@ -1158,108 +1100,6 @@ class SpecialVersion extends SpecialPage {
 		}
 	}
 
-	/**
-	 * Get an associative array of information about a given path, from its .svn
-	 * subdirectory. Returns false on error, such as if the directory was not
-	 * checked out with subversion.
-	 *
-	 * Returned keys are:
-	 *    Required:
-	 *        checkout-rev          The revision which was checked out
-	 *    Optional:
-	 *        directory-rev         The revision when the directory was last modified
-	 *        url                   The subversion URL of the directory
-	 *        repo-url              The base URL of the repository
-	 *        viewvc-url            A ViewVC URL pointing to the checked-out revision
-	 * @param string $dir
-	 * @return array|bool
-	 */
-	public static function getSvnInfo( $dir ) {
-		// http://svnbook.red-bean.com/nightly/en/svn.developer.insidewc.html
-		$entries = $dir . '/.svn/entries';
-
-		if ( !file_exists( $entries ) ) {
-			return false;
-		}
-
-		$lines = file( $entries );
-		if ( !count( $lines ) ) {
-			return false;
-		}
-
-		// check if file is xml (subversion release <= 1.3) or not (subversion release = 1.4)
-		if ( preg_match( '/^<\?xml/', $lines[0] ) ) {
-			// subversion is release <= 1.3
-			if ( !function_exists( 'simplexml_load_file' ) ) {
-				// We could fall back to expat... YUCK
-				return false;
-			}
-
-			// SimpleXml whines about the xmlns...
-			MediaWiki\suppressWarnings();
-			$xml = simplexml_load_file( $entries );
-			MediaWiki\restoreWarnings();
-
-			if ( $xml ) {
-				foreach ( $xml->entry as $entry ) {
-					if ( $xml->entry[0]['name'] == '' ) {
-						// The directory entry should always have a revision marker.
-						if ( $entry['revision'] ) {
-							return array( 'checkout-rev' => intval( $entry['revision'] ) );
-						}
-					}
-				}
-			}
-
-			return false;
-		}
-
-		// Subversion is release 1.4 or above.
-		if ( count( $lines ) < 11 ) {
-			return false;
-		}
-
-		$info = array(
-			'checkout-rev' => intval( trim( $lines[3] ) ),
-			'url' => trim( $lines[4] ),
-			'repo-url' => trim( $lines[5] ),
-			'directory-rev' => intval( trim( $lines[10] ) )
-		);
-
-		if ( isset( self::$viewvcUrls[$info['repo-url']] ) ) {
-			$viewvc = str_replace(
-				$info['repo-url'],
-				self::$viewvcUrls[$info['repo-url']],
-				$info['url']
-			);
-
-			$viewvc .= '/?pathrev=';
-			$viewvc .= urlencode( $info['checkout-rev'] );
-			$info['viewvc-url'] = $viewvc;
-		}
-
-		return $info;
-	}
-
-	/**
-	 * Retrieve the revision number of a Subversion working directory.
-	 *
-	 * @param string $dir Directory of the svn checkout
-	 *
-	 * @return int Revision number
-	 */
-	public static function getSvnRevision( $dir ) {
-		$info = self::getSvnInfo( $dir );
-
-		if ( $info === false ) {
-			return false;
-		} elseif ( isset( $info['checkout-rev'] ) ) {
-			return $info['checkout-rev'];
-		} else {
-			return false;
-		}
-	}
-
 	/**
 	 * @param string $dir Directory of the git checkout
 	 * @return bool|string Sha1 of commit HEAD points to
@@ -1286,31 +1126,31 @@ class SpecialVersion extends SpecialPage {
 	public function getEntryPointInfo() {
 		global $wgArticlePath, $wgScriptPath;
 		$scriptPath = $wgScriptPath ? $wgScriptPath : "/";
-		$entryPoints = array(
+		$entryPoints = [
 			'version-entrypoints-articlepath' => $wgArticlePath,
 			'version-entrypoints-scriptpath' => $scriptPath,
 			'version-entrypoints-index-php' => wfScript( 'index' ),
 			'version-entrypoints-api-php' => wfScript( 'api' ),
 			'version-entrypoints-load-php' => wfScript( 'load' ),
-		);
+		];
 
 		$language = $this->getLanguage();
-		$thAttribures = array(
+		$thAttribures = [
 			'dir' => $language->getDir(),
 			'lang' => $language->getHtmlCode()
-		);
+		];
 		$out = Html::element(
 				'h2',
-				array( 'id' => 'mw-version-entrypoints' ),
+				[ 'id' => 'mw-version-entrypoints' ],
 				$this->msg( 'version-entrypoints' )->text()
 			) .
 			Html::openElement( 'table',
-				array(
+				[
 					'class' => 'wikitable plainlinks',
 					'id' => 'mw-version-entrypoints-table',
 					'dir' => 'ltr',
 					'lang' => 'en'
-				)
+				]
 			) .
 			Html::openElement( 'tr' ) .
 			Html::element(
@@ -1330,8 +1170,8 @@ class SpecialVersion extends SpecialPage {
 			$out .= Html::openElement( 'tr' ) .
 				// ->text() looks like it should be ->parse(), but this function
 				// returns wikitext, not HTML, boo
-				Html::rawElement( 'td', array(), $this->msg( $message )->text() ) .
-				Html::rawElement( 'td', array(), Html::rawElement( 'code', array(), "[$url $value]" ) ) .
+				Html::rawElement( 'td', [], $this->msg( $message )->text() ) .
+				Html::rawElement( 'td', [], Html::rawElement( 'code', [], "[$url $value]" ) ) .
 				Html::closeElement( 'tr' );
 		}
 
