@@ -22,7 +22,9 @@
 
 // Bail on old versions of PHP, or if composer has not been run yet to install
 // dependencies. Using dirname( __FILE__ ) here because __DIR__ is PHP5.3+.
+// @codingStandardsIgnoreStart MediaWiki.Usage.DirUsage.FunctionFound
 require_once dirname( __FILE__ ) . '/../includes/PHPVersionCheck.php';
+// @codingStandardsIgnoreEnd
 wfEntryPointCheck( 'cli' );
 
 /**
@@ -61,19 +63,19 @@ abstract class Maintenance {
 	const STDIN_ALL = 'all';
 
 	// This is the desired params
-	protected $mParams = array();
+	protected $mParams = [];
 
 	// Array of mapping short parameters to long ones
-	protected $mShortParamsMap = array();
+	protected $mShortParamsMap = [];
 
 	// Array of desired args
-	protected $mArgList = array();
+	protected $mArgList = [];
 
 	// This is the list of options that were actually passed
-	protected $mOptions = array();
+	protected $mOptions = [];
 
 	// This is the list of arguments that were actually passed
-	protected $mArgs = array();
+	protected $mArgs = [];
 
 	// Name of the script currently running
 	protected $mSelf;
@@ -82,7 +84,7 @@ abstract class Maintenance {
 	protected $mQuiet = false;
 	protected $mDbUser, $mDbPass;
 
-	// A description of the script, children should change this
+	// A description of the script, children should change this via addDescription()
 	protected $mDescription = '';
 
 	// Have we already loaded our user input?
@@ -97,16 +99,19 @@ abstract class Maintenance {
 	protected $mBatchSize = null;
 
 	// Generic options added by addDefaultParams()
-	private $mGenericParameters = array();
+	private $mGenericParameters = [];
 	// Generic options which might or not be supported by the script
-	private $mDependantParameters = array();
+	private $mDependantParameters = [];
 
 	/**
 	 * Used by getDB() / setDB()
-	 * @var DatabaseBase
+	 * @var IDatabase
 	 */
 	private $mDb = null;
 
+	/** @var float UNIX timestamp */
+	private $lastSlaveWait = 0.0;
+
 	/**
 	 * Used when creating separate schema files.
 	 * @var resource
@@ -120,6 +125,19 @@ abstract class Maintenance {
 	 */
 	private $config;
 
+	/**
+	 * Used to read the options in the order they were passed.
+	 * Useful for option chaining (Ex. dumpBackup.php). It will
+	 * be an empty array if the options are passed in through
+	 * loadParamsAndArgs( $self, $opts, $args ).
+	 *
+	 * This is an array of arrays where
+	 * 0 => the option and 1 => parameter value.
+	 *
+	 * @var array
+	 */
+	public $orderedOptions = [];
+
 	/**
 	 * Default constructor. Children should call this *first* if implementing
 	 * their own constructors
@@ -132,7 +150,7 @@ abstract class Maintenance {
 			: realpath( __DIR__ . '/..' );
 
 		$this->addDefaultParams();
-		register_shutdown_function( array( $this, 'outputChanneled' ), false );
+		register_shutdown_function( [ $this, 'outputChanneled' ], false );
 	}
 
 	/**
@@ -158,7 +176,7 @@ abstract class Maintenance {
 		if ( $bt[0]['class'] !== 'Maintenance' || $bt[0]['function'] !== 'shouldExecute' ) {
 			return false; // last call should be to this function
 		}
-		$includeFuncs = array( 'require_once', 'require', 'include', 'include_once' );
+		$includeFuncs = [ 'require_once', 'require', 'include', 'include_once' ];
 		for ( $i = 1; $i < $count; $i++ ) {
 			if ( !in_array( $bt[$i]['function'], $includeFuncs ) ) {
 				return false; // previous calls should all be "requires"
@@ -182,16 +200,18 @@ abstract class Maintenance {
 	 * @param bool $required Is the param required?
 	 * @param bool $withArg Is an argument required with this option?
 	 * @param string $shortName Character to use as short name
+	 * @param bool $multiOccurrence Can this option be passed multiple times?
 	 */
 	protected function addOption( $name, $description, $required = false,
-		$withArg = false, $shortName = false
+		$withArg = false, $shortName = false, $multiOccurrence = false
 	) {
-		$this->mParams[$name] = array(
+		$this->mParams[$name] = [
 			'desc' => $description,
 			'require' => $required,
 			'withArg' => $withArg,
-			'shortName' => $shortName
-		);
+			'shortName' => $shortName,
+			'multiOccurrence' => $multiOccurrence
+		];
 
 		if ( $shortName !== false ) {
 			$this->mShortParamsMap[$shortName] = $name;
@@ -208,7 +228,11 @@ abstract class Maintenance {
 	}
 
 	/**
-	 * Get an option, or return the default
+	 * Get an option, or return the default.
+	 *
+	 * If the option was added to support multiple occurrences,
+	 * this will return an array.
+	 *
 	 * @param string $name The name of the param
 	 * @param mixed $default Anything you want, default null
 	 * @return mixed
@@ -231,11 +255,11 @@ abstract class Maintenance {
 	 * @param bool $required Is this required?
 	 */
 	protected function addArg( $arg, $description, $required = true ) {
-		$this->mArgList[] = array(
+		$this->mArgList[] = [
 			'name' => $arg,
 			'desc' => $description,
 			'require' => $required
-		);
+		];
 	}
 
 	/**
@@ -460,7 +484,7 @@ abstract class Maintenance {
 		}
 
 		# Save additional script dependant options to display
-		# them separately in help
+		#  them separately in help
 		$this->mDependantParameters = array_diff_key( $this->mParams, $this->mGenericParameters );
 	}
 
@@ -611,9 +635,9 @@ abstract class Maintenance {
 		if ( is_array( $wgProfiler ) && isset( $wgProfiler['class'] ) ) {
 			$class = $wgProfiler['class'];
 			$profiler = new $class(
-				array( 'sampling' => 1, 'output' => array( $output ) )
+				[ 'sampling' => 1, 'output' => [ $output ] ]
 					+ $wgProfiler
-					+ array( 'threshold' => $wgProfileLimit )
+					+ [ 'threshold' => $wgProfileLimit ]
 			);
 			$profiler->setTemplated( true );
 			Profiler::replaceStubInstance( $profiler );
@@ -628,11 +652,122 @@ abstract class Maintenance {
 	 * Clear all params and arguments.
 	 */
 	public function clearParamsAndArgs() {
-		$this->mOptions = array();
-		$this->mArgs = array();
+		$this->mOptions = [];
+		$this->mArgs = [];
 		$this->mInputLoaded = false;
 	}
 
+	/**
+	 * Load params and arguments from a given array
+	 * of command-line arguments
+	 *
+	 * @since 1.27
+	 * @param array $argv
+	 */
+	public function loadWithArgv( $argv ) {
+		$options = [];
+		$args = [];
+		$this->orderedOptions = [];
+
+		# Parse arguments
+		for ( $arg = reset( $argv ); $arg !== false; $arg = next( $argv ) ) {
+			if ( $arg == '--' ) {
+				# End of options, remainder should be considered arguments
+				$arg = next( $argv );
+				while ( $arg !== false ) {
+					$args[] = $arg;
+					$arg = next( $argv );
+				}
+				break;
+			} elseif ( substr( $arg, 0, 2 ) == '--' ) {
+				# Long options
+				$option = substr( $arg, 2 );
+				if ( isset( $this->mParams[$option] ) && $this->mParams[$option]['withArg'] ) {
+					$param = next( $argv );
+					if ( $param === false ) {
+						$this->error( "\nERROR: $option parameter needs a value after it\n" );
+						$this->maybeHelp( true );
+					}
+
+					$this->setParam( $options, $option, $param );
+				} else {
+					$bits = explode( '=', $option, 2 );
+					if ( count( $bits ) > 1 ) {
+						$option = $bits[0];
+						$param = $bits[1];
+					} else {
+						$param = 1;
+					}
+
+					$this->setParam( $options, $option, $param );
+				}
+			} elseif ( $arg == '-' ) {
+				# Lonely "-", often used to indicate stdin or stdout.
+				$args[] = $arg;
+			} elseif ( substr( $arg, 0, 1 ) == '-' ) {
+				# Short options
+				$argLength = strlen( $arg );
+				for ( $p = 1; $p < $argLength; $p++ ) {
+					$option = $arg[$p];
+					if ( !isset( $this->mParams[$option] ) && isset( $this->mShortParamsMap[$option] ) ) {
+						$option = $this->mShortParamsMap[$option];
+					}
+
+					if ( isset( $this->mParams[$option]['withArg'] ) && $this->mParams[$option]['withArg'] ) {
+						$param = next( $argv );
+						if ( $param === false ) {
+							$this->error( "\nERROR: $option parameter needs a value after it\n" );
+							$this->maybeHelp( true );
+						}
+						$this->setParam( $options, $option, $param );
+					} else {
+						$this->setParam( $options, $option, 1 );
+					}
+				}
+			} else {
+				$args[] = $arg;
+			}
+		}
+
+		$this->mOptions = $options;
+		$this->mArgs = $args;
+		$this->loadSpecialVars();
+		$this->mInputLoaded = true;
+	}
+
+	/**
+	 * Helper function used solely by loadParamsAndArgs
+	 * to prevent code duplication
+	 *
+	 * This sets the param in the options array based on
+	 * whether or not it can be specified multiple times.
+	 *
+	 * @since 1.27
+	 * @param array $options
+	 * @param string $option
+	 * @param mixed $value
+	 */
+	private function setParam( &$options, $option, $value ) {
+		$this->orderedOptions[] = [ $option, $value ];
+
+		if ( isset( $this->mParams[$option] ) ) {
+			$multi = $this->mParams[$option]['multiOccurrence'];
+		} else {
+			$multi = false;
+		}
+		$exists = array_key_exists( $option, $options );
+		if ( $multi && $exists ) {
+			$options[$option][] = $value;
+		} elseif ( $multi ) {
+			$options[$option] = [ $value ];
+		} elseif ( !$exists ) {
+			$options[$option] = $value;
+		} else {
+			$this->error( "\nERROR: $option parameter given twice\n" );
+			$this->maybeHelp( true );
+		}
+	}
+
 	/**
 	 * Process command line arguments
 	 * $mOptions becomes an array with keys set to the option names
@@ -667,80 +802,8 @@ abstract class Maintenance {
 		}
 
 		global $argv;
-		$this->mSelf = array_shift( $argv );
-
-		$options = array();
-		$args = array();
-
-		# Parse arguments
-		for ( $arg = reset( $argv ); $arg !== false; $arg = next( $argv ) ) {
-			if ( $arg == '--' ) {
-				# End of options, remainder should be considered arguments
-				$arg = next( $argv );
-				while ( $arg !== false ) {
-					$args[] = $arg;
-					$arg = next( $argv );
-				}
-				break;
-			} elseif ( substr( $arg, 0, 2 ) == '--' ) {
-				# Long options
-				$option = substr( $arg, 2 );
-				if ( array_key_exists( $option, $options ) ) {
-					$this->error( "\nERROR: $option parameter given twice\n" );
-					$this->maybeHelp( true );
-				}
-				if ( isset( $this->mParams[$option] ) && $this->mParams[$option]['withArg'] ) {
-					$param = next( $argv );
-					if ( $param === false ) {
-						$this->error( "\nERROR: $option parameter needs a value after it\n" );
-						$this->maybeHelp( true );
-					}
-					$options[$option] = $param;
-				} else {
-					$bits = explode( '=', $option, 2 );
-					if ( count( $bits ) > 1 ) {
-						$option = $bits[0];
-						$param = $bits[1];
-					} else {
-						$param = 1;
-					}
-					$options[$option] = $param;
-				}
-			} elseif ( $arg == '-' ) {
-				# Lonely "-", often used to indicate stdin or stdout.
-				$args[] = $arg;
-			} elseif ( substr( $arg, 0, 1 ) == '-' ) {
-				# Short options
-				$argLength = strlen( $arg );
-				for ( $p = 1; $p < $argLength; $p++ ) {
-					$option = $arg[$p];
-					if ( !isset( $this->mParams[$option] ) && isset( $this->mShortParamsMap[$option] ) ) {
-						$option = $this->mShortParamsMap[$option];
-					}
-					if ( array_key_exists( $option, $options ) ) {
-						$this->error( "\nERROR: $option parameter given twice\n" );
-						$this->maybeHelp( true );
-					}
-					if ( isset( $this->mParams[$option]['withArg'] ) && $this->mParams[$option]['withArg'] ) {
-						$param = next( $argv );
-						if ( $param === false ) {
-							$this->error( "\nERROR: $option parameter needs a value after it\n" );
-							$this->maybeHelp( true );
-						}
-						$options[$option] = $param;
-					} else {
-						$options[$option] = 1;
-					}
-				}
-			} else {
-				$args[] = $arg;
-			}
-		}
-
-		$this->mOptions = $options;
-		$this->mArgs = $args;
-		$this->loadSpecialVars();
-		$this->mInputLoaded = true;
+		$this->mSelf = $argv[0];
+		$this->loadWithArgv( array_slice( $argv, 1 ) );
 	}
 
 	/**
@@ -1024,11 +1087,11 @@ abstract class Maintenance {
 	public function purgeRedundantText( $delete = true ) {
 		# Data should come off the master, wrapped in a transaction
 		$dbw = $this->getDB( DB_MASTER );
-		$dbw->begin( __METHOD__ );
+		$this->beginTransaction( $dbw, __METHOD__ );
 
 		# Get "active" text records from the revisions table
 		$this->output( 'Searching for active text records in revisions table...' );
-		$res = $dbw->select( 'revision', 'rev_text_id', array(), __METHOD__, array( 'DISTINCT' ) );
+		$res = $dbw->select( 'revision', 'rev_text_id', [], __METHOD__, [ 'DISTINCT' ] );
 		foreach ( $res as $row ) {
 			$cur[] = $row->rev_text_id;
 		}
@@ -1036,7 +1099,7 @@ abstract class Maintenance {
 
 		# Get "active" text records from the archive table
 		$this->output( 'Searching for active text records in archive table...' );
-		$res = $dbw->select( 'archive', 'ar_text_id', array(), __METHOD__, array( 'DISTINCT' ) );
+		$res = $dbw->select( 'archive', 'ar_text_id', [], __METHOD__, [ 'DISTINCT' ] );
 		foreach ( $res as $row ) {
 			# old pre-MW 1.5 records can have null ar_text_id's.
 			if ( $row->ar_text_id !== null ) {
@@ -1048,8 +1111,8 @@ abstract class Maintenance {
 		# Get the IDs of all text records not in these sets
 		$this->output( 'Searching for inactive text records...' );
 		$cond = 'old_id NOT IN ( ' . $dbw->makeList( $cur ) . ' )';
-		$res = $dbw->select( 'text', 'old_id', array( $cond ), __METHOD__, array( 'DISTINCT' ) );
-		$old = array();
+		$res = $dbw->select( 'text', 'old_id', [ $cond ], __METHOD__, [ 'DISTINCT' ] );
+		$old = [];
 		foreach ( $res as $row ) {
 			$old[] = $row->old_id;
 		}
@@ -1062,12 +1125,12 @@ abstract class Maintenance {
 		# Delete as appropriate
 		if ( $delete && $count ) {
 			$this->output( 'Deleting...' );
-			$dbw->delete( 'text', array( 'old_id' => $old ), __METHOD__ );
+			$dbw->delete( 'text', [ 'old_id' => $old ], __METHOD__ );
 			$this->output( "done.\n" );
 		}
 
 		# Done
-		$dbw->commit( __METHOD__ );
+		$this->commitTransaction( $dbw, __METHOD__ );
 	}
 
 	/**
@@ -1083,9 +1146,12 @@ abstract class Maintenance {
 	 * If not set, wfGetDB() will be used.
 	 * This function has the same parameters as wfGetDB()
 	 *
-	 * @return DatabaseBase
+	 * @param integer $db DB index (DB_SLAVE/DB_MASTER)
+	 * @param array $groups; default: empty array
+	 * @param string|bool $wiki; default: current wiki
+	 * @return IDatabase
 	 */
-	protected function getDB( $db, $groups = array(), $wiki = false ) {
+	protected function getDB( $db, $groups = [], $wiki = false ) {
 		if ( is_null( $this->mDb ) ) {
 			return wfGetDB( $db, $groups, $wiki );
 		} else {
@@ -1096,19 +1162,75 @@ abstract class Maintenance {
 	/**
 	 * Sets database object to be returned by getDB().
 	 *
-	 * @param DatabaseBase $db Database object to be used
+	 * @param IDatabase $db Database object to be used
 	 */
-	public function setDB( $db ) {
+	public function setDB( IDatabase $db ) {
 		$this->mDb = $db;
 	}
 
+	/**
+	 * Begin a transcation on a DB
+	 *
+	 * This method makes it clear that begin() is called from a maintenance script,
+	 * which has outermost scope. This is safe, unlike $dbw->begin() called in other places.
+	 *
+	 * @param IDatabase $dbw
+	 * @param string $fname Caller name
+	 * @since 1.27
+	 */
+	protected function beginTransaction( IDatabase $dbw, $fname ) {
+		$dbw->begin( $fname );
+	}
+
+	/**
+	 * Commit the transcation on a DB handle and wait for slaves to catch up
+	 *
+	 * This method makes it clear that commit() is called from a maintenance script,
+	 * which has outermost scope. This is safe, unlike $dbw->commit() called in other places.
+	 *
+	 * @param IDatabase $dbw
+	 * @param string $fname Caller name
+	 * @return bool Whether the slave wait succeeded
+	 * @since 1.27
+	 */
+	protected function commitTransaction( IDatabase $dbw, $fname ) {
+		$dbw->commit( $fname );
+
+		$ok = wfWaitForSlaves( $this->lastSlaveWait, false, '*', 30 );
+		$this->lastSlaveWait = microtime( true );
+
+		return $ok;
+	}
+
+	/**
+	 * Rollback the transcation on a DB handle
+	 *
+	 * This method makes it clear that rollback() is called from a maintenance script,
+	 * which has outermost scope. This is safe, unlike $dbw->rollback() called in other places.
+	 *
+	 * @param IDatabase $dbw
+	 * @param string $fname Caller name
+	 * @since 1.27
+	 */
+	protected function rollbackTransaction( IDatabase $dbw, $fname ) {
+		$dbw->rollback( $fname );
+	}
+
 	/**
 	 * Lock the search index
 	 * @param DatabaseBase &$db
 	 */
 	private function lockSearchindex( $db ) {
-		$write = array( 'searchindex' );
-		$read = array( 'page', 'revision', 'text', 'interwiki', 'l10n_cache', 'user', 'page_restrictions' );
+		$write = [ 'searchindex' ];
+		$read = [
+			'page',
+			'revision',
+			'text',
+			'interwiki',
+			'l10n_cache',
+			'user',
+			'page_restrictions'
+		];
 		$db->lockTables( $read, $write, __CLASS__ . '::' . __METHOD__ );
 	}
 
@@ -1251,13 +1373,13 @@ abstract class Maintenance {
 	 * @return string
 	 */
 	private static function readlineEmulation( $prompt ) {
-		$bash = Installer::locateExecutableInDefaultPaths( array( 'bash' ) );
+		$bash = Installer::locateExecutableInDefaultPaths( [ 'bash' ] );
 		if ( !wfIsWindows() && $bash ) {
 			$retval = false;
 			$encPrompt = wfEscapeShellArg( $prompt );
 			$command = "read -er -p $encPrompt && echo \"\$REPLY\"";
 			$encCommand = wfEscapeShellArg( $command );
-			$line = wfShellExec( "$bash -c $encCommand", $retval, array(), array( 'walltime' => 0 ) );
+			$line = wfShellExec( "$bash -c $encCommand", $retval, [], [ 'walltime' => 0 ] );
 
 			if ( $retval == 0 ) {
 				return $line;
@@ -1308,7 +1430,7 @@ abstract class LoggedUpdateMaintenance extends Maintenance {
 		$key = $this->getUpdateKey();
 
 		if ( !$this->hasOption( 'force' )
-			&& $db->selectRow( 'updatelog', '1', array( 'ul_key' => $key ), __METHOD__ )
+			&& $db->selectRow( 'updatelog', '1', [ 'ul_key' => $key ], __METHOD__ )
 		) {
 			$this->output( "..." . $this->updateSkippedMessage() . "\n" );
 
@@ -1319,7 +1441,7 @@ abstract class LoggedUpdateMaintenance extends Maintenance {
 			return false;
 		}
 
-		if ( $db->insert( 'updatelog', array( 'ul_key' => $key ), __METHOD__, 'IGNORE' ) ) {
+		if ( $db->insert( 'updatelog', [ 'ul_key' => $key ], __METHOD__, 'IGNORE' ) ) {
 			return true;
 		} else {
 			$this->output( $this->updatelogFailedMessage() . "\n" );
