@@ -3,15 +3,20 @@
  */
 ( function ( mw, $ ) {
 	mw.searchSuggest = {
+		// queries the wiki and calls response with the result
 		request: function ( api, query, response, maxRows ) {
 			return api.get( {
+				formatversion: 2,
 				action: 'opensearch',
 				search: query,
 				namespace: 0,
 				limit: maxRows,
-				suggest: ''
-			} ).done( function ( data ) {
-				response( data[ 1 ] );
+				suggest: true
+			} ).done( function ( data, jqXHR ) {
+				response( data[ 1 ], {
+					type: jqXHR.getResponseHeader( 'X-OpenSearch-Type' ),
+					query: query
+				} );
 			} );
 		}
 	};
@@ -86,39 +91,68 @@
 			previousSearchText = searchText;
 		}
 
+		/**
+		 * defines the location of autocomplete. Typically either
+		 * header, which is in the top right of vector (for example)
+		 * and content which identifies the main search bar on
+		 * Special:Search.  Defaults to header for skins that don't set
+		 * explicitly.
+		 *
+		 * @ignore
+		 */
+		function getInputLocation( context ) {
+			return context.config.$region
+					.closest( 'form' )
+					.find( '[data-search-loc]' )
+					.data( 'search-loc' ) || 'header';
+		}
+
 		/**
 		 * Callback that's run when suggestions have been updated either from the cache or the API
 		 * 'this' is the search input box (jQuery object)
 		 *
 		 * @ignore
 		 */
-		function onAfterUpdate() {
+		function onAfterUpdate( metadata ) {
 			var context = this.data( 'suggestionsContext' );
 
 			mw.track( 'mediawiki.searchSuggest', {
 				action: 'impression-results',
 				numberOfResults: context.config.suggestions.length,
-				// FIXME: when other types of search become available change this value accordingly
-				// See the API call below (opensearch = prefix)
-				resultSetType: 'prefix'
+				resultSetType: metadata.type || 'unknown',
+				query: metadata.query,
+				inputLocation: getInputLocation( context )
 			} );
 		}
 
 		// The function used to render the suggestions.
 		function renderFunction( text, context ) {
-			var formData = getFormData( context );
+			var formData = getFormData( context ),
+				textboxConfig = context.data.$textbox.data( 'mw-searchsuggest' ) || {};
 
 			// linkParams object is modified and reused
 			formData.linkParams[ formData.textParam ] = text;
 
+			// Allow trackers to attach tracking information, such
+			// as wprov, to clicked links.
+			mw.track( 'mediawiki.searchSuggest', {
+				action: 'render-one',
+				formData: formData,
+				index: context.config.suggestions.indexOf( text ) + 1
+			} );
+
 			// this is the container <div>, jQueryfied
-			this.text( text )
-				.wrap(
+			this.text( text );
+
+			// wrap only as link, if the config doesn't disallow it
+			if ( textboxConfig.wrapAsLink !== false	) {
+				this.wrap(
 					$( '<a>' )
 						.attr( 'href', formData.baseHref + $.param( formData.linkParams ) )
 						.attr( 'title', text )
 						.addClass( 'mw-searchSuggest-link' )
 				);
+			}
 		}
 
 		// The function used when the user makes a selection
@@ -174,9 +208,6 @@
 		searchboxesSelectors = [
 			// Primary searchbox on every page in standard skins
 			'#searchInput',
-			// Special:Search
-			'#powerSearchText',
-			'#searchText',
 			// Generic selector for skins with multiple searchboxes (used by CologneBlue)
 			// and for MediaWiki itself (special pages with page title inputs)
 			'.mw-searchInput'
@@ -206,6 +237,10 @@
 						return true;
 					}
 				},
+				update: {
+					before: onBeforeUpdate,
+					after: onAfterUpdate
+				},
 				cache: true,
 				highlightInput: true
 			} )
@@ -260,7 +295,9 @@
 				var context = $searchInput.data( 'suggestionsContext' );
 				mw.track( 'mediawiki.searchSuggest', {
 					action: 'submit-form',
-					numberOfResults: context.config.suggestions.length
+					numberOfResults: context.config.suggestions.length,
+					$form: context.config.$region.closest( 'form' ),
+					inputLocation: getInputLocation( context )
 				} );
 			} )
 			// If the form includes any fallback fulltext search buttons, remove them
