@@ -13,26 +13,30 @@ class ApiLoginTest extends ApiTestCase {
 	 * Test result of attempted login with an empty username
 	 */
 	public function testApiLoginNoName() {
-		$data = $this->doApiRequest( array( 'action' => 'login',
+		$session = [
+			'wsTokenSecrets' => [ 'login' => 'foobar' ],
+		];
+		$data = $this->doApiRequest( [ 'action' => 'login',
 			'lgname' => '', 'lgpassword' => self::$users['sysop']->password,
-		) );
-		$this->assertEquals( 'NoName', $data[0]['login']['result'] );
+			'lgtoken' => (string)( new MediaWiki\Session\Token( 'foobar', '' ) )
+		], $session );
+		$this->assertEquals( 'Failed', $data[0]['login']['result'] );
 	}
 
 	public function testApiLoginBadPass() {
 		global $wgServer;
 
 		$user = self::$users['sysop'];
-		$user->getUser()->logOut();
+		$user->getUser()->logout();
 
 		if ( !isset( $wgServer ) ) {
 			$this->markTestIncomplete( 'This test needs $wgServer to be set in LocalSettings.php' );
 		}
-		$ret = $this->doApiRequest( array(
+		$ret = $this->doApiRequest( [
 			"action" => "login",
 			"lgname" => $user->username,
 			"lgpassword" => "bad",
-		) );
+		] );
 
 		$result = $ret[0];
 
@@ -43,12 +47,12 @@ class ApiLoginTest extends ApiTestCase {
 		$token = $result["login"]["token"];
 
 		$ret = $this->doApiRequest(
-			array(
+			[
 				"action" => "login",
 				"lgtoken" => $token,
 				"lgname" => $user->username,
 				"lgpassword" => "badnowayinhell",
-			),
+			],
 			$ret[2]
 		);
 
@@ -57,7 +61,7 @@ class ApiLoginTest extends ApiTestCase {
 		$this->assertNotInternalType( "bool", $result );
 		$a = $result["login"]["result"];
 
-		$this->assertEquals( "WrongPass", $a );
+		$this->assertEquals( 'Failed', $a );
 	}
 
 	public function testApiLoginGoodPass() {
@@ -68,13 +72,13 @@ class ApiLoginTest extends ApiTestCase {
 		}
 
 		$user = self::$users['sysop'];
-		$user->getUser()->logOut();
+		$user->getUser()->logout();
 
-		$ret = $this->doApiRequest( array(
+		$ret = $this->doApiRequest( [
 				"action" => "login",
 				"lgname" => $user->username,
 				"lgpassword" => $user->password,
-			)
+			]
 		);
 
 		$result = $ret[0];
@@ -86,12 +90,12 @@ class ApiLoginTest extends ApiTestCase {
 		$token = $result["login"]["token"];
 
 		$ret = $this->doApiRequest(
-			array(
+			[
 				"action" => "login",
 				"lgtoken" => $token,
 				"lgname" => $user->username,
 				"lgpassword" => $user->password,
-			),
+			],
 			$ret[2]
 		);
 
@@ -118,12 +122,12 @@ class ApiLoginTest extends ApiTestCase {
 		$user = self::$users['sysop'];
 
 		$req = MWHttpRequest::factory( self::$apiUrl . "?action=login&format=xml",
-			array( "method" => "POST",
-				"postData" => array(
+			[ "method" => "POST",
+				"postData" => [
 					"lgname" => $user->username,
 					"lgpassword" => $user->password
-				)
-			),
+				]
+			],
 			__METHOD__
 		);
 		$req->execute();
@@ -138,10 +142,10 @@ class ApiLoginTest extends ApiTestCase {
 		$this->assertEquals( ' result="NeedToken"', $a->asXML() );
 		$token = (string)$sxe->login[0]->attributes()->token;
 
-		$req->setData( array(
+		$req->setData( [
 			"lgtoken" => $token,
 			"lgname" => $user->username,
-			"lgpassword" => $user->password ) );
+			"lgpassword" => $user->password ] );
 		$req->execute();
 
 		$cj = $req->getCookieJar();
@@ -149,7 +153,7 @@ class ApiLoginTest extends ApiTestCase {
 		$this->assertNotEquals( false, $serverName );
 		$serializedCookie = $cj->serializeToHttpRequest( $wgScriptPath, $serverName );
 		$this->assertNotEquals( '', $serializedCookie );
-		$this->assertRegexp(
+		$this->assertRegExp(
 			'/_session=[^;]*; .*UserID=[0-9]*; .*UserName=' . $user->userName . '; .*Token=/',
 			$serializedCookie
 		);
@@ -157,21 +161,21 @@ class ApiLoginTest extends ApiTestCase {
 
 	public function testRunLogin() {
 		$sysopUser = self::$users['sysop'];
-		$data = $this->doApiRequest( array(
+		$data = $this->doApiRequest( [
 			'action' => 'login',
 			'lgname' => $sysopUser->username,
-			'lgpassword' => $sysopUser->password ) );
+			'lgpassword' => $sysopUser->password ] );
 
 		$this->assertArrayHasKey( "login", $data[0] );
 		$this->assertArrayHasKey( "result", $data[0]['login'] );
 		$this->assertEquals( "NeedToken", $data[0]['login']['result'] );
 		$token = $data[0]['login']['token'];
 
-		$data = $this->doApiRequest( array(
+		$data = $this->doApiRequest( [
 			'action' => 'login',
 			"lgtoken" => $token,
 			"lgname" => $sysopUser->username,
-			"lgpassword" => $sysopUser->password ), $data[2] );
+			"lgpassword" => $sysopUser->password ], $data[2] );
 
 		$this->assertArrayHasKey( "login", $data[0] );
 		$this->assertArrayHasKey( "result", $data[0]['login'] );
@@ -179,4 +183,94 @@ class ApiLoginTest extends ApiTestCase {
 		$this->assertArrayHasKey( 'lgtoken', $data[0]['login'] );
 	}
 
+	public function testBotPassword() {
+		global $wgServer, $wgSessionProviders;
+
+		if ( !isset( $wgServer ) ) {
+			$this->markTestIncomplete( 'This test needs $wgServer to be set in LocalSettings.php' );
+		}
+
+		$this->setMwGlobals( [
+			'wgSessionProviders' => array_merge( $wgSessionProviders, [
+				[
+					'class' => MediaWiki\Session\BotPasswordSessionProvider::class,
+					'args' => [ [ 'priority' => 40 ] ],
+				]
+			] ),
+			'wgEnableBotPasswords' => true,
+			'wgBotPasswordsDatabase' => false,
+			'wgCentralIdLookupProvider' => 'local',
+			'wgGrantPermissions' => [
+				'test' => [ 'read' => true ],
+			],
+		] );
+
+		// Make sure our session provider is present
+		$manager = TestingAccessWrapper::newFromObject( MediaWiki\Session\SessionManager::singleton() );
+		if ( !isset( $manager->sessionProviders[MediaWiki\Session\BotPasswordSessionProvider::class] ) ) {
+			$tmp = $manager->sessionProviders;
+			$manager->sessionProviders = null;
+			$manager->sessionProviders = $tmp + $manager->getProviders();
+		}
+		$this->assertNotNull(
+			MediaWiki\Session\SessionManager::singleton()->getProvider(
+				MediaWiki\Session\BotPasswordSessionProvider::class
+			),
+			'sanity check'
+		);
+
+		$user = self::$users['sysop'];
+		$centralId = CentralIdLookup::factory()->centralIdFromLocalUser( $user->getUser() );
+		$this->assertNotEquals( 0, $centralId, 'sanity check' );
+
+		$passwordFactory = new PasswordFactory();
+		$passwordFactory->init( RequestContext::getMain()->getConfig() );
+		// A is unsalted MD5 (thus fast) ... we don't care about security here, this is test only
+		$passwordFactory->setDefaultType( 'A' );
+		$pwhash = $passwordFactory->newFromPlaintext( 'foobaz' );
+
+		$dbw = wfGetDB( DB_MASTER );
+		$dbw->insert(
+			'bot_passwords',
+			[
+				'bp_user' => $centralId,
+				'bp_app_id' => 'foo',
+				'bp_password' => $pwhash->toString(),
+				'bp_token' => '',
+				'bp_restrictions' => MWRestrictions::newDefault()->toJson(),
+				'bp_grants' => '["test"]',
+			],
+			__METHOD__
+		);
+
+		$lgName = $user->username . BotPassword::getSeparator() . 'foo';
+
+		$ret = $this->doApiRequest( [
+			'action' => 'login',
+			'lgname' => $lgName,
+			'lgpassword' => 'foobaz',
+		] );
+
+		$result = $ret[0];
+		$this->assertNotInternalType( 'bool', $result );
+		$this->assertNotInternalType( 'null', $result['login'] );
+
+		$a = $result['login']['result'];
+		$this->assertEquals( 'NeedToken', $a );
+		$token = $result['login']['token'];
+
+		$ret = $this->doApiRequest( [
+			'action' => 'login',
+			'lgtoken' => $token,
+			'lgname' => $lgName,
+			'lgpassword' => 'foobaz',
+		], $ret[2] );
+
+		$result = $ret[0];
+		$this->assertNotInternalType( 'bool', $result );
+		$a = $result['login']['result'];
+
+		$this->assertEquals( 'Success', $a );
+	}
+
 }
