@@ -30,9 +30,9 @@ class MediaWikiPageLinkRendererTest extends MediaWikiTestCase {
 	protected function setUp() {
 		parent::setUp();
 
-		$this->setMwGlobals( array(
+		$this->setMwGlobals( [
 			'wgContLang' => Language::factory( 'en' ),
-		) );
+		] );
 	}
 
 	/**
@@ -53,18 +53,18 @@ class MediaWikiPageLinkRendererTest extends MediaWikiTestCase {
 	}
 
 	public static function provideGetPageUrl() {
-		return array(
-			array(
+		return [
+			[
 				new TitleValue( NS_MAIN, 'Foo_Bar' ),
-				array(),
+				[],
 				'/Foo_Bar'
-			),
-			array(
+			],
+			[
 				new TitleValue( NS_USER, 'Hansi_Maier', 'stuff' ),
-				array( 'foo' => 'bar' ),
+				[ 'foo' => 'bar' ],
 				'/User:Hansi_Maier?foo=bar#stuff'
-			),
-		);
+			],
+		];
 	}
 
 	/**
@@ -86,27 +86,27 @@ class MediaWikiPageLinkRendererTest extends MediaWikiTestCase {
 	}
 
 	public static function provideRenderHtmlLink() {
-		return array(
-			array(
+		return [
+			[
 				new TitleValue( NS_MAIN, 'Foo_Bar' ),
 				'Foo Bar',
 				'!<a .*href=".*?Foo_Bar.*?".*?>Foo Bar</a>!'
-			),
-			array(
-				//NOTE: Linker doesn't include fragments in "broken" links
-				//NOTE: once this no longer uses Linker, we will get "2" instead of "User" for the namespace.
+			],
+			[
+				// NOTE: Linker doesn't include fragments in "broken" links
+				// NOTE: once this no longer uses Linker, we will get "2" instead of "User" for the namespace.
 				new TitleValue( NS_USER, 'Hansi_Maier', 'stuff' ),
 				'Hansi Maier\'s Stuff',
 				'!<a .*href=".*?User:Hansi_Maier.*?>Hansi Maier\'s Stuff</a>!'
-			),
-			array(
-				//NOTE: Linker doesn't include fragments in "broken" links
-				//NOTE: once this no longer uses Linker, we will get "2" instead of "User" for the namespace.
+			],
+			[
+				// NOTE: Linker doesn't include fragments in "broken" links
+				// NOTE: once this no longer uses Linker, we will get "2" instead of "User" for the namespace.
 				new TitleValue( NS_USER, 'Hansi_Maier', 'stuff' ),
 				null,
 				'!<a .*href=".*?User:Hansi_Maier.*?>User:Hansi Maier#stuff</a>!'
-			),
-		);
+			],
+		];
 	}
 
 	/**
@@ -128,23 +128,23 @@ class MediaWikiPageLinkRendererTest extends MediaWikiTestCase {
 	}
 
 	public static function provideRenderWikitextLink() {
-		return array(
-			array(
+		return [
+			[
 				new TitleValue( NS_MAIN, 'Foo_Bar' ),
 				'Foo Bar',
 				'[[:0:Foo Bar|Foo Bar]]'
-			),
-			array(
+			],
+			[
 				new TitleValue( NS_USER, 'Hansi_Maier', 'stuff' ),
 				'Hansi Maier\'s Stuff',
 				'[[:2:Hansi Maier#stuff|Hansi Maier&#39;s Stuff]]'
-			),
-			array(
+			],
+			[
 				new TitleValue( NS_USER, 'Hansi_Maier', 'stuff' ),
 				null,
 				'[[:2:Hansi Maier#stuff|2:Hansi Maier#stuff]]'
-			),
-		);
+			],
+		];
 	}
 
 	/**
